"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var StrategyConstants = require("../Utilities/Constants/StrategyConstants");
var AdvancedSearchRedux = require("../Redux/ActionsReducers/AdvancedSearchRedux");
var ApiBase_1 = require("./ApiBase");
var StringExtensions_1 = require("../Utilities/Extensions/StringExtensions");
var BlotterHelper_1 = require("../Utilities/Helpers/BlotterHelper");
var AdvancedSearchApi = /** @class */ (function (_super) {
    tslib_1.__extends(AdvancedSearchApi, _super);
    function AdvancedSearchApi() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    AdvancedSearchApi.prototype.getAdvancedSearchState = function () {
        return this.getBlotterState().AdvancedSearch;
    };
    AdvancedSearchApi.prototype.setAdvancedSearchState = function (advancedSearchState) {
        var _this = this;
        // add/update each advanced search where the states are different
        var advancedSearches = this.getAllAdvancedSearch();
        if (advancedSearches != advancedSearchState.AdvancedSearches) {
            advancedSearchState.AdvancedSearches.forEach(function (advancedSearch) {
                if (BlotterHelper_1.default.BlotterObjectExistsInState(advancedSearches, advancedSearch)) {
                    _this.editAdvancedSearch(advancedSearch);
                }
                else {
                    _this.addAdvancedSearch(advancedSearch);
                }
            });
        }
        // set or clear the current one
        if (this.getAdvancedSearchState().CurrentAdvancedSearch !=
            advancedSearchState.CurrentAdvancedSearch) {
            if (StringExtensions_1.default.IsNotNullOrEmpty(advancedSearchState.CurrentAdvancedSearch)) {
                this.setAdvancedSearch(advancedSearchState.CurrentAdvancedSearch);
            }
            else {
                this.clearAdvancedSearch();
            }
        }
    };
    AdvancedSearchApi.prototype.setAdvancedSearch = function (advancedSearchName) {
        var advancedSearch = this.getBlotterState().AdvancedSearch.AdvancedSearches.find(function (a) { return a.Name == advancedSearchName; });
        if (this.checkItemExists(advancedSearch, advancedSearchName, StrategyConstants.AdvancedSearchStrategyName)) {
            this.dispatchAction(AdvancedSearchRedux.AdvancedSearchSelect(advancedSearchName));
        }
    };
    AdvancedSearchApi.prototype.clearAdvancedSearch = function () {
        this.dispatchAction(AdvancedSearchRedux.AdvancedSearchSelect(''));
    };
    AdvancedSearchApi.prototype.addAdvancedSearch = function (advancedSearch) {
        this.dispatchAction(AdvancedSearchRedux.AdvancedSearchAdd(advancedSearch));
    };
    AdvancedSearchApi.prototype.editAdvancedSearch = function (advancedSearch) {
        this.dispatchAction(AdvancedSearchRedux.AdvancedSearchEdit(advancedSearch));
    };
    AdvancedSearchApi.prototype.deleteAdvancedSearch = function (advancedSearch) {
        // todo something if doesnt exist?
        if (advancedSearch) {
            this.dispatchAction(AdvancedSearchRedux.AdvancedSearchDelete(advancedSearch));
        }
    };
    AdvancedSearchApi.prototype.deleteAdvancedSearchByName = function (advancedSearchName) {
        var searchToDelete = this.getAdvancedSearchByName(advancedSearchName);
        this.deleteAdvancedSearch(searchToDelete);
    };
    AdvancedSearchApi.prototype.deleteAdvancedSearchByUuid = function (uid) {
        var searchToDelete = this.getAdvancedSearchByUuid(uid);
        this.deleteAdvancedSearch(searchToDelete);
    };
    AdvancedSearchApi.prototype.getCurrentAdvancedSearch = function () {
        return this.getAdvancedSearchByName(this.getCurrentAdvancedSearchName());
    };
    AdvancedSearchApi.prototype.getCurrentAdvancedSearchName = function () {
        return this.getBlotterState().AdvancedSearch.CurrentAdvancedSearch;
    };
    AdvancedSearchApi.prototype.getAdvancedSearchByName = function (advancedSearchName) {
        return this.getAllAdvancedSearch().find(function (a) { return a.Name == advancedSearchName; });
    };
    AdvancedSearchApi.prototype.getAdvancedSearchByUuid = function (uuid) {
        return this.getAllAdvancedSearch().find(function (a) { return a.Uuid == uuid; });
    };
    AdvancedSearchApi.prototype.getAllAdvancedSearch = function () {
        var searches = this.getBlotterState().AdvancedSearch
            .AdvancedSearches;
        if (searches == undefined) {
            searches = [];
        }
        return searches;
    };
    return AdvancedSearchApi;
}(ApiBase_1.ApiBase));
exports.AdvancedSearchApi = AdvancedSearchApi;
