"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var SystemRedux = require("../Redux/ActionsReducers/SystemRedux");
var PopupRedux = require("../Redux/ActionsReducers/PopupRedux");
var ApiBase_1 = require("./ApiBase");
var Enums_1 = require("../PredefinedConfig/Common/Enums");
var StringExtensions_1 = require("../Utilities/Extensions/StringExtensions");
var LoggingHelper_1 = require("../Utilities/Helpers/LoggingHelper");
var OpenfinHelper_1 = require("../Utilities/Helpers/OpenfinHelper");
var AlertApi = /** @class */ (function (_super) {
    tslib_1.__extends(AlertApi, _super);
    function AlertApi() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    AlertApi.prototype.getAlertState = function () {
        return this.getBlotterState().Alert;
    };
    AlertApi.prototype.displayAlert = function (alertToShow) {
        var maxAlerts = this.getBlotterState().Alert.MaxAlertsInStore;
        this.dispatchAction(SystemRedux.SystemAlertAdd(alertToShow, maxAlerts));
        if (alertToShow.ShowAsPopup) {
            if (StringExtensions_1.StringExtensions.IsNotNullOrEmpty(this.getBlotterState().Alert.AlertPopupDiv)) {
                var alertString = alertToShow.Header + ': ' + alertToShow.Msg;
                var alertDiv = document.getElementById(this.getBlotterState().Alert.AlertPopupDiv);
                if (alertDiv) {
                    alertDiv.innerHTML = alertString;
                }
            }
            else {
                this.dispatchAction(PopupRedux.PopupShowAlert(alertToShow));
            }
        }
        this.blotter.api.eventApi._onAlertFired.Dispatch(this.blotter, { alert: alertToShow });
        LoggingHelper_1.LoggingHelper.LogAlert(alertToShow.Header + ': ' + alertToShow.Msg, alertToShow.MessageType);
    };
    AlertApi.prototype.showAlert = function (alertHeader, alertMessage, MessageType, showAsPopup) {
        var MessageTypeEnum = MessageType;
        var alertToShow = {
            Header: alertHeader,
            Msg: alertMessage,
            MessageType: MessageTypeEnum,
            ShowAsPopup: showAsPopup,
        };
        this.displayAlert(alertToShow);
        // tmp
        if (OpenfinHelper_1.default.isRunningInOpenfin) {
            /*
            createOpenFinNotification({
              id: String(Math.random()),
              title: alertToShow.Header,
              body: alertToShow.Msg,
              icon: 'https://openfin.co/favicon.ico',
            });
            */
        }
    };
    AlertApi.prototype.showAlertInfo = function (alertHeader, alertMessage, showAsPopup) {
        this.showAlert(alertHeader, alertMessage, Enums_1.MessageType.Info, showAsPopup);
    };
    AlertApi.prototype.showAlertSuccess = function (alertHeader, alertMessage, showAsPopup) {
        this.showAlert(alertHeader, alertMessage, Enums_1.MessageType.Success, showAsPopup);
    };
    AlertApi.prototype.showAlertWarning = function (alertHeader, alertMessage, showAsPopup) {
        this.showAlert(alertHeader, alertMessage, Enums_1.MessageType.Warning, showAsPopup);
    };
    AlertApi.prototype.showAlertError = function (alertHeader, alertMessage, showAsPopup) {
        this.showAlert(alertHeader, alertMessage, Enums_1.MessageType.Error, showAsPopup);
    };
    return AlertApi;
}(ApiBase_1.ApiBase));
exports.AlertApi = AlertApi;
