import { Action } from 'redux';
import { IAdaptableBlotter } from '../Utilities/Interface/IAdaptableBlotter';
import { AdaptableBlotterState } from '../Redux/Store/Interface/IAdaptableStore';
export declare abstract class ApiBase {
    protected blotter: IAdaptableBlotter;
    /**
     * Constructor for all the api classes which simply takes and assigns an instance of the Adaptable Blotter
     * @param blotter the core IAdaptableBlotter object
     */
    constructor(blotter: IAdaptableBlotter);
    /**
     * Base api Helper method to ensure that the Adaptable Blotter Object being used in the function is not null or undefined
     *
     * If it does not exist then we log an error and the api method should stop
     * @param item the AdaptableBlotterObject being checked
     * @param name the name of the object if it has one (e.g. if its a search)
     * @param type the actual type of the object being checked
     */
    checkItemExists(item: any, name: string, type: string): boolean;
    /**
     * Base api Helper method that dispatches a *Redux Action* to the Store
     * @param action the Redux Action to be dispatched
     */
    dispatchAction(action: Action): void;
    /**
     * Returns the entire State from the Store
     *
     * This is a simple *getState()* call
     */
    getBlotterState(): AdaptableBlotterState;
}
