"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var LoggingHelper_1 = require("../Utilities/Helpers/LoggingHelper");
var Helper_1 = require("../Utilities/Helpers/Helper");
// Base class for the API - provides checking dispatching methods
var ApiBase = /** @class */ (function () {
    /**
     * Constructor for all the api classes which simply takes and assigns an instance of the Adaptable Blotter
     * @param blotter the core IAdaptableBlotter object
     */
    function ApiBase(blotter) {
        this.blotter = blotter;
        this.blotter = blotter;
    }
    /**
     * Base api Helper method to ensure that the Adaptable Blotter Object being used in the function is not null or undefined
     *
     * If it does not exist then we log an error and the api method should stop
     * @param item the AdaptableBlotterObject being checked
     * @param name the name of the object if it has one (e.g. if its a search)
     * @param type the actual type of the object being checked
     */
    ApiBase.prototype.checkItemExists = function (item, name, type) {
        if (Helper_1.default.objectNotExists(item)) {
            LoggingHelper_1.LoggingHelper.LogAdaptableBlotterError("No " + type + " found with the name: " + name);
            return false;
        }
        return true;
    };
    /**
     * Base api Helper method that dispatches a *Redux Action* to the Store
     * @param action the Redux Action to be dispatched
     */
    ApiBase.prototype.dispatchAction = function (action) {
        this.blotter.adaptableBlotterStore.TheStore.dispatch(action);
    };
    /**
     * Returns the entire State from the Store
     *
     * This is a simple *getState()* call
     */
    ApiBase.prototype.getBlotterState = function () {
        return this.blotter.adaptableBlotterStore.TheStore.getState();
    };
    return ApiBase;
}());
exports.ApiBase = ApiBase;
