"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var AdaptableBlotterStore_1 = require("../Redux/Store/AdaptableBlotterStore");
var Enums_1 = require("../PredefinedConfig/Common/Enums");
var ApiBase_1 = require("./ApiBase");
var ConfigApi = /** @class */ (function (_super) {
    tslib_1.__extends(ConfigApi, _super);
    function ConfigApi() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ConfigApi.prototype.configInit = function () {
        this.dispatchAction(AdaptableBlotterStore_1.InitState());
    };
    ConfigApi.prototype.configClear = function () {
        //this doesnt work but should!
        this.dispatchAction(AdaptableBlotterStore_1.ResetUserData());
    };
    ConfigApi.prototype.configDeleteLocalStorage = function () {
        //   a horrible rough and ready method which clears local storage and refreshes but is not nice.
        localStorage.removeItem(this.blotter.blotterOptions.blotterId);
        window.location.reload();
    };
    ConfigApi.prototype.configGetAllState = function () {
        return this.getBlotterState();
    };
    ConfigApi.prototype.getUserStateKeys = function () {
        return [
            'AdvancedSearch',
            'Alert',
            'BulkUpdate',
            'CalculatedColumn',
            'Calendar',
            'CellValidation',
            'Chart',
            'ColumnFilter',
            'ConditionalStyle',
            'CustomSort',
            'Dashboard',
            'DataSource',
            'Export',
            'FlashingCell',
            'FormatColumn',
            'Layout',
            'PlusMinus',
            'QuickSearch',
            'SelectedCells',
            'Shortcut',
            'SmartEdit',
            'Theme',
            'UserFilter',
        ];
    };
    ConfigApi.prototype.configGetAllUserState = function () {
        var userStateKeys = this.getUserStateKeys();
        var allState = this.configGetAllState();
        return userStateKeys.map(function (k) { return allState[k]; });
    };
    ConfigApi.prototype.configloadUserState = function (state) {
        var userStateKeys = this.getUserStateKeys();
        var userState = Object.keys(state).reduce(function (xs, x) {
            var _a;
            return (userStateKeys.indexOf(x) !== -1 ? tslib_1.__assign({}, xs, (_a = {}, _a[x] = state[x], _a)) : xs);
        }, {});
        this.dispatchAction(AdaptableBlotterStore_1.LoadState(userState));
    };
    ConfigApi.prototype.configGetUserStateByFunction = function (functionName, returnJson) {
        if (returnJson === void 0) { returnJson = false; }
        switch (functionName) {
            case Enums_1.StateChangedTrigger.AdvancedSearch:
                return returnJson
                    ? JSON.stringify(this.getBlotterState().AdvancedSearch)
                    : this.getBlotterState().AdvancedSearch;
            case Enums_1.StateChangedTrigger.Alert:
                return returnJson
                    ? JSON.stringify(this.getBlotterState().Alert)
                    : this.getBlotterState().Alert;
            case Enums_1.StateChangedTrigger.BulkUpdate:
                return returnJson
                    ? JSON.stringify(this.getBlotterState().BulkUpdate)
                    : this.getBlotterState().BulkUpdate;
            case Enums_1.StateChangedTrigger.CalculatedColumn:
                return returnJson
                    ? JSON.stringify(this.getBlotterState().CalculatedColumn)
                    : this.getBlotterState().CalculatedColumn;
            case Enums_1.StateChangedTrigger.Calendar:
                return returnJson
                    ? JSON.stringify(this.getBlotterState().Calendar)
                    : this.getBlotterState().Calendar;
            case Enums_1.StateChangedTrigger.CellValidation:
                return returnJson
                    ? JSON.stringify(this.getBlotterState().CellValidation)
                    : this.getBlotterState().CellValidation;
            case Enums_1.StateChangedTrigger.Chart:
                return returnJson
                    ? JSON.stringify(this.getBlotterState().Chart)
                    : this.getBlotterState().Chart;
            case Enums_1.StateChangedTrigger.ColumnFilter:
                return returnJson
                    ? JSON.stringify(this.getBlotterState().ColumnFilter)
                    : this.getBlotterState().ColumnFilter;
            case Enums_1.StateChangedTrigger.ConditionalStyle:
                return returnJson
                    ? JSON.stringify(this.getBlotterState().ConditionalStyle)
                    : this.getBlotterState().ConditionalStyle;
            case Enums_1.StateChangedTrigger.CustomSort:
                return returnJson
                    ? JSON.stringify(this.getBlotterState().CustomSort)
                    : this.getBlotterState().CustomSort;
            case Enums_1.StateChangedTrigger.Dashboard:
                return returnJson
                    ? JSON.stringify(this.getBlotterState().Dashboard)
                    : this.getBlotterState().Dashboard;
            case Enums_1.StateChangedTrigger.DataSource:
                return returnJson
                    ? JSON.stringify(this.getBlotterState().DataSource)
                    : this.getBlotterState().DataSource;
            case Enums_1.StateChangedTrigger.Export:
                return returnJson
                    ? JSON.stringify(this.getBlotterState().Export)
                    : this.getBlotterState().Export;
            case Enums_1.StateChangedTrigger.FlashingCell:
                return returnJson
                    ? JSON.stringify(this.getBlotterState().FlashingCell)
                    : this.getBlotterState().FlashingCell;
            case Enums_1.StateChangedTrigger.FormatColumn:
                return returnJson
                    ? JSON.stringify(this.getBlotterState().FormatColumn)
                    : this.getBlotterState().FormatColumn;
            case Enums_1.StateChangedTrigger.Layout:
                return returnJson
                    ? JSON.stringify(this.getBlotterState().Layout)
                    : this.getBlotterState().Layout;
            case Enums_1.StateChangedTrigger.PlusMinus:
                return returnJson
                    ? JSON.stringify(this.getBlotterState().PlusMinus)
                    : this.getBlotterState().PlusMinus;
            case Enums_1.StateChangedTrigger.QuickSearch:
                return returnJson
                    ? JSON.stringify(this.getBlotterState().QuickSearch)
                    : this.getBlotterState().QuickSearch;
            case Enums_1.StateChangedTrigger.CellSummary:
                return returnJson
                    ? JSON.stringify(this.getBlotterState().SelectedCells)
                    : this.getBlotterState().CellSummary;
            case Enums_1.StateChangedTrigger.Shortcut:
                return returnJson
                    ? JSON.stringify(this.getBlotterState().Shortcut)
                    : this.getBlotterState().Shortcut;
            case Enums_1.StateChangedTrigger.SmartEdit:
                return returnJson
                    ? JSON.stringify(this.getBlotterState().SmartEdit)
                    : this.getBlotterState().SmartEdit;
            case Enums_1.StateChangedTrigger.Theme:
                return returnJson
                    ? JSON.stringify(this.getBlotterState().Theme)
                    : this.getBlotterState().Theme;
            case Enums_1.StateChangedTrigger.UserFilter:
                return returnJson
                    ? JSON.stringify(this.getBlotterState().UserFilter)
                    : this.getBlotterState().UserFilter;
        }
    };
    ConfigApi.prototype.configGetAdvancedSearchState = function (returnJson) {
        if (returnJson === void 0) { returnJson = false; }
        return this.configGetUserStateByFunction(Enums_1.StateChangedTrigger.AdvancedSearch, returnJson);
    };
    ConfigApi.prototype.configGetAlertSearchState = function (returnJson) {
        if (returnJson === void 0) { returnJson = false; }
        return this.configGetUserStateByFunction(Enums_1.StateChangedTrigger.Alert, returnJson);
    };
    ConfigApi.prototype.configGetBulkUpdateState = function (returnJson) {
        if (returnJson === void 0) { returnJson = false; }
        return this.configGetUserStateByFunction(Enums_1.StateChangedTrigger.BulkUpdate, returnJson);
    };
    ConfigApi.prototype.configGetCalculatedColumnState = function (returnJson) {
        if (returnJson === void 0) { returnJson = false; }
        return this.configGetUserStateByFunction(Enums_1.StateChangedTrigger.CalculatedColumn, returnJson);
    };
    ConfigApi.prototype.configGetCalendarState = function (returnJson) {
        if (returnJson === void 0) { returnJson = false; }
        return this.configGetUserStateByFunction(Enums_1.StateChangedTrigger.Calendar, returnJson);
    };
    ConfigApi.prototype.configGetCellValidationState = function (returnJson) {
        if (returnJson === void 0) { returnJson = false; }
        return this.configGetUserStateByFunction(Enums_1.StateChangedTrigger.CellValidation, returnJson);
    };
    ConfigApi.prototype.configGetChartState = function (returnJson) {
        if (returnJson === void 0) { returnJson = false; }
        return this.configGetUserStateByFunction(Enums_1.StateChangedTrigger.Chart, returnJson);
    };
    ConfigApi.prototype.configGetColumnFilterState = function (returnJson) {
        if (returnJson === void 0) { returnJson = false; }
        return this.configGetUserStateByFunction(Enums_1.StateChangedTrigger.ColumnFilter, returnJson);
    };
    ConfigApi.prototype.configGetConditionalStyleState = function (returnJson) {
        if (returnJson === void 0) { returnJson = false; }
        return this.configGetUserStateByFunction(Enums_1.StateChangedTrigger.ConditionalStyle, returnJson);
    };
    ConfigApi.prototype.configGetCustomSortState = function (returnJson) {
        if (returnJson === void 0) { returnJson = false; }
        return this.configGetUserStateByFunction(Enums_1.StateChangedTrigger.CustomSort, returnJson);
    };
    ConfigApi.prototype.configGetDashboardState = function (returnJson) {
        if (returnJson === void 0) { returnJson = false; }
        return this.configGetUserStateByFunction(Enums_1.StateChangedTrigger.Dashboard, returnJson);
    };
    ConfigApi.prototype.configGetDataSourceState = function (returnJson) {
        if (returnJson === void 0) { returnJson = false; }
        return this.configGetUserStateByFunction(Enums_1.StateChangedTrigger.DataSource, returnJson);
    };
    ConfigApi.prototype.configGetExportState = function (returnJson) {
        if (returnJson === void 0) { returnJson = false; }
        return this.configGetUserStateByFunction(Enums_1.StateChangedTrigger.Export, returnJson);
    };
    ConfigApi.prototype.configGetFlashingCellState = function (returnJson) {
        if (returnJson === void 0) { returnJson = false; }
        return this.configGetUserStateByFunction(Enums_1.StateChangedTrigger.FlashingCell, returnJson);
    };
    ConfigApi.prototype.configGetFormatColumnState = function (returnJson) {
        if (returnJson === void 0) { returnJson = false; }
        return this.configGetUserStateByFunction(Enums_1.StateChangedTrigger.FormatColumn, returnJson);
    };
    ConfigApi.prototype.configGetLayoutState = function (returnJson) {
        if (returnJson === void 0) { returnJson = false; }
        return this.configGetUserStateByFunction(Enums_1.StateChangedTrigger.Layout, returnJson);
    };
    ConfigApi.prototype.configGetPlusMinusState = function (returnJson) {
        if (returnJson === void 0) { returnJson = false; }
        return this.configGetUserStateByFunction(Enums_1.StateChangedTrigger.PlusMinus, returnJson);
    };
    ConfigApi.prototype.configGetQuickSearchState = function (returnJson) {
        if (returnJson === void 0) { returnJson = false; }
        return this.configGetUserStateByFunction(Enums_1.StateChangedTrigger.QuickSearch, returnJson);
    };
    ConfigApi.prototype.configGetCellSummaryState = function (returnJson) {
        if (returnJson === void 0) { returnJson = false; }
        return this.configGetUserStateByFunction(Enums_1.StateChangedTrigger.CellSummary, returnJson);
    };
    ConfigApi.prototype.configGetShortcutState = function (returnJson) {
        if (returnJson === void 0) { returnJson = false; }
        return this.configGetUserStateByFunction(Enums_1.StateChangedTrigger.Shortcut, returnJson);
    };
    ConfigApi.prototype.configGetSmartEditState = function (returnJson) {
        if (returnJson === void 0) { returnJson = false; }
        return this.configGetUserStateByFunction(Enums_1.StateChangedTrigger.SmartEdit, returnJson);
    };
    ConfigApi.prototype.configGetThemeState = function (returnJson) {
        if (returnJson === void 0) { returnJson = false; }
        return this.configGetUserStateByFunction(Enums_1.StateChangedTrigger.Theme, returnJson);
    };
    ConfigApi.prototype.configGetUserFilterState = function (returnJson) {
        if (returnJson === void 0) { returnJson = false; }
        return this.configGetUserStateByFunction(Enums_1.StateChangedTrigger.UserFilter, returnJson);
    };
    return ConfigApi;
}(ApiBase_1.ApiBase));
exports.ConfigApi = ConfigApi;
