"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var LayoutRedux = require("../Redux/ActionsReducers/LayoutRedux");
var StrategyConstants = require("../Utilities/Constants/StrategyConstants");
var ApiBase_1 = require("./ApiBase");
var GeneralConstants_1 = require("../Utilities/Constants/GeneralConstants");
var LayoutApi = /** @class */ (function (_super) {
    tslib_1.__extends(LayoutApi, _super);
    function LayoutApi() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    LayoutApi.prototype.getLayoutState = function () {
        return this.getBlotterState().Layout;
    };
    LayoutApi.prototype.setLayout = function (layoutName) {
        var layout = this.getBlotterState().Layout.Layouts.find(function (l) { return l.Name == layoutName; });
        if (this.checkItemExists(layout, layoutName, StrategyConstants.LayoutStrategyName)) {
            this.dispatchAction(LayoutRedux.LayoutSelect(layoutName));
        }
    };
    LayoutApi.prototype.clearLayout = function () {
        this.dispatchAction(LayoutRedux.LayoutSelect(GeneralConstants_1.DEFAULT_LAYOUT));
    };
    LayoutApi.prototype.getCurrentLayout = function () {
        var layoutName = this.getBlotterState().Layout.CurrentLayout;
        return this.getLayoutByName(layoutName);
    };
    LayoutApi.prototype.getCurrentLayoutName = function () {
        return this.getBlotterState().Layout.CurrentLayout;
    };
    LayoutApi.prototype.getLayoutByName = function (layoutName) {
        var layout = this.getBlotterState().Layout.Layouts.find(function (l) { return l.Name == layoutName; });
        if (this.checkItemExists(layout, layoutName, StrategyConstants.LayoutStrategyName)) {
            return layout;
        }
    };
    LayoutApi.prototype.getAllLayout = function () {
        return this.getBlotterState().Layout.Layouts;
    };
    LayoutApi.prototype.saveCurrentLayout = function () {
        var currentLayoutName = this.getBlotterState().Layout.CurrentLayout;
        if (currentLayoutName != GeneralConstants_1.DEFAULT_LAYOUT) {
            var currentLayoutObject = this.getBlotterState().Layout.Layouts.find(function (l) { return l.Name == currentLayoutName; });
            if (currentLayoutObject) {
                var gridState = currentLayoutObject ? currentLayoutObject.VendorGridInfo : null;
                var visibleColumns = this.getBlotterState().Grid.Columns.filter(function (c) { return c.Visible; });
                var columSorts = this.getBlotterState().Grid.ColumnSorts;
                var layoutToSave = {
                    Uuid: currentLayoutObject.Uuid,
                    Name: currentLayoutName,
                    Columns: visibleColumns ? visibleColumns.map(function (x) { return x.ColumnId; }) : [],
                    ColumnSorts: columSorts,
                    VendorGridInfo: gridState,
                };
                this.saveLayout(layoutToSave);
            }
        }
    };
    LayoutApi.prototype.saveLayout = function (layoutToSave) {
        this.dispatchAction(LayoutRedux.LayoutSave(layoutToSave));
    };
    return LayoutApi;
}(ApiBase_1.ApiBase));
exports.LayoutApi = LayoutApi;
