"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var UserInterfaceRedux = require("../Redux/ActionsReducers/UserInterfaceRedux");
var ApiBase_1 = require("./ApiBase");
var ArrayExtensions_1 = require("../Utilities/Extensions/ArrayExtensions");
var UserInterfaceApi = /** @class */ (function (_super) {
    tslib_1.__extends(UserInterfaceApi, _super);
    function UserInterfaceApi() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    UserInterfaceApi.prototype.getUserInterfaceState = function () {
        return this.getBlotterState().UserInterface;
    };
    UserInterfaceApi.prototype.setColorPalette = function (colorPalette) {
        this.dispatchAction(UserInterfaceRedux.ColorPaletteSet(colorPalette));
    };
    UserInterfaceApi.prototype.addColorsToPalette = function (colorPalette) {
        this.dispatchAction(UserInterfaceRedux.ColorPaletteAdd(colorPalette));
    };
    UserInterfaceApi.prototype.addStyleClassNames = function (styleClassNames) {
        this.dispatchAction(UserInterfaceRedux.StyleClassNamesAdd(styleClassNames));
    };
    UserInterfaceApi.prototype.getAllPermittedValues = function () {
        return this.getBlotterState().UserInterface.PermittedColumnValues;
    };
    UserInterfaceApi.prototype.getPermittedValuesForColumn = function (columnId) {
        var permittedValues = this.getAllPermittedValues();
        if (ArrayExtensions_1.ArrayExtensions.IsNotNullOrEmpty(permittedValues)) {
            return permittedValues.find(function (pc) { return pc.ColumnId == columnId; });
        }
        return undefined;
    };
    UserInterfaceApi.prototype.setColumnPermittedValues = function (column, permittedValues) {
        var permittedColumnValues = {
            ColumnId: column,
            PermittedValues: permittedValues,
        };
        this.dispatchAction(UserInterfaceRedux.PermittedColumnValuesSet(permittedColumnValues));
    };
    UserInterfaceApi.prototype.clearColumnPermittedValues = function (column) {
        this.dispatchAction(UserInterfaceRedux.PermittedColumnValuesDelete(column));
    };
    UserInterfaceApi.prototype.getAllEditLookUpColumns = function () {
        return this.getBlotterState().UserInterface.EditLookUpColumns;
    };
    UserInterfaceApi.prototype.getEditLookUpColumnForColumn = function (columnId) {
        var editLookUpColumns = this.getAllEditLookUpColumns();
        if (ArrayExtensions_1.ArrayExtensions.IsNotNullOrEmpty(editLookUpColumns)) {
            return editLookUpColumns.find(function (pc) { return pc.ColumnId == columnId; });
        }
        return undefined;
    };
    UserInterfaceApi.prototype.isEditLookUpColumn = function (columnId) {
        var editLookUpColumnIds = this.getAllEditLookUpColumns().map(function (c) { return c.ColumnId; });
        return ArrayExtensions_1.ArrayExtensions.ContainsItem(editLookUpColumnIds, columnId);
    };
    return UserInterfaceApi;
}(ApiBase_1.ApiBase));
exports.UserInterfaceApi = UserInterfaceApi;
