import { IAdaptableBlotterStore } from '../Redux/Store/Interface/IAdaptableStore';
import { IStrategyCollection } from '../Strategy/Interface/IStrategy';
import { DataType, DistinctCriteriaPairValue } from '../PredefinedConfig/Common/Enums';
import { IAdaptableBlotter, EmitterCallback } from '../Utilities/Interface/IAdaptableBlotter';
import { IPPStyle } from '../Utilities/Interface/Reports/IPPStyle';
import { IRawValueDisplayValuePair } from '../View/UIInterfaces';
import { IBlotterApi } from '../Api/Interface/IBlotterApi';
import { AdaptableBlotterOptions } from '../BlotterOptions/AdaptableBlotterOptions';
import * as _ from 'lodash';
import { GridCell } from '../Utilities/Interface/Selection/GridCell';
import { IChartService } from '../Utilities/Services/Interface/IChartService';
import { ICalculatedColumnExpressionService } from '../Utilities/Services/Interface/ICalculatedColumnExpressionService';
import { ICalendarService } from '../Utilities/Services/Interface/ICalendarService';
import { IValidationService } from '../Utilities/Services/Interface/IValidationService';
import { IFreeTextColumnService } from '../Utilities/Services/Interface/IFreeTextColumnService';
import { IDataService } from '../Utilities/Services/Interface/IDataService';
import { IScheduleService } from '../Utilities/Services/Interface/IScheduleService';
import { IAuditLogService } from '../Utilities/Services/Interface/IAuditLogService';
import { ISearchService } from '../Utilities/Services/Interface/ISearchService';
import { IStyle } from '../PredefinedConfig/Common/IStyle';
import { IColumn } from '../Utilities/Interface/IColumn';
import { VendorGridInfo } from '../PredefinedConfig/RunTimeState/LayoutState';
import { CalculatedColumn } from '../PredefinedConfig/RunTimeState/CalculatedColumnState';
import { FreeTextColumn } from '../PredefinedConfig/RunTimeState/FreeTextColumnState';
import { PercentBar } from '../PredefinedConfig/RunTimeState/PercentBarState';
import { ActionColumn } from '../PredefinedConfig/DesignTimeState/ActionColumnState';
export declare class AdaptableBlotter implements IAdaptableBlotter {
    api: IBlotterApi;
    strategies: IStrategyCollection;
    adaptableBlotterStore: IAdaptableBlotterStore;
    CalendarService: ICalendarService;
    DataService: IDataService;
    ValidationService: IValidationService;
    AuditLogService: IAuditLogService;
    ChartService: IChartService;
    CalculatedColumnExpressionService: ICalculatedColumnExpressionService;
    FreeTextColumnService: IFreeTextColumnService;
    ScheduleService: IScheduleService;
    SearchService: ISearchService;
    blotterOptions: AdaptableBlotterOptions;
    vendorGridName: any;
    embedColumnMenu: boolean;
    private cellStyleHypergridMap;
    private cellFlashIntervalHypergridMap;
    private abContainerElement;
    private hyperGrid;
    private filterContainer;
    isInitialised: boolean;
    private throttleOnDataChangedUser;
    private throttleOnDataChangedExternal;
    hasQuickFilter: boolean;
    private runtimeConfig?;
    private emitter;
    constructor(blotterOptions: AdaptableBlotterOptions, renderGrid?: boolean);
    private getState;
    private buildFontCSSShorthand;
    private buildFontCSSProperties;
    setColumnIntoStore(): void;
    hideFilterForm(): void;
    setNewColumnListOrder(VisibleColumnList: Array<IColumn>): void;
    on: (eventName: string, callback: EmitterCallback) => () => void;
    emit: (eventName: string, data?: any) => Promise<any>;
    createMainMenu(): void;
    reloadGrid(): void;
    getPrimaryKeyValueFromRecord(record: any): any;
    gridHasCurrentEditValue(): boolean;
    getCurrentCellEditValue(): any;
    getActiveCell(): GridCell;
    debouncedSetSelectedCells: (() => void) & _.Cancelable;
    debouncedFilterGrid: (() => void) & _.Cancelable;
    private filterOnUserDataChange;
    private filterOnExternalDataChange;
    setSelectedCells(): void;
    setSelectedRows(): void;
    getColumnDataType(column: any): DataType;
    setValue(cellInfo: GridCell): void;
    setValueBatch(batchValues: GridCell[]): void;
    private ClearSelection;
    cancelEdit(): void;
    forAllRecordsDo(func: (record: any) => any): any;
    forAllVisibleRecordsDo(func: (record: any) => any): void;
    getRecordIsSatisfiedFunction(id: any, distinctCriteria: DistinctCriteriaPairValue): (columnId: string) => any;
    getRecordIsSatisfiedFunctionFromRecord(record: any, distinctCriteria: DistinctCriteriaPairValue): (columnId: string) => any;
    private getColumnIndex;
    private isColumnReadonly;
    private isColumnSortable;
    setCustomSort(columnId: string): void;
    removeCustomSort(columnId: string): void;
    ReindexAndRepaint(): void;
    getColumnValueDisplayValuePairDistinctList(columnId: string, distinctCriteria: DistinctCriteriaPairValue, visibleRowsOnly: boolean): Array<IRawValueDisplayValuePair>;
    private addDistinctItem;
    getDisplayValue(id: any, columnId: string): string;
    getDisplayValueFromRecord(row: any, columnId: string): any;
    getDisplayValueFromRawValue(colId: string, rawValue: any): any;
    getRawValueFromRecord(row: any, columnId: string): any;
    getDataRowFromRecord(record: any): any;
    getColumnFormatter(columnId: string): any;
    addCellStyleHypergrid(rowIdentifierValue: any, columnId: string, style: CellStyleHypergrid, timeout?: number): void;
    addRowStyleHypergrid(rowIdentifierValue: any, style: CellStyleHypergrid): void;
    getRowIndexHypergrid(rowIdentifierValue: any): number;
    removeCellStyleHypergrid(rowIdentifierValue: any, columnId: string, style: 'flash' | 'csColumn' | 'csRow' | 'QuickSearch' | 'formatColumn'): void;
    removeAllCellStyleHypergrid(style: 'flash' | 'csColumn' | 'csRow' | 'QuickSearch' | 'formatColumn'): void;
    applyGridFiltering(): void;
    private applyDataChange;
    clearGridFiltering(): void;
    clearColumnFiltering(columnIds: string[]): void;
    removeCalculatedColumnFromGrid(calculatedColumnID: string): void;
    editCalculatedColumnInGrid(calculatedColumn: CalculatedColumn): void;
    addCalculatedColumnToGrid(calculatedColumn: CalculatedColumn): void;
    addFreeTextColumnToGrid(freeTextColumn: FreeTextColumn): void;
    addActionColumnToGrid(actionColumn: ActionColumn): void;
    isGroupRecord(): boolean;
    getFirstRecord(): any;
    destroy(): void;
    private valOrFunc;
    getHypergridColumn(columnId: string): any;
    getIPPStyle(): IPPStyle;
    private initInternalGridLogic;
    getRowCount(): number;
    getColumnCount(): number;
    getVisibleRowCount(): number;
    getVisibleColumnCount(): number;
    selectColumn(columnId: string): void;
    onSortSaved(gridColumnIndex: number): void;
    setColumnSort(): void;
    setGridData(data: any): void;
    getVendorGridState(): VendorGridInfo;
    setVendorGridState(vendorGridState: VendorGridInfo): void;
    isSelectable(): boolean;
    private isSortable;
    private isColumnFilterable;
    showQuickFilter(): void;
    hideQuickFilter(): void;
    applyLightTheme(): void;
    applyDarkTheme(): void;
    applyBlotterTheme(themeClassName: string): void;
    private applyAlternateRowStyle;
    addPercentBar(pcr: PercentBar): void;
    removePercentBar(pcr: PercentBar): void;
    editPercentBar(pcr: PercentBar): void;
    redraw(): void;
}
export interface CellStyleHypergrid {
    conditionalStyleColumn?: IStyle;
    conditionalStyleRow?: IStyle;
    flashBackColor?: string;
    quickSearchStyle?: IStyle;
    formatColumnStyle?: IStyle;
}
