"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var Enums_1 = require("../PredefinedConfig/Common/Enums");
var DataSourceIndexed_1 = require("./DataSourceIndexed");
var SortHelper_1 = require("../Utilities/Helpers/SortHelper");
var ArrayExtensions_1 = require("../Utilities/Extensions/ArrayExtensions");
//All custom pipelines should extend from pipelineBase
exports.CustomSortDataSource = function (blotter) {
    return DataSourceIndexed_1.DataSourceIndexed.extend('CustomSortDataSource', {
        blotter: blotter,
        // This function is called on every reIndex call if this object is in the pipelne
        apply: function () {
            var columnSorts = blotter.api.gridApi.getColumnSorts();
            if (ArrayExtensions_1.ArrayExtensions.IsNullOrEmpty(columnSorts)) {
                this.clearIndex();
                return;
            }
            //There is a sort so we init the index array with each items index and we'll sort that
            this.buildIndex();
            var dataToSort = new Array(this.index.length);
            var hypergridColumns = [];
            var customSortInfoList = [];
            var customSortFunction = function (firstElement, secondElement, direction) {
                // for now assuming there is only one custom sort... might need something clever in due course
                var customSortInfo = customSortInfoList[0];
                var firstElementValueString = customSortInfo.Formatter
                    ? customSortInfo.Formatter(firstElement)
                    : String(firstElement); //firstElement[customSort.ColumnId];
                var secondElementValueString = customSortInfo.Formatter
                    ? customSortInfo.Formatter(secondElement)
                    : String(secondElement); //secondElement[customSort.ColumnId];
                var indexFirstElement = customSortInfo.SortedValues.indexOf(firstElementValueString);
                var containsFirstElement = indexFirstElement >= 0;
                var indexSecondElement = customSortInfo.SortedValues.indexOf(secondElementValueString);
                var containsSecondElement = indexSecondElement >= 0;
                //if none of the element are in the list we jsut return normal compare
                if (!containsFirstElement && !containsSecondElement) {
                    return (firstElement < secondElement ? -1 : 1) * direction;
                }
                //if first item not in the list make sure we put it after the second item
                if (!containsFirstElement) {
                    return 1 * direction;
                }
                //if second item not in the list make sure we put it after the first item
                if (!containsSecondElement) {
                    return -1 * direction;
                }
                //return the comparison from the list if the two items are in the list
                return indexFirstElement - indexSecondElement;
            };
            var basicSortFunction = function (a, b, direction) {
                if (a > b) {
                    return direction * 1;
                }
                if (a < b) {
                    return -1 * direction;
                }
                // a must be equal to b
                return 0 * direction;
            };
            var functionsArray = [];
            var directionArray = [];
            columnSorts.forEach(function (columnSort) {
                var hypergridColumn = blotter.getHypergridColumn(columnSort.Column);
                hypergridColumns.push(hypergridColumn);
                var customSort = blotter.api.customSortApi
                    .getAllCustomSort()
                    .find(function (x) { return x.ColumnId == columnSort.Column; });
                if (customSort) {
                    var direction = columnSort.SortOrder === Enums_1.SortOrder.Ascending ? 1 : -1;
                    var formatter = blotter.getColumnFormatter(customSort.ColumnId);
                    customSortInfoList.push({ SortedValues: customSort.SortedValues, Formatter: formatter });
                    directionArray.push(direction);
                    functionsArray.push(customSortFunction);
                }
                else {
                    var direction = columnSort.SortOrder == Enums_1.SortOrder.Ascending ? 1 : -1;
                    directionArray.push(direction);
                    functionsArray.push(basicSortFunction);
                }
            });
            var sortCount = columnSorts.length;
            for (var i = 0; i < dataToSort.length; i++) {
                var dataRow = this.dataSource.getRow(i);
                if (sortCount == 1) {
                    dataToSort[i] = {
                        OriginalIndex: i,
                        ColumnValue1: this.valOrFunc(dataRow, hypergridColumns[0]),
                    };
                }
                else if (sortCount == 2) {
                    dataToSort[i] = {
                        OriginalIndex: i,
                        ColumnValue1: this.valOrFunc(dataRow, hypergridColumns[0]),
                        ColumnValue2: this.valOrFunc(dataRow, hypergridColumns[1]),
                    };
                }
                else if (sortCount == 3) {
                    dataToSort[i] = {
                        OriginalIndex: i,
                        ColumnValue1: this.valOrFunc(dataRow, hypergridColumns[0]),
                        ColumnValue2: this.valOrFunc(dataRow, hypergridColumns[1]),
                        ColumnValue3: this.valOrFunc(dataRow, hypergridColumns[2]),
                    };
                }
                else if (sortCount == 4) {
                    dataToSort[i] = {
                        OriginalIndex: i,
                        ColumnValue1: this.valOrFunc(dataRow, hypergridColumns[0]),
                        ColumnValue2: this.valOrFunc(dataRow, hypergridColumns[1]),
                        ColumnValue3: this.valOrFunc(dataRow, hypergridColumns[2]),
                        ColumnValue4: this.valOrFunc(dataRow, hypergridColumns[3]),
                    };
                }
                else if (sortCount == 5) {
                    dataToSort[i] = {
                        OriginalIndex: i,
                        ColumnValue1: this.valOrFunc(dataRow, hypergridColumns[0]),
                        ColumnValue2: this.valOrFunc(dataRow, hypergridColumns[1]),
                        ColumnValue3: this.valOrFunc(dataRow, hypergridColumns[2]),
                        ColumnValue4: this.valOrFunc(dataRow, hypergridColumns[3]),
                        ColumnValue5: this.valOrFunc(dataRow, hypergridColumns[4]),
                    };
                }
            }
            if (sortCount == 1) {
                this.index = SortHelper_1.SortHelper.orderBy(dataToSort, [function (item) { return item.ColumnValue1; }], directionArray, functionsArray);
            }
            else if (sortCount == 2) {
                this.index = SortHelper_1.SortHelper.orderBy(dataToSort, [function (item) { return item.ColumnValue1; }, function (item) { return item.ColumnValue2; }], directionArray, functionsArray);
            }
            else if (sortCount == 3) {
                this.index = SortHelper_1.SortHelper.orderBy(dataToSort, [
                    function (item) { return item.ColumnValue1; },
                    function (item) { return item.ColumnValue2; },
                    function (item) { return item.ColumnValue3; },
                ], directionArray, functionsArray);
            }
            else if (sortCount == 4) {
                this.index = SortHelper_1.SortHelper.orderBy(dataToSort, [
                    function (item) { return item.ColumnValue1; },
                    function (item) { return item.ColumnValue2; },
                    function (item) { return item.ColumnValue3; },
                    function (item) { return item.ColumnValue4; },
                ], directionArray, functionsArray);
            }
            else if (sortCount == 5) {
                this.index = SortHelper_1.SortHelper.orderBy(dataToSort, [
                    function (item) { return item.ColumnValue1; },
                    function (item) { return item.ColumnValue2; },
                    function (item) { return item.ColumnValue3; },
                    function (item) { return item.ColumnValue4; },
                    function (item) { return item.ColumnValue5; },
                ], directionArray, functionsArray);
            }
        },
        valOrFunc: function (dataRow, column) {
            var result, calculator;
            if (dataRow) {
                result = dataRow[column.name];
                calculator = ((typeof result)[0] === 'f' && result) || column.calculator;
                if (calculator) {
                    result = calculator(dataRow, column.name);
                }
            }
            return result || result === 0 || result === false ? result : '';
        },
    });
};
