"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var ConditionalStyleStrategy_1 = require("../../Strategy/ConditionalStyleStrategy");
var Enums_1 = require("../../PredefinedConfig/Common/Enums");
var ExpressionHelper_1 = require("../../Utilities/Helpers/ExpressionHelper");
var ArrayExtensions_1 = require("../../Utilities/Extensions/ArrayExtensions");
var ConditionalStyleStrategyHypergrid = /** @class */ (function (_super) {
    tslib_1.__extends(ConditionalStyleStrategyHypergrid, _super);
    function ConditionalStyleStrategyHypergrid(blotter) {
        return _super.call(this, blotter) || this;
    }
    // Called when a single piece of data changes, ie. usually the result of an inline edit
    ConditionalStyleStrategyHypergrid.prototype.handleDataSourceChanged = function (dataChangedEvent) {
        var e_1, _a;
        var _this = this;
        var conditionalStyles = this.blotter.api.conditionalStyleApi.getAllConditionalStyle();
        if (ArrayExtensions_1.ArrayExtensions.IsNotNullOrEmpty(conditionalStyles)) {
            var theBlotter_1 = this.blotter;
            var columns_2 = this.blotter.api.gridApi.getColumns();
            try {
                //here we don't call Repaint as we consider that we already are in the repaint loop
                for (var columns_1 = tslib_1.__values(columns_2), columns_1_1 = columns_1.next(); !columns_1_1.done; columns_1_1 = columns_1.next()) {
                    var column = columns_1_1.value;
                    theBlotter_1.removeCellStyleHypergrid(dataChangedEvent.IdentifierValue, column.ColumnId, 'csColumn');
                    theBlotter_1.removeCellStyleHypergrid(dataChangedEvent.IdentifierValue, column.ColumnId, 'csRow');
                }
            }
            catch (e_1_1) { e_1 = { error: e_1_1 }; }
            finally {
                try {
                    if (columns_1_1 && !columns_1_1.done && (_a = columns_1.return)) _a.call(columns_1);
                }
                finally { if (e_1) throw e_1.error; }
            }
            conditionalStyles.forEach(function (c) {
                if (c.Expression) {
                    if (dataChangedEvent.Record) {
                        if (ExpressionHelper_1.ExpressionHelper.checkForExpressionFromRecord(c.Expression, dataChangedEvent.Record, columns_2, _this.blotter)) {
                            if (c.ConditionalStyleScope == Enums_1.ConditionalStyleScope.Row) {
                                theBlotter_1.addRowStyleHypergrid(dataChangedEvent.IdentifierValue, {
                                    conditionalStyleRow: c.Style,
                                });
                            }
                            else if (c.ConditionalStyleScope == Enums_1.ConditionalStyleScope.ColumnCategory) {
                                var columnCategory = _this.blotter.api.columnCategoryApi
                                    .getAllColumnCategory()
                                    .find(function (lc) { return lc.ColumnCategoryId == c.ColumnCategoryId; });
                                columnCategory.ColumnIds.forEach(function (cc) {
                                    theBlotter_1.addCellStyleHypergrid(dataChangedEvent.IdentifierValue, cc, {
                                        conditionalStyleColumn: c.Style,
                                    });
                                });
                            }
                            else if (c.ConditionalStyleScope == Enums_1.ConditionalStyleScope.Column) {
                                theBlotter_1.addCellStyleHypergrid(dataChangedEvent.IdentifierValue, c.ColumnId, {
                                    conditionalStyleColumn: c.Style,
                                });
                            }
                        }
                    }
                    else {
                        if (ExpressionHelper_1.ExpressionHelper.checkForExpression(c.Expression, dataChangedEvent.IdentifierValue, columns_2, _this.blotter)) {
                            if (c.ConditionalStyleScope == Enums_1.ConditionalStyleScope.Row) {
                                theBlotter_1.addRowStyleHypergrid(dataChangedEvent.IdentifierValue, {
                                    conditionalStyleRow: c.Style,
                                });
                            }
                            else if (c.ConditionalStyleScope == Enums_1.ConditionalStyleScope.ColumnCategory) {
                                var columnCategory = _this.blotter.api.columnCategoryApi.getColumnCategoryById(c.ColumnCategoryId);
                                columnCategory.ColumnIds.forEach(function (cc) {
                                    theBlotter_1.addCellStyleHypergrid(dataChangedEvent.IdentifierValue, cc, {
                                        conditionalStyleColumn: c.Style,
                                    });
                                });
                            }
                            else if (c.ConditionalStyleScope == Enums_1.ConditionalStyleScope.Column) {
                                theBlotter_1.addCellStyleHypergrid(dataChangedEvent.IdentifierValue, c.ColumnId, {
                                    conditionalStyleColumn: c.Style,
                                });
                            }
                        }
                    }
                }
            });
        }
    };
    ConditionalStyleStrategyHypergrid.prototype.initStyles = function () {
        var _this = this;
        var theBlotter = this.blotter;
        var columns = this.blotter.api.gridApi.getColumns();
        var conditionalStyles = theBlotter.api.conditionalStyleApi.getAllConditionalStyle();
        theBlotter.removeAllCellStyleHypergrid('csColumn');
        theBlotter.removeAllCellStyleHypergrid('csRow');
        // adding this check as things can get mixed up during 'clean user data'
        if (columns.length > 0 && conditionalStyles.length > 0) {
            var rowConditionalStyles_1 = conditionalStyles.filter(function (x) { return x.ConditionalStyleScope == Enums_1.ConditionalStyleScope.Row; });
            var columnConditionalStyles = conditionalStyles
                .filter(function (x) { return x.ConditionalStyleScope == Enums_1.ConditionalStyleScope.Column; })
                .map(function (cs) { return cs; });
            var columnConditionalStylesGroupedByColumn_1 = ArrayExtensions_1.ArrayExtensions.groupArrayBy(columnConditionalStyles, 'ColumnId');
            theBlotter.forAllRecordsDo(function (row) {
                var e_2, _a, e_3, _b;
                //here we use the operator "in" on purpose as the GroupBy function that I wrote creates
                //an object with properties that have the name of the groupbykey
                for (var column in columnConditionalStylesGroupedByColumn_1) {
                    try {
                        //we just need to find one that match....
                        for (var _c = (e_2 = void 0, tslib_1.__values(columnConditionalStylesGroupedByColumn_1[column])), _d = _c.next(); !_d.done; _d = _c.next()) {
                            var columnCS = _d.value;
                            var localCS = columnCS;
                            if (ExpressionHelper_1.ExpressionHelper.checkForExpressionFromRecord(localCS.Expression, row, columns, _this.blotter)) {
                                theBlotter.addCellStyleHypergrid(theBlotter.getPrimaryKeyValueFromRecord(row), localCS.ColumnId, { conditionalStyleColumn: localCS.Style });
                                break;
                            }
                        }
                    }
                    catch (e_2_1) { e_2 = { error: e_2_1 }; }
                    finally {
                        try {
                            if (_d && !_d.done && (_a = _c.return)) _a.call(_c);
                        }
                        finally { if (e_2) throw e_2.error; }
                    }
                }
                try {
                    //we just need to find one that match....
                    for (var rowConditionalStyles_2 = tslib_1.__values(rowConditionalStyles_1), rowConditionalStyles_2_1 = rowConditionalStyles_2.next(); !rowConditionalStyles_2_1.done; rowConditionalStyles_2_1 = rowConditionalStyles_2.next()) {
                        var rowCS = rowConditionalStyles_2_1.value;
                        if (ExpressionHelper_1.ExpressionHelper.checkForExpressionFromRecord(rowCS.Expression, row, columns, _this.blotter)) {
                            theBlotter.addRowStyleHypergrid(theBlotter.getPrimaryKeyValueFromRecord(row), {
                                conditionalStyleRow: rowCS.Style,
                            });
                            break;
                        }
                    }
                }
                catch (e_3_1) { e_3 = { error: e_3_1 }; }
                finally {
                    try {
                        if (rowConditionalStyles_2_1 && !rowConditionalStyles_2_1.done && (_b = rowConditionalStyles_2.return)) _b.call(rowConditionalStyles_2);
                    }
                    finally { if (e_3) throw e_3.error; }
                }
            });
        }
        theBlotter.ReindexAndRepaint();
    };
    return ConditionalStyleStrategyHypergrid;
}(ConditionalStyleStrategy_1.ConditionalStyleStrategy));
exports.ConditionalStyleStrategyHypergrid = ConditionalStyleStrategyHypergrid;
