"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var StrategyConstants = require("../../Utilities/Constants/StrategyConstants");
var ArrayExtensions_1 = require("../../Utilities/Extensions/ArrayExtensions");
var Enums_1 = require("../../PredefinedConfig/Common/Enums");
var DASHBOARD_SET_AVAILABLE_TOOLBARS = 'DASHBOARD_SET_AVAILABLE_TOOLBARS';
var DASHBOARD_SET_TOOLBARS = 'DASHBOARD_SET_TOOLBARS';
var DASHBOARD_SHOW_TOOLBAR = 'DASHBOARD_SHOW_TOOLBAR';
var DASHBOARD_HIDE_TOOLBAR = 'DASHBOARD_HIDE_TOOLBAR';
var DASHBOARD_MOVE_ITEM = 'DASHBOARD_MOVE_ITEM';
var DASHBOARD_SET_FUNCTION_BUTTONS = 'DASHBOARD_SET_FUNCTION_BUTTONS';
var DASHBOARD_SET_VISIBILITY = 'DASHBOARD_SET_VISIBILITY';
var DASHBOARD_SHOW_SYSTEM_STATUS_BUTTON = 'DASHBOARD_SHOW_SYSTEM_STATUS_BUTTON';
var DASHBOARD_HIDE_SYSTEM_STATUS_BUTTON = 'DASHBOARD_HIDE_SYSTEM_STATUS_BUTTON';
var DASHBOARD_SHOW_GRID_INFO_BUTTON = 'DASHBOARD_SHOW_GRID_INFO_BUTTON';
var DASHBOARD_HIDE_GRID_INFO_BUTTON = 'DASHBOARD_HIDE_GRID_INFO_BUTTON';
var DASHBOARD_SHOW_FUNCTIONS_DROPDOWN = 'DASHBOARD_SHOW_FUNCTIONS_DROPDOWN';
var DASHBOARD_HIDE_FUNCTIONS_DROPDOWN = 'DASHBOARD_HIDE_FUNCTIONS_DROPDOWN';
var DASHBOARD_SHOW_COLUMNS_DROPDOWN = 'DASHBOARD_SHOW_COLUMNS_DROPDOWN';
var DASHBOARD_HIDE_COLUMNS_DROPDOWN = 'DASHBOARD_HIDE_COLUMNS_DROPDOWN';
var DASHBOARD_SHOW_TOOLBARS_DROPDOWN = 'DASHBOARD_SHOW_TOOLBARS_DROPDOWN';
var DASHBOARD_HIDE_TOOLBARS_DROPDOWN = 'DASHBOARD_HIDE_TOOLBARS_DROPDOWN';
var DASHBOARD_SET_HOME_TOOLBAR_TITLE = 'DASHBOARD_SET_HOME_TOOLBAR_TITLE';
var DASHBOARD_SET_APPLICATION_TOOLBAR_TITLE = 'DASHBOARD_SET_APPLICATION_TOOLBAR_TITLE';
exports.DashboardSetAvailableToolbars = function (StrategyIds) { return ({
    type: DASHBOARD_SET_AVAILABLE_TOOLBARS,
    StrategyIds: StrategyIds,
}); };
exports.DashboardSetToolbars = function (StrategyIds) { return ({
    type: DASHBOARD_SET_TOOLBARS,
    StrategyIds: StrategyIds,
}); };
exports.DashboardShowToolbar = function (StrategyId) { return ({
    type: DASHBOARD_SHOW_TOOLBAR,
    StrategyId: StrategyId,
}); };
exports.DashboardHideToolbar = function (StrategyId) { return ({
    type: DASHBOARD_HIDE_TOOLBAR,
    StrategyId: StrategyId,
}); };
exports.DashboardMoveItem = function (StrategyId, NewIndex) { return ({
    type: DASHBOARD_MOVE_ITEM,
    StrategyId: StrategyId,
    NewIndex: NewIndex,
}); };
exports.DashboardSetFunctionButtons = function (StrategyIds) { return ({
    type: DASHBOARD_SET_FUNCTION_BUTTONS,
    StrategyIds: StrategyIds,
}); };
exports.DashboardSetVisibility = function (Visibility) { return ({
    type: DASHBOARD_SET_VISIBILITY,
    Visibility: Visibility,
}); };
exports.DashboardShowSystemStatusButton = function () { return ({
    type: DASHBOARD_SHOW_SYSTEM_STATUS_BUTTON,
}); };
exports.DashboardHideSystemStatusButton = function () { return ({
    type: DASHBOARD_HIDE_SYSTEM_STATUS_BUTTON,
}); };
exports.DashboardShowGridInfoButton = function () { return ({
    type: DASHBOARD_SHOW_GRID_INFO_BUTTON,
}); };
exports.DashboardHideGridInfoButton = function () { return ({
    type: DASHBOARD_HIDE_GRID_INFO_BUTTON,
}); };
exports.DashboardShowFunctionsDropdown = function () { return ({
    type: DASHBOARD_SHOW_FUNCTIONS_DROPDOWN,
}); };
exports.DashboardHideFunctionsDropdown = function () { return ({
    type: DASHBOARD_HIDE_FUNCTIONS_DROPDOWN,
}); };
exports.DashboardShowColumnsDropdown = function () { return ({
    type: DASHBOARD_SHOW_COLUMNS_DROPDOWN,
}); };
exports.DashboardHideColumnsDropdown = function () { return ({
    type: DASHBOARD_HIDE_COLUMNS_DROPDOWN,
}); };
exports.DashboardShowToolbarsDropdown = function () { return ({
    type: DASHBOARD_SHOW_TOOLBARS_DROPDOWN,
}); };
exports.DashboardHideToolbarsDropdown = function () { return ({
    type: DASHBOARD_HIDE_TOOLBARS_DROPDOWN,
}); };
exports.DashboardSetHomeToolbarTitle = function (Title) { return ({
    type: DASHBOARD_SET_HOME_TOOLBAR_TITLE,
    Title: Title,
}); };
exports.DashboardSetApplicationToolbarTitle = function (Title) { return ({
    type: DASHBOARD_SET_APPLICATION_TOOLBAR_TITLE,
    Title: Title,
}); };
var initialDashboardState = {
    AvailableToolbars: [
        StrategyConstants.AdvancedSearchStrategyId,
        StrategyConstants.AlertStrategyId,
        StrategyConstants.ApplicationStrategyId,
        StrategyConstants.BulkUpdateStrategyId,
        StrategyConstants.CellSummaryStrategyId,
        StrategyConstants.ChartStrategyId,
        StrategyConstants.ColumnFilterStrategyId,
        StrategyConstants.DataSourceStrategyId,
        StrategyConstants.ExportStrategyId,
        StrategyConstants.LayoutStrategyId,
        StrategyConstants.SmartEditStrategyId,
        StrategyConstants.QuickSearchStrategyId,
        StrategyConstants.ThemeStrategyId,
    ],
    VisibleToolbars: [
        StrategyConstants.QuickSearchStrategyId,
        StrategyConstants.LayoutStrategyId,
        StrategyConstants.ExportStrategyId,
        StrategyConstants.ColumnFilterStrategyId,
    ],
    VisibleButtons: [
        StrategyConstants.DashboardStrategyId,
        StrategyConstants.SmartEditStrategyId,
        StrategyConstants.ColumnChooserStrategyId,
        StrategyConstants.ConditionalStyleStrategyId,
        StrategyConstants.TeamSharingStrategyId,
    ],
    DashboardVisibility: Enums_1.Visibility.Visible,
    ShowSystemStatusButton: true,
    ShowGridInfoButton: true,
    ShowFunctionsDropdown: true,
    ShowColumnsDropdown: true,
    ShowToolbarsDropdown: true,
    HomeToolbarTitle: '',
    ApplicationToolbarTitle: '',
};
exports.DashboardReducer = function (state, action) {
    if (state === void 0) { state = initialDashboardState; }
    var index;
    var dashboardControls;
    switch (action.type) {
        case DASHBOARD_SET_AVAILABLE_TOOLBARS:
            return Object.assign({}, state, {
                AvailableToolbars: action.StrategyIds,
            });
        case DASHBOARD_SET_TOOLBARS: {
            var actionTyped = action;
            var dashboardToolbars = actionTyped.StrategyIds;
            return Object.assign({}, state, { VisibleToolbars: dashboardToolbars });
        }
        case DASHBOARD_MOVE_ITEM: {
            var actionTyped_1 = action;
            dashboardControls = [].concat(state.VisibleToolbars);
            index = dashboardControls.findIndex(function (a) { return a == actionTyped_1.StrategyId; });
            ArrayExtensions_1.ArrayExtensions.moveArray(dashboardControls, index, actionTyped_1.NewIndex);
            return Object.assign({}, state, { VisibleToolbars: dashboardControls });
        }
        case DASHBOARD_SHOW_TOOLBAR: {
            var actionTyped = action;
            var dashboardToolbars = [].concat(state.VisibleToolbars);
            dashboardToolbars.push(actionTyped.StrategyId);
            return Object.assign({}, state, { VisibleToolbars: dashboardToolbars });
        }
        case DASHBOARD_HIDE_TOOLBAR: {
            var actionTyped_2 = action;
            var dashboardToolbars = [].concat(state.VisibleToolbars);
            index = dashboardToolbars.findIndex(function (a) { return a == actionTyped_2.StrategyId; });
            dashboardToolbars.splice(index, 1);
            return Object.assign({}, state, { VisibleToolbars: dashboardToolbars });
        }
        case DASHBOARD_SET_FUNCTION_BUTTONS: {
            var actionTyped = action;
            var dashboardFunctionButtons = actionTyped.StrategyIds;
            return Object.assign({}, state, { VisibleButtons: dashboardFunctionButtons });
        }
        case DASHBOARD_SET_VISIBILITY: {
            var actionTyped = action;
            return Object.assign({}, state, { DashboardVisibility: actionTyped.Visibility });
        }
        case DASHBOARD_SHOW_SYSTEM_STATUS_BUTTON: {
            return Object.assign({}, state, { ShowSystemStatusButton: true });
        }
        case DASHBOARD_HIDE_SYSTEM_STATUS_BUTTON: {
            return Object.assign({}, state, { ShowSystemStatusButton: false });
        }
        case DASHBOARD_SHOW_GRID_INFO_BUTTON: {
            return Object.assign({}, state, { ShowGridInfoButton: true });
        }
        case DASHBOARD_HIDE_GRID_INFO_BUTTON: {
            return Object.assign({}, state, { ShowGridInfoButton: false });
        }
        case DASHBOARD_SHOW_FUNCTIONS_DROPDOWN: {
            return Object.assign({}, state, { ShowFunctionsDropdown: true });
        }
        case DASHBOARD_HIDE_FUNCTIONS_DROPDOWN: {
            return Object.assign({}, state, { ShowFunctionsDropdown: false });
        }
        case DASHBOARD_SHOW_COLUMNS_DROPDOWN: {
            return Object.assign({}, state, { ShowColumnsDropdown: true });
        }
        case DASHBOARD_HIDE_COLUMNS_DROPDOWN: {
            return Object.assign({}, state, { ShowColumnsDropdown: false });
        }
        case DASHBOARD_SHOW_TOOLBARS_DROPDOWN: {
            return Object.assign({}, state, { ShowToolbarsDropdown: true });
        }
        case DASHBOARD_HIDE_TOOLBARS_DROPDOWN: {
            return Object.assign({}, state, { ShowToolbarsDropdown: false });
        }
        case DASHBOARD_SET_HOME_TOOLBAR_TITLE: {
            var actionTyped = action;
            return Object.assign({}, state, { HomeToolbarTitle: actionTyped.Title });
        }
        case DASHBOARD_SET_APPLICATION_TOOLBAR_TITLE: {
            var actionTyped = action;
            return Object.assign({}, state, { ApplicationToolbarTitle: actionTyped.Title });
        }
        default:
            return state;
    }
};
