"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var UIHelper_1 = require("../../View/UIHelper");
var GeneralConstants_1 = require("../../Utilities/Constants/GeneralConstants");
exports.COLOR_PALETTE_SET = 'COLOR_PALETTE_SET';
exports.COLOR_PALETTE_ADD = 'COLOR_PALETTE_ADD';
exports.STYLE_CLASSNAMES_ADD = 'STYLE_CLASSNAMES_ADD';
exports.PERMITTED_COLUMNVALUES_SET = 'PERMITTED_COLUMNVALUES_SET';
exports.PERMITTED_COLUMNVALUES_DELETE = 'PERMITTED_COLUMNVALUES_DELETE';
exports.ColorPaletteSet = function (ColorPalette) { return ({
    type: exports.COLOR_PALETTE_SET,
    ColorPalette: ColorPalette,
}); };
exports.ColorPaletteAdd = function (ColorPalette) { return ({
    type: exports.COLOR_PALETTE_ADD,
    ColorPalette: ColorPalette,
}); };
exports.StyleClassNamesAdd = function (StyleClassNames) { return ({
    type: exports.STYLE_CLASSNAMES_ADD,
    StyleClassNames: StyleClassNames,
}); };
exports.PermittedColumnValuesSet = function (PermittedColumnValues) { return ({
    type: exports.PERMITTED_COLUMNVALUES_SET,
    PermittedColumnValues: PermittedColumnValues,
}); };
exports.PermittedColumnValuesDelete = function (Column) { return ({
    type: exports.PERMITTED_COLUMNVALUES_DELETE,
    Column: Column,
}); };
//export const PermittedColumnValuesAdd = (ColumnValues: string[]): PermittedColumnValuesAddAction => ({
//    type: PERMITTED_COLUMNVALUES_ADD,
//    ColumnValues
//})
var initialUserInterfaceState = {
    ColorPalette: UIHelper_1.UIHelper.getDefaultColors(),
    StyleClassNames: GeneralConstants_1.EMPTY_ARRAY,
    PermittedColumnValues: GeneralConstants_1.EMPTY_ARRAY,
    EditLookUpColumns: GeneralConstants_1.EMPTY_ARRAY,
};
exports.UserInterfaceStateReducer = function (state, action) {
    if (state === void 0) { state = initialUserInterfaceState; }
    var permittedColumnValues;
    switch (action.type) {
        case exports.COLOR_PALETTE_SET:
            return Object.assign({}, state, {
                ColorPalette: action.ColorPalette,
            });
        case exports.COLOR_PALETTE_ADD:
            var actionTypedAddColors = action;
            var existingColors_1 = [].concat(state.ColorPalette);
            actionTypedAddColors.ColorPalette.forEach(function (cp) {
                existingColors_1.push(cp);
            });
            return Object.assign({}, state, { ColorPalette: existingColors_1 });
        case exports.STYLE_CLASSNAMES_ADD:
            var actionTypedAddStyles = action;
            var existingStyleNames_1 = [].concat(state.StyleClassNames);
            actionTypedAddStyles.StyleClassNames.forEach(function (sc) {
                existingStyleNames_1.push(sc);
            });
            return Object.assign({}, state, { StyleClassNames: existingStyleNames_1 });
        case exports.PERMITTED_COLUMNVALUES_SET:
            var actionTypedSetColumnValues_1 = action;
            permittedColumnValues = [].concat(state.PermittedColumnValues);
            var existingPermittedColumnValues = permittedColumnValues.find(function (pcv) { return pcv.ColumnId == actionTypedSetColumnValues_1.PermittedColumnValues.ColumnId; });
            if (existingPermittedColumnValues) {
                existingPermittedColumnValues.PermittedValues =
                    actionTypedSetColumnValues_1.PermittedColumnValues.PermittedValues;
            }
            else {
                permittedColumnValues.push(actionTypedSetColumnValues_1.PermittedColumnValues);
            }
            return Object.assign({}, state, {
                PermittedColumnValues: permittedColumnValues,
            });
        case exports.PERMITTED_COLUMNVALUES_DELETE:
            var actionTypedDeleteColumnValues_1 = action;
            permittedColumnValues = [].concat(state.PermittedColumnValues);
            var index = permittedColumnValues.findIndex(function (pcv) { return pcv.ColumnId == actionTypedDeleteColumnValues_1.Column; });
            permittedColumnValues.splice(index, 1);
            return Object.assign({}, state, {
                PermittedColumnValues: permittedColumnValues,
            });
        default:
            return state;
    }
};
