"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var isomorphic_fetch_1 = require("isomorphic-fetch");
var AdaptableBlotterReduxMerger_1 = require("./AdaptableBlotterReduxMerger");
var StringExtensions_1 = require("../../Utilities/Extensions/StringExtensions");
var LoggingHelper_1 = require("../../Utilities/Helpers/LoggingHelper");
var checkStatus = function (response) {
    var error = new Error(response.statusText);
    if (response.status >= 200 && response.status < 300) {
        return response;
    }
    throw error;
};
var AdaptableBlotterReduxLocalStorageEngine = /** @class */ (function () {
    function AdaptableBlotterReduxLocalStorageEngine(key, predefinedConfig) {
        this.key = key;
        this.predefinedConfig = predefinedConfig;
        this.key = key;
        this.predefinedConfig = predefinedConfig;
    }
    AdaptableBlotterReduxLocalStorageEngine.prototype.load = function () {
        var jsonState = localStorage.getItem(this.key);
        var parsedJsonState = JSON.parse(jsonState) || {};
        if (typeof this.predefinedConfig === 'string' &&
            StringExtensions_1.StringExtensions.IsNotNullOrEmpty(this.predefinedConfig)) {
            // we have config in a file so lets merge it with the other state
            return isomorphic_fetch_1.default(this.predefinedConfig)
                .then(checkStatus)
                .then(function (response) { return response.json(); })
                .then(function (parsedPredefinedState) { return AdaptableBlotterReduxMerger_1.MergeStateFunction(parsedPredefinedState, parsedJsonState); })
                .catch(function (err) { return LoggingHelper_1.LoggingHelper.LogAdaptableBlotterError(err); });
        }
        if (this.predefinedConfig != null) {
            // we have config as an object so need to merge that
            return Promise.resolve(this.predefinedConfig)
                .then(function (parsedPredefinedState) { return AdaptableBlotterReduxMerger_1.MergeStateFunction(parsedPredefinedState, parsedJsonState); })
                .catch(function (err) { return LoggingHelper_1.LoggingHelper.LogAdaptableBlotterError(err); });
        }
        // no predefined config so nothing to merge
        return new Promise(function (resolve) {
            resolve(parsedJsonState || {});
        }).catch(rejectWithMessage);
    };
    AdaptableBlotterReduxLocalStorageEngine.prototype.save = function (state) {
        var _this = this;
        return new Promise(function (resolve) {
            localStorage.setItem(_this.key, JSON.stringify(state));
            resolve();
        }).catch(rejectWithMessage);
    };
    return AdaptableBlotterReduxLocalStorageEngine;
}());
function rejectWithMessage(error) {
    return Promise.reject(error.message);
}
function createEngine(key, predefinedConfig) {
    return new AdaptableBlotterReduxLocalStorageEngine(key, predefinedConfig);
}
exports.createEngine = createEngine;
