"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var isomorphic_fetch_1 = require("isomorphic-fetch");
var lodash_1 = require("lodash");
var LoggingHelper_1 = require("../../Utilities/Helpers/LoggingHelper");
var DEBOUNCE_DELAY = 500;
var checkStatus = function (response) {
    var error = new Error(response.statusText);
    if (response.status >= 200 && response.status < 300) {
        return response;
    }
    throw error;
};
var AdaptableBlotterRemoteStorageEngine = /** @class */ (function () {
    function AdaptableBlotterRemoteStorageEngine(url, userName, blotterId) {
        this.url = url;
        this.userName = userName;
        this.blotterId = blotterId;
        this.url = url;
        this.userName = userName;
        this.blotterId = blotterId;
        this.save = lodash_1.debounce(this.save, DEBOUNCE_DELAY);
    }
    AdaptableBlotterRemoteStorageEngine.prototype.load = function () {
        var loadOptions = {
            headers: {
                ab_username: this.userName,
                ab_id: this.blotterId,
            },
        };
        return isomorphic_fetch_1.default(this.url, loadOptions)
            .then(checkStatus)
            .then(function (response) { return response.json(); })
            .catch(function (error) { return Promise.reject(error.message); });
    };
    AdaptableBlotterRemoteStorageEngine.prototype.save = function (state) {
        var saveOptions = {
            method: 'POST',
            body: JSON.stringify(state),
            headers: {
                Accept: 'application/json',
                'Content-Type': 'application/json',
                ab_username: this.userName,
                ab_id: this.blotterId,
            },
        };
        return isomorphic_fetch_1.default(this.url, saveOptions)
            .then(checkStatus)
            .catch(function (error) {
            LoggingHelper_1.LoggingHelper.LogAdaptableBlotterError("Cannot Save Config: " + error.message);
            return Promise.reject("Cannot save config:" + error.message);
        });
    };
    return AdaptableBlotterRemoteStorageEngine;
}());
function createEngine(url, userName, blotterId) {
    return new AdaptableBlotterRemoteStorageEngine(url, userName, blotterId);
}
exports.createEngine = createEngine;
