"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var AdaptableStrategyBase_1 = require("./AdaptableStrategyBase");
var StrategyConstants = require("../Utilities/Constants/StrategyConstants");
var ScreenPopups = require("../Utilities/Constants/ScreenPopups");
var ExpressionHelper_1 = require("../Utilities/Helpers/ExpressionHelper");
var Enums_1 = require("../PredefinedConfig/Common/Enums");
var ArrayExtensions_1 = require("../Utilities/Extensions/ArrayExtensions");
var ColumnHelper_1 = require("../Utilities/Helpers/ColumnHelper");
var AlertHelper_1 = require("../Utilities/Helpers/AlertHelper");
var AlertStrategy = /** @class */ (function (_super) {
    tslib_1.__extends(AlertStrategy, _super);
    function AlertStrategy(blotter) {
        var _this = _super.call(this, StrategyConstants.AlertStrategyId, blotter) || this;
        _this.blotter.DataService.OnDataSourceChanged().Subscribe(function (sender, eventText) {
            return _this.handleDataSourceChanged(eventText);
        });
        return _this;
    }
    AlertStrategy.prototype.addPopupMenuItem = function () {
        this.createMenuItemShowPopup(StrategyConstants.AlertStrategyName, ScreenPopups.AlertPopup, StrategyConstants.AlertGlyph);
    };
    AlertStrategy.prototype.handleDataSourceChanged = function (dataChangedEvent) {
        var _this = this;
        var alertDefinitions = this.CheckDataChanged(dataChangedEvent);
        if (ArrayExtensions_1.ArrayExtensions.IsNotNullOrEmpty(alertDefinitions)) {
            var columns_1 = this.blotter.api.gridApi.getColumns();
            alertDefinitions.forEach(function (fr) {
                // might be better to do a single alert with all the messages?
                _this.blotter.api.alertApi.showAlert(ColumnHelper_1.ColumnHelper.getFriendlyNameFromColumnId(fr.ColumnId, columns_1), AlertHelper_1.AlertHelper.createAlertDescription(fr, columns_1), fr.MessageType, fr.ShowAsPopup);
            });
        }
    };
    AlertStrategy.prototype.CheckDataChanged = function (dataChangedEvent) {
        var e_1, _a, e_2, _b;
        var relatedAlertDefinitions = this.blotter.api.alertApi
            .getAlertState()
            .AlertDefinitions.filter(function (v) { return v.ColumnId == dataChangedEvent.ColumnId; });
        var triggeredAlerts = [];
        if (relatedAlertDefinitions.length > 0) {
            var columns = this.blotter.api.gridApi.getColumns();
            // first check the rules which have expressions
            var expressionAlertDefinitions = relatedAlertDefinitions.filter(function (r) {
                return ExpressionHelper_1.ExpressionHelper.IsNotNullOrEmptyExpression(r.Expression);
            });
            if (expressionAlertDefinitions.length > 0) {
                try {
                    for (var expressionAlertDefinitions_1 = tslib_1.__values(expressionAlertDefinitions), expressionAlertDefinitions_1_1 = expressionAlertDefinitions_1.next(); !expressionAlertDefinitions_1_1.done; expressionAlertDefinitions_1_1 = expressionAlertDefinitions_1.next()) {
                        var expressionRule = expressionAlertDefinitions_1_1.value;
                        var isSatisfiedExpression = ExpressionHelper_1.ExpressionHelper.checkForExpression(expressionRule.Expression, dataChangedEvent.IdentifierValue, columns, this.blotter);
                        if (isSatisfiedExpression &&
                            this.IsAlertTriggered(expressionRule, dataChangedEvent, columns)) {
                            triggeredAlerts.push(expressionRule);
                        }
                    }
                }
                catch (e_1_1) { e_1 = { error: e_1_1 }; }
                finally {
                    try {
                        if (expressionAlertDefinitions_1_1 && !expressionAlertDefinitions_1_1.done && (_a = expressionAlertDefinitions_1.return)) _a.call(expressionAlertDefinitions_1);
                    }
                    finally { if (e_1) throw e_1.error; }
                }
            }
            // now check the rules without expressions//
            var noExpressionRules = relatedAlertDefinitions.filter(function (r) {
                return ExpressionHelper_1.ExpressionHelper.IsNullOrEmptyExpression(r.Expression);
            });
            try {
                for (var noExpressionRules_1 = tslib_1.__values(noExpressionRules), noExpressionRules_1_1 = noExpressionRules_1.next(); !noExpressionRules_1_1.done; noExpressionRules_1_1 = noExpressionRules_1.next()) {
                    var noExpressionRule = noExpressionRules_1_1.value;
                    if (this.IsAlertTriggered(noExpressionRule, dataChangedEvent, columns)) {
                        triggeredAlerts.push(noExpressionRule);
                    }
                }
            }
            catch (e_2_1) { e_2 = { error: e_2_1 }; }
            finally {
                try {
                    if (noExpressionRules_1_1 && !noExpressionRules_1_1.done && (_b = noExpressionRules_1.return)) _b.call(noExpressionRules_1);
                }
                finally { if (e_2) throw e_2.error; }
            }
        }
        return triggeredAlerts;
    };
    AlertStrategy.prototype.IsAlertTriggered = function (alert, dataChangedEvent, columns) {
        // if its any change then alert triggers immediately
        if (alert.Range.Operator == Enums_1.LeafExpressionOperator.AnyChange) {
            return true;
        }
        // todo: change the last argument from null as we might want to do evaluation based on other cells...
        var column = ColumnHelper_1.ColumnHelper.getColumnFromId(dataChangedEvent.ColumnId, columns);
        var rangeEvaluation = ExpressionHelper_1.ExpressionHelper.GetRangeEvaluation(alert.Range, dataChangedEvent.NewValue, dataChangedEvent.OldValue, column, this.blotter, null);
        return ExpressionHelper_1.ExpressionHelper.TestRangeEvaluation(rangeEvaluation, this.blotter);
    };
    return AlertStrategy;
}(AdaptableStrategyBase_1.AdaptableStrategyBase));
exports.AlertStrategy = AlertStrategy;
