"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var AdaptableStrategyBase_1 = require("./AdaptableStrategyBase");
var StrategyConstants = require("../Utilities/Constants/StrategyConstants");
var ScreenPopups = require("../Utilities/Constants/ScreenPopups");
var Enums_1 = require("../PredefinedConfig/Common/Enums");
var PreviewHelper_1 = require("../Utilities/Helpers/PreviewHelper");
var BulkUpdateRedux_1 = require("../Redux/ActionsReducers/BulkUpdateRedux");
var StringExtensions_1 = require("../Utilities/Extensions/StringExtensions");
var ArrayExtensions_1 = require("../Utilities/Extensions/ArrayExtensions");
var BulkUpdateStrategy = /** @class */ (function (_super) {
    tslib_1.__extends(BulkUpdateStrategy, _super);
    function BulkUpdateStrategy(blotter) {
        return _super.call(this, StrategyConstants.BulkUpdateStrategyId, blotter) || this;
    }
    BulkUpdateStrategy.prototype.addPopupMenuItem = function () {
        this.createMenuItemShowPopup(StrategyConstants.BulkUpdateStrategyName, ScreenPopups.BulkUpdatePopup, StrategyConstants.BulkUpdateGlyph);
    };
    BulkUpdateStrategy.prototype.ApplyBulkUpdate = function (newValues) {
        if (this.blotter.AuditLogService.isAuditFunctionEventsEnabled) {
            // logging audit log function here as there is no obvious Action to listen to in the Store - not great but not end of the world...
            var functionAppliedDetails = {
                name: StrategyConstants.BulkUpdateStrategyId,
                action: BulkUpdateRedux_1.BULK_UPDATE_APPLY,
                info: 'Bulk Update Applied',
                data: newValues,
            };
            this.blotter.AuditLogService.addFunctionAppliedAuditLog(functionAppliedDetails);
        }
        this.blotter.api.gridApi.setGridCellBatch(newValues);
    };
    BulkUpdateStrategy.prototype.CheckCorrectCellSelection = function () {
        var selectedCellInfo = this.blotter.api.gridApi.getSelectedCellInfo();
        if (selectedCellInfo == null || ArrayExtensions_1.default.IsNullOrEmpty(selectedCellInfo.Columns)) {
            return {
                IsValid: false,
                Alert: {
                    Header: 'Bulk Update Error',
                    Msg: 'No cells are selected.\nPlease select some cells.',
                    MessageType: Enums_1.MessageType.Error,
                    ShowAsPopup: true,
                },
            };
        }
        if (ArrayExtensions_1.default.NotCorrectLength(selectedCellInfo.Columns, 1)) {
            return {
                IsValid: false,
                Alert: {
                    Header: 'Bulk Update Error',
                    Msg: 'Bulk Update only supports single column edit.\nPlease adjust cell selection.',
                    MessageType: Enums_1.MessageType.Error,
                    ShowAsPopup: true,
                },
            };
        }
        var selectedColumn = selectedCellInfo.Columns[0];
        if (selectedColumn.ReadOnly) {
            return {
                IsValid: false,
                Alert: {
                    Header: 'Bulk Update Error',
                    Msg: 'Bulk Update is not permitted on readonly columns.\nPlease adjust the cell selection.',
                    MessageType: Enums_1.MessageType.Error,
                    ShowAsPopup: true,
                },
            };
        }
        return { IsValid: true, Column: selectedColumn };
    };
    BulkUpdateStrategy.prototype.BuildPreviewValues = function (bulkUpdateValue) {
        var _this = this;
        var previewResults = [];
        if (StringExtensions_1.default.IsNullOrEmpty(String(bulkUpdateValue))) {
            return null;
        }
        var selectedCellInfo = this.blotter.api.gridApi.getSelectedCellInfo();
        var columnId = '';
        if (selectedCellInfo != null && selectedCellInfo.Columns.length > 0) {
            columnId = selectedCellInfo.Columns[0].ColumnId;
            var typedBulkUpdateValue_1;
            switch (selectedCellInfo.Columns[0].DataType) {
                case Enums_1.DataType.Number:
                    typedBulkUpdateValue_1 = Number(bulkUpdateValue);
                    break;
                case Enums_1.DataType.String:
                    typedBulkUpdateValue_1 = bulkUpdateValue;
                    break;
                case Enums_1.DataType.Date:
                    typedBulkUpdateValue_1 = new Date(bulkUpdateValue);
                    break;
            }
            selectedCellInfo.GridCells.forEach(function (selectedCell) {
                var dataChangedEvent = {
                    OldValue: selectedCell.value,
                    NewValue: typedBulkUpdateValue_1,
                    ColumnId: selectedCell.columnId,
                    IdentifierValue: selectedCell.primaryKeyValue,
                    Record: null,
                };
                var validationRules = _this.blotter.ValidationService.ValidateCellChanging(dataChangedEvent);
                var previewResult = {
                    Id: selectedCell.primaryKeyValue,
                    InitialValue: selectedCell.value,
                    ComputedValue: typedBulkUpdateValue_1,
                    ValidationRules: validationRules,
                };
                previewResults.push(previewResult);
            });
        }
        return {
            ColumnId: columnId,
            PreviewResults: previewResults,
            PreviewValidationSummary: PreviewHelper_1.PreviewHelper.GetPreviewValidationSummary(previewResults),
        };
    };
    return BulkUpdateStrategy;
}(AdaptableStrategyBase_1.AdaptableStrategyBase));
exports.BulkUpdateStrategy = BulkUpdateStrategy;
