"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var AdaptableStrategyBase_1 = require("./AdaptableStrategyBase");
var StrategyConstants = require("../Utilities/Constants/StrategyConstants");
var ScreenPopups = require("../Utilities/Constants/ScreenPopups");
var Enums_1 = require("../PredefinedConfig/Common/Enums");
var ArrayExtensions_1 = require("../Utilities/Extensions/ArrayExtensions");
var Helper_1 = require("../Utilities/Helpers/Helper");
var CellSummaryStrategy = /** @class */ (function (_super) {
    tslib_1.__extends(CellSummaryStrategy, _super);
    function CellSummaryStrategy(blotter) {
        return _super.call(this, StrategyConstants.CellSummaryStrategyId, blotter) || this;
    }
    CellSummaryStrategy.prototype.addPopupMenuItem = function () {
        this.createMenuItemShowPopup(StrategyConstants.CellSummaryStrategyName, ScreenPopups.CellSummaryPopup, StrategyConstants.CellSummaryGlyph);
    };
    CellSummaryStrategy.prototype.CreateCellSummary = function (selectedCellInfo) {
        var selectedCellSummary;
        if (selectedCellInfo && ArrayExtensions_1.ArrayExtensions.IsNotNullOrEmpty(selectedCellInfo.Columns)) {
            var numericValues_1 = [];
            var allValues_1 = [];
            var numericColumns_1 = [];
            selectedCellInfo.Columns.map(function (c) {
                if (c && c.DataType == Enums_1.DataType.Number) {
                    numericColumns_1.push(c.ColumnId);
                }
            });
            selectedCellInfo.GridCells.forEach(function (selectedCell) {
                var value = selectedCell.value;
                allValues_1.push(value);
                if (ArrayExtensions_1.ArrayExtensions.ContainsItem(numericColumns_1, selectedCell.columnId)) {
                    var valueAsNumber = Number(value);
                    // possible that its not a number despite it being a numeric column
                    if (!isNaN(Number(valueAsNumber))) {
                        numericValues_1.push(valueAsNumber);
                    }
                }
            });
            var hasNumericColumns = numericValues_1.length > 0;
            var distinctCount = ArrayExtensions_1.ArrayExtensions.RetrieveDistinct(allValues_1).length;
            selectedCellSummary = {
                Sum: hasNumericColumns ? Helper_1.Helper.RoundNumberTo4dp(this.sumNumberArray(numericValues_1)) : '',
                Average: hasNumericColumns
                    ? Helper_1.Helper.RoundNumberTo4dp(this.meanNumberArray(numericValues_1))
                    : '',
                Median: hasNumericColumns
                    ? Helper_1.Helper.RoundNumberTo4dp(this.medianNumberArray(numericValues_1))
                    : '',
                Distinct: distinctCount,
                Max: hasNumericColumns ? Helper_1.Helper.RoundNumberTo4dp(Math.max.apply(Math, tslib_1.__spread(numericValues_1))) : '',
                Min: hasNumericColumns ? Helper_1.Helper.RoundNumberTo4dp(Math.min.apply(Math, tslib_1.__spread(numericValues_1))) : '',
                Count: allValues_1.length,
                Only: this.calculateOnly(distinctCount, allValues_1),
                VWAP: this.calculateVwap(numericValues_1, numericColumns_1),
            };
        }
        return selectedCellSummary;
    };
    CellSummaryStrategy.prototype.sumNumberArray = function (numericValues) {
        return numericValues.reduce(function (a, b) {
            return a + b;
        }, 0);
    };
    CellSummaryStrategy.prototype.meanNumberArray = function (numericValues) {
        return this.sumNumberArray(numericValues) / numericValues.length;
    };
    CellSummaryStrategy.prototype.medianNumberArray = function (numericValues) {
        // median of [3, 5, 4, 4, 1, 1, 2, 3] = 3
        var median = 0, numsLen = numericValues.length;
        numericValues.sort();
        if (numsLen % 2 ===
            0 // is even
        ) {
            // average of two middle numbers
            median = (numericValues[numsLen / 2 - 1] + numericValues[numsLen / 2]) / 2;
        }
        else {
            // is odd
            // middle number only
            median = numericValues[(numsLen - 1) / 2];
        }
        return median;
    };
    CellSummaryStrategy.prototype.calculateOnly = function (distinctCount, allValues) {
        if (ArrayExtensions_1.ArrayExtensions.NotContainsItem(this.blotter.api.cellSummaryApi.getCellSummaryState().OptionalSummaryOperations, Enums_1.CellSummaryOptionalOperation.Only)) {
            return null;
        }
        return distinctCount == 1 ? allValues[0] : '';
    };
    CellSummaryStrategy.prototype.calculateVwap = function (numericValues, numericColumns) {
        if (ArrayExtensions_1.ArrayExtensions.NotContainsItem(this.blotter.api.cellSummaryApi.getCellSummaryState().OptionalSummaryOperations, Enums_1.CellSummaryOptionalOperation.VWAP)) {
            return null;
        }
        if (numericColumns.length == 2) {
            return '';
        }
        var firstColValues = [];
        var secondColComputedValues = [];
        for (var i = 0; i < numericValues.length; i++) {
            if (i % 2 === 0) {
                // index is odd
                firstColValues.push(numericValues[i]);
            }
            else {
                var newValue = numericValues[i] * numericValues[i - 1];
                secondColComputedValues.push(newValue);
            }
        }
        var firstColTotal = this.sumNumberArray(firstColValues);
        var secondColTotal = this.sumNumberArray(secondColComputedValues);
        var result = Helper_1.Helper.RoundNumberTo4dp(secondColTotal / firstColTotal);
        return result;
    };
    return CellSummaryStrategy;
}(AdaptableStrategyBase_1.AdaptableStrategyBase));
exports.CellSummaryStrategy = CellSummaryStrategy;
