"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var AdaptableStrategyBase_1 = require("./AdaptableStrategyBase");
var StrategyConstants = require("../Utilities/Constants/StrategyConstants");
var ScreenPopups = require("../Utilities/Constants/ScreenPopups");
var CustomSortStrategy = /** @class */ (function (_super) {
    tslib_1.__extends(CustomSortStrategy, _super);
    function CustomSortStrategy(blotter) {
        return _super.call(this, StrategyConstants.CustomSortStrategyId, blotter) || this;
    }
    CustomSortStrategy.prototype.InitState = function () {
        if (this.CustomSorts != this.blotter.api.customSortApi.getAllCustomSort()) {
            this.removeCustomSorts();
            this.CustomSorts = this.blotter.api.customSortApi.getAllCustomSort();
            this.applyCustomSorts();
        }
    };
    CustomSortStrategy.prototype.addPopupMenuItem = function () {
        this.createMenuItemShowPopup(StrategyConstants.CustomSortStrategyName, ScreenPopups.CustomSortPopup, StrategyConstants.CustomSortGlyph);
    };
    CustomSortStrategy.prototype.addColumnMenuItem = function (column) {
        if (this.canCreateColumnMenuItem(column, this.blotter, 'sort')) {
            var customSort = this.CustomSorts.find(function (x) { return x.ColumnId == column.ColumnId; });
            var label = customSort ? 'Edit ' : 'Create ';
            var popupParam = customSort ? 'Edit|' : 'New|';
            this.createColumnMenuItemShowPopup(label + StrategyConstants.CustomSortStrategyName, ScreenPopups.CustomSortPopup, StrategyConstants.CustomSortGlyph, popupParam + column.ColumnId);
        }
    };
    CustomSortStrategy.prototype.removeCustomSorts = function () {
        var _this = this;
        if (this.CustomSorts) {
            this.CustomSorts.forEach(function (customSort) {
                _this.blotter.removeCustomSort(customSort.ColumnId);
            });
        }
    };
    CustomSortStrategy.prototype.applyCustomSorts = function () {
        var _this = this;
        this.CustomSorts.forEach(function (customSort) {
            _this.blotter.setCustomSort(customSort.ColumnId, _this.getComparerFunction(customSort, _this.blotter));
        });
    };
    CustomSortStrategy.prototype.getComparerFunction = function (customSort, blotter) {
        return function compareItemsOfCustomSort(firstElement, secondElement) {
            var firstElementValueString = blotter.getDisplayValue(blotter.getPrimaryKeyValueFromRecord(firstElement), customSort.ColumnId); //firstElement[customSort.ColumnId];
            var secondElementValueString = blotter.getDisplayValue(blotter.getPrimaryKeyValueFromRecord(secondElement), customSort.ColumnId); //secondElement[customSort.ColumnId];
            var firstElementValue = firstElement[customSort.ColumnId];
            var secondElementValue = secondElement[customSort.ColumnId];
            var indexFirstElement = customSort.SortedValues.indexOf(firstElementValueString);
            var containsFirstElement = indexFirstElement >= 0;
            var indexSecondElement = customSort.SortedValues.indexOf(secondElementValueString);
            var containsSecondElement = indexSecondElement >= 0;
            //if none of the element are in the list we jsut return normal compare
            if (!containsFirstElement && !containsSecondElement) {
                return firstElementValue < secondElementValue ? -1 : 1;
            }
            //if first item not in the list make sure we put it after the second item
            if (!containsFirstElement) {
                return 1;
            }
            //if second item not in the list make sure we put it after the first item
            if (!containsSecondElement) {
                return -1;
            }
            //return the comparison from the list if the two items are in the list
            return indexFirstElement - indexSecondElement;
        };
    };
    return CustomSortStrategy;
}(AdaptableStrategyBase_1.AdaptableStrategyBase));
exports.CustomSortStrategy = CustomSortStrategy;
