"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var AdaptableStrategyBase_1 = require("./AdaptableStrategyBase");
var StrategyConstants = require("../Utilities/Constants/StrategyConstants");
var ScreenPopups = require("../Utilities/Constants/ScreenPopups");
var PopupRedux = require("../Redux/ActionsReducers/PopupRedux");
var SystemRedux = require("../Redux/ActionsReducers/SystemRedux");
var Enums_1 = require("../PredefinedConfig/Common/Enums");
var Helper_1 = require("../Utilities/Helpers/Helper");
var ReportHelper_1 = require("../Utilities/Helpers/ReportHelper");
var OpenfinHelper_1 = require("../Utilities/Helpers/OpenfinHelper");
var _ = require("lodash");
var iPushPullHelper_1 = require("../Utilities/Helpers/iPushPullHelper");
var LoggingHelper_1 = require("../Utilities/Helpers/LoggingHelper");
var ArrayExtensions_1 = require("../Utilities/Extensions/ArrayExtensions");
var Glue42Helper_1 = require("../Utilities/Helpers/Glue42Helper");
var GeneralConstants_1 = require("../Utilities/Constants/GeneralConstants");
var ExportStrategy = /** @class */ (function (_super) {
    tslib_1.__extends(ExportStrategy, _super);
    function ExportStrategy(blotter) {
        var _this = _super.call(this, StrategyConstants.ExportStrategyId, blotter) || this;
        _this.isSendingData = false;
        _this.workAroundOpenfinExcelDataDimension = new Map();
        _this.throttledRecomputeAndSendLiveExcelEvent = _.throttle(function () { return _this.sendNewDataToLiveExcel(); }, 2000);
        //  this.blotter.onGridReloaded().Subscribe((sender, blotter) => this.handleGridReloaded());
        _this.blotter.on(GeneralConstants_1.GRID_RELOADED_EVENT, function () {
            _this.scheduleReports();
        });
        OpenfinHelper_1.OpenfinHelper.OnExcelDisconnected().Subscribe(function () {
            LoggingHelper_1.LoggingHelper.LogAdaptableBlotterInfo('Excel closed stopping all Live Excel');
            _this.blotter.api.internalApi.getLiveReports().forEach(function (cle) {
                _this.blotter.adaptableBlotterStore.TheStore.dispatch(SystemRedux.ReportStopLive(cle.Report, Enums_1.ExportDestination.OpenfinExcel));
            });
        });
        OpenfinHelper_1.OpenfinHelper.OnWorkbookDisconnected().Subscribe(function (sender, workbook) {
            LoggingHelper_1.LoggingHelper.LogAdaptableBlotterInfo('Workbook closed:' + workbook.name + ', Stopping Openfin Live Excel');
            var liveReport = _this.blotter.api.internalApi
                .getLiveReports()
                .find(function (x) { return x.WorkbookName == workbook.name; });
            if (liveReport) {
                _this.blotter.adaptableBlotterStore.TheStore.dispatch(SystemRedux.ReportStopLive(liveReport.Report, Enums_1.ExportDestination.OpenfinExcel));
            }
        });
        OpenfinHelper_1.OpenfinHelper.OnWorkbookSaved().Subscribe(function (sender, workbookSavedEvent) {
            LoggingHelper_1.LoggingHelper.LogAdaptableBlotterInfo('Workbook Saved', workbookSavedEvent);
            var liveReport = _this.blotter.api.internalApi
                .getLiveReports()
                .find(function (x) { return x.WorkbookName == workbookSavedEvent.OldName; });
            _this.blotter.adaptableBlotterStore.TheStore.dispatch(SystemRedux.ReportStopLive(liveReport.Report, Enums_1.ExportDestination.OpenfinExcel));
            _this.blotter.adaptableBlotterStore.TheStore.dispatch(SystemRedux.ReportStartLive(liveReport.Report, workbookSavedEvent.NewName, Enums_1.ExportDestination.OpenfinExcel));
        });
        _this.blotter.DataService.OnDataSourceChanged().Subscribe(function () {
            _this.throttledRecomputeAndSendLiveExcelEvent();
        });
        _this.blotter.on(GeneralConstants_1.GRID_REFRESHED_EVENT, function () {
            _this.throttledRecomputeAndSendLiveExcelEvent();
        });
        _this.blotter.on(GeneralConstants_1.CELLS_SELECTED_EVENT, function () {
            if (ArrayExtensions_1.ArrayExtensions.IsNotNullOrEmpty(_this.blotter.api.internalApi.getLiveReports())) {
                var liveReport = _this.blotter.api.internalApi
                    .getLiveReports()
                    .find(function (x) { return x.Report.Name == ReportHelper_1.ReportHelper.SELECTED_CELLS_REPORT; });
                if (liveReport) {
                    _this.throttledRecomputeAndSendLiveExcelEvent();
                }
            }
        });
        return _this;
    }
    ExportStrategy.prototype.addPopupMenuItem = function () {
        this.createMenuItemShowPopup(StrategyConstants.ExportStrategyName, ScreenPopups.ExportPopup, StrategyConstants.ExportGlyph);
    };
    ExportStrategy.prototype.sendNewDataToLiveExcel = function () {
        var _this = this;
        //we wait for the last sendNewDataToLiveExcel to finish
        if (this.isSendingData == true) {
            this.throttledRecomputeAndSendLiveExcelEvent();
            return;
        }
        if (ArrayExtensions_1.ArrayExtensions.IsNotNullOrEmpty(this.blotter.api.internalApi.getLiveReports())) {
            this.isSendingData = true;
            var ippStyle_1 = this.blotter.getIPPStyle();
            var promises_1 = [];
            this.blotter.api.internalApi.getLiveReports().forEach(function (cle) {
                if (cle.ExportDestination == Enums_1.ExportDestination.OpenfinExcel) {
                    promises_1.push(Promise.resolve()
                        .then(function () {
                        return new Promise(function (resolve, reject) {
                            //we want to erase old cells in case we are sending less data
                            //we don't want to call clearCellContent as it makes the excel sheet to blink
                            //and also is incorrrect as until we call setcells again we've lost all values in excel which might upset
                            //some macros
                            var previousDimension = _this.workAroundOpenfinExcelDataDimension.get(cle.Report.Uuid);
                            var ReportAsArray = _this.ConvertReportToArray(cle.Report);
                            var newDimension = { x: ReportAsArray[0].length, y: ReportAsArray.length };
                            if (previousDimension) {
                                var missingNumberOfRows = previousDimension.y - newDimension.y;
                                var missingNumberOfColumns_1 = previousDimension.x - newDimension.x;
                                if (missingNumberOfRows > 0) {
                                    for (var i = 0; i < missingNumberOfRows; i++) {
                                        var newRow = [];
                                        for (var j = 0; j < newDimension.x; j++) {
                                            newRow.push(null);
                                        }
                                        ReportAsArray.push(newRow);
                                    }
                                }
                                if (missingNumberOfColumns_1 > 0) {
                                    //missing column
                                    ReportAsArray.forEach(function (row) {
                                        for (var j = 0; j < missingNumberOfColumns_1; j++) {
                                            row.push(null);
                                        }
                                    });
                                }
                            }
                            if (ReportAsArray) {
                                _this.workAroundOpenfinExcelDataDimension.set(cle.Report.Uuid, newDimension);
                                resolve(ReportAsArray);
                            }
                            else {
                                reject();
                            }
                        });
                    })
                        .then(function (ReportAsArray) {
                        return OpenfinHelper_1.OpenfinHelper.pushData(cle.WorkbookName, ReportAsArray);
                    })
                        .catch(function (reason) {
                        LoggingHelper_1.LoggingHelper.LogAdaptableBlotterWarning('Live Excel failed to send data for [' + cle.Report + ']', reason);
                        _this.blotter.adaptableBlotterStore.TheStore.dispatch(SystemRedux.ReportStopLive(cle.Report, Enums_1.ExportDestination.OpenfinExcel));
                        _this.blotter.api.alertApi.showAlertError('Live Excel Error', 'Failed to send data for [' + cle.Report + ']. This live export has been stopped', true);
                    }));
                }
                else if (cle.ExportDestination == Enums_1.ExportDestination.iPushPull) {
                    //we there is no logic related to the Report so we want to get it only one time
                    if (!ippStyle_1) {
                        ippStyle_1 = _this.blotter.getIPPStyle();
                    }
                    promises_1.push(Promise.resolve()
                        .then(function () {
                        return new Promise(function (resolve, reject) {
                            var ReportAsArray = _this.ConvertReportToArray(cle.Report);
                            if (ReportAsArray) {
                                resolve(ReportAsArray);
                            }
                            else {
                                reject();
                            }
                        });
                    })
                        .then(function (ReportAsArray) {
                        return iPushPullHelper_1.iPushPullHelper.pushData(cle.WorkbookName, ReportAsArray, ippStyle_1);
                    })
                        .catch(function (reason) {
                        LoggingHelper_1.LoggingHelper.LogAdaptableBlotterWarning('Live Excel failed to send data for [' + cle.Report + ']', reason);
                        _this.blotter.adaptableBlotterStore.TheStore.dispatch(SystemRedux.ReportStopLive(cle.Report, Enums_1.ExportDestination.iPushPull));
                        _this.blotter.api.alertApi.showAlertError('Live Excel Error', 'Failed to send data for [' + cle.Report + ']. This live export has been stopped', true);
                    }));
                }
            });
            Promise.all(promises_1)
                .then(function () {
                LoggingHelper_1.LoggingHelper.LogAdaptableBlotterSuccess('All live report data sent');
                _this.isSendingData = false;
            })
                .catch(function () {
                LoggingHelper_1.LoggingHelper.LogAdaptableBlotterWarning('One live Excel failed to send data');
                _this.isSendingData = false;
            });
        }
    };
    ExportStrategy.prototype.Export = function (report, exportDestination, folder, page) {
        var _this = this;
        switch (exportDestination) {
            case Enums_1.ExportDestination.Clipboard:
                this.copyToClipboard(report);
                break;
            case Enums_1.ExportDestination.CSV:
                this.convertReportToCsv(report);
                break;
            case Enums_1.ExportDestination.OpenfinExcel:
                OpenfinHelper_1.OpenfinHelper.initOpenFinExcel() //.then((workbook) => OpenfinHelper.addReportWorkSheet(workbook, ReportName))
                    .then(function (workbookName) {
                    _this.blotter.adaptableBlotterStore.TheStore.dispatch(SystemRedux.ReportStartLive(report, workbookName, Enums_1.ExportDestination.OpenfinExcel));
                    setTimeout(function () {
                        _this.throttledRecomputeAndSendLiveExcelEvent();
                    }, 500);
                });
                break;
            case Enums_1.ExportDestination.iPushPull:
                iPushPullHelper_1.iPushPullHelper.LoadPage(folder, page).then(function () {
                    _this.blotter.api.internalApi.startLiveReport(report, page, Enums_1.ExportDestination.iPushPull);
                    setTimeout(function () {
                        _this.throttledRecomputeAndSendLiveExcelEvent();
                    }, 500);
                });
                break;
            case Enums_1.ExportDestination.Glue42:
                var data = this.ConvertReportToArray(report);
                var gridColumns = this.blotter.adaptableBlotterStore.TheStore.getState().Grid
                    .Columns;
                Glue42Helper_1.Glue42Helper.exportData(data, gridColumns, this.blotter);
                break;
        }
    };
    ExportStrategy.prototype.convertReportToCsv = function (report) {
        var csvContent = this.createCSVContent(report);
        if (csvContent) {
            var csvFileName = report.Name + '.csv';
            Helper_1.Helper.createDownloadedFile(csvContent, csvFileName, 'text/csv;encoding:utf-8');
        }
    };
    ExportStrategy.prototype.copyToClipboard = function (report) {
        var csvContent = this.createTabularContent(report);
        if (csvContent) {
            Helper_1.Helper.copyToClipboard(csvContent);
        }
    };
    ExportStrategy.prototype.createCSVContent = function (report) {
        var ReportAsArray = this.ConvertReportToArray(report);
        if (ReportAsArray) {
            return Helper_1.Helper.convertArrayToCsv(ReportAsArray, ',');
        }
        return null;
    };
    ExportStrategy.prototype.createTabularContent = function (report) {
        var ReportAsArray = this.ConvertReportToArray(report);
        if (ReportAsArray) {
            return Helper_1.Helper.convertArrayToCsv(ReportAsArray, '\t');
        }
        return null;
    };
    // Converts a Report into an array of array - first array is the column names and subsequent arrays are the values
    ExportStrategy.prototype.ConvertReportToArray = function (report) {
        var actionReturnObj = ReportHelper_1.ReportHelper.ConvertReportToArray(this.blotter, report);
        if (actionReturnObj.Alert) {
            // assume that the MessageType is error - if not then refactor
            this.blotter.adaptableBlotterStore.TheStore.dispatch(PopupRedux.PopupShowAlert(actionReturnObj.Alert));
            return null;
        }
        return actionReturnObj.ActionReturn;
    };
    ExportStrategy.prototype.scheduleReports = function () {
        var _this = this;
        // just clear all jobs and recreate - simplest thing to do...
        this.blotter.ScheduleService.ClearAllExportJobs();
        this.blotter.adaptableBlotterStore.TheStore.getState().Export.Reports.forEach(function (report) {
            if (report.AutoExport) {
                _this.blotter.ScheduleService.AddReportSchedule(report);
            }
        });
    };
    return ExportStrategy;
}(AdaptableStrategyBase_1.AdaptableStrategyBase));
exports.ExportStrategy = ExportStrategy;
