"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var AdaptableStrategyBase_1 = require("./AdaptableStrategyBase");
var StrategyConstants = require("../Utilities/Constants/StrategyConstants");
var ScreenPopups = require("../Utilities/Constants/ScreenPopups");
var ObjectFactory_1 = require("../Utilities/ObjectFactory");
var FlashingCellsRedux = require("../Redux/ActionsReducers/FlashingCellsRedux");
var Enums_1 = require("../PredefinedConfig/Common/Enums");
var FlashingCellsStrategy = /** @class */ (function (_super) {
    tslib_1.__extends(FlashingCellsStrategy, _super);
    function FlashingCellsStrategy(blotter) {
        var _this = _super.call(this, StrategyConstants.FlashingCellsStrategyId, blotter) || this;
        if (_this.shouldHandleDataSourceChanged()) {
            _this.blotter.DataService.OnDataSourceChanged().Subscribe(function (sender, eventText) {
                return _this.handleDataSourceChanged(eventText);
            });
        }
        return _this;
    }
    FlashingCellsStrategy.prototype.addPopupMenuItem = function () {
        this.createMenuItemShowPopup(StrategyConstants.FlashingCellsStrategyName, ScreenPopups.FlashingCellsPopup, StrategyConstants.FlashingCellGlyph);
    };
    FlashingCellsStrategy.prototype.addColumnMenuItem = function (column) {
        if (this.canCreateColumnMenuItem(column, this.blotter)) {
            if (column.DataType == Enums_1.DataType.Number) {
                if (this.blotter.api.calculatedColumnApi
                    .getAllCalculatedColumn()
                    .find(function (c) { return c.ColumnId == column.ColumnId; }) == null) {
                    var flashingCell = this.blotter.api.flashingCellApi
                        .getAllFlashingCell()
                        .find(function (x) { return x.ColumnId == column.ColumnId; });
                    if (flashingCell && flashingCell.IsLive) {
                        this.createColumnMenuItemReduxAction('Turn Flashing Cell Off', StrategyConstants.FlashingCellGlyph, FlashingCellsRedux.FlashingCellSelect(flashingCell));
                    }
                    else {
                        if (!flashingCell) {
                            var flashingCellState = this.blotter.api.flashingCellApi.getFlashingCellState();
                            flashingCell = ObjectFactory_1.ObjectFactory.CreateDefaultFlashingCell(column, flashingCellState.DefaultUpColor, flashingCellState.DefautDownColor, flashingCellState.DefaultDuration);
                        }
                        this.createColumnMenuItemReduxAction('Turn Flashing Cell On', StrategyConstants.FlashingCellGlyph, FlashingCellsRedux.FlashingCellSelect(flashingCell));
                    }
                }
            }
        }
    };
    FlashingCellsStrategy.prototype.handleDataSourceChanged = function (dataChangedInfo) {
        var flashingCell = this.blotter.api.flashingCellApi
            .getAllFlashingCell()
            .find(function (f) { return f.ColumnId == dataChangedInfo.ColumnId; });
        if (flashingCell && flashingCell.IsLive) {
            this.FlashCell(dataChangedInfo, flashingCell);
        }
    };
    return FlashingCellsStrategy;
}(AdaptableStrategyBase_1.AdaptableStrategyBase));
exports.FlashingCellsStrategy = FlashingCellsStrategy;
