"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var AdaptableStrategyBase_1 = require("./AdaptableStrategyBase");
var StrategyConstants = require("../Utilities/Constants/StrategyConstants");
var GlyphConstants = require("../Utilities/Constants/GlyphConstants");
var GridRedux = require("../Redux/ActionsReducers/GridRedux");
var GeneralConstants_1 = require("../Utilities/Constants/GeneralConstants");
// This is a special strategy that the user can never remove but which is useful to us
// We use it to manage internal state changes and menu items that are not directly strategy related
var HomeStrategy = /** @class */ (function (_super) {
    tslib_1.__extends(HomeStrategy, _super);
    function HomeStrategy(blotter) {
        var _this = _super.call(this, StrategyConstants.HomeStrategyId, blotter) || this;
        // this.blotter.onGridReloaded().Subscribe(() => this.handleGridReloaded());
        // useful for when grid reloads (e.g. at midnight);
        _this.blotter.on(GeneralConstants_1.GRID_RELOADED_EVENT, function () {
            _this.blotter.applyGridFiltering();
        });
        return _this;
    }
    HomeStrategy.prototype.addColumnMenuItem = function (column) {
        if (this.canCreateColumnMenuItem(column, this.blotter)) {
            this.createColumnMenuItemReduxAction('Hide Column', StrategyConstants.ColumnChooserGlyph, GridRedux.GridHideColumn(column.ColumnId));
        }
        if (this.canCreateColumnMenuItem(column, this.blotter, 'quickfilter')) {
            var isFilterActive = this.blotter.api.gridApi.getGridState().IsQuickFilterActive;
            this.createColumnMenuItemReduxAction(isFilterActive ? 'Hide Quick Filter Bar' : 'Show Quick Filter Bar', isFilterActive ? GlyphConstants.OK_GLYPH : GlyphConstants.REMOVE_GLYPH, isFilterActive ? GridRedux.QuickFilterBarHide() : GridRedux.QuickFilterBarShow());
        }
        if (this.blotter.isSelectable()) {
            if (this.canCreateColumnMenuItem(column, this.blotter)) {
                this.createColumnMenuItemReduxAction('Select Column', 'tab-unselected', GridRedux.GridSelectColumn(column.ColumnId));
            }
        }
    };
    return HomeStrategy;
}(AdaptableStrategyBase_1.AdaptableStrategyBase));
exports.HomeStrategy = HomeStrategy;
