"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var AdaptableStrategyBase_1 = require("./AdaptableStrategyBase");
var StrategyConstants = require("../Utilities/Constants/StrategyConstants");
var ScreenPopups = require("../Utilities/Constants/ScreenPopups");
var ArrayExtensions_1 = require("../Utilities/Extensions/ArrayExtensions");
var PercentBarStrategy = /** @class */ (function (_super) {
    tslib_1.__extends(PercentBarStrategy, _super);
    function PercentBarStrategy(blotter) {
        return _super.call(this, StrategyConstants.PercentBarStrategyId, blotter) || this;
    }
    PercentBarStrategy.prototype.addPopupMenuItem = function () {
        this.createMenuItemShowPopup(StrategyConstants.PercentBarStrategyName, ScreenPopups.PercentBarPopup, StrategyConstants.PercentBarGlyph);
    };
    PercentBarStrategy.prototype.addColumnMenuItem = function (column) {
        if (this.canCreateColumnMenuItem(column, this.blotter, 'numeric')) {
            var percentBarExists = ArrayExtensions_1.ArrayExtensions.ContainsItem(this.PercentBarState.PercentBars.map(function (f) { return f.ColumnId; }), column.ColumnId);
            var label = percentBarExists ? 'Edit ' : 'Create ';
            var popupParam = percentBarExists ? 'Edit|' : 'New|';
            this.createColumnMenuItemShowPopup(label + StrategyConstants.PercentBarStrategyName, ScreenPopups.PercentBarPopup, StrategyConstants.PercentBarGlyph, popupParam + column.ColumnId);
        }
    };
    PercentBarStrategy.prototype.InitState = function () {
        var _this = this;
        if (this.PercentBarState != this.GetPercentBarState()) {
            if (this.blotter.isInitialised) {
                // if we have made any changes then first delete them all
                this.PercentBarState.PercentBars.forEach(function (pb) {
                    _this.blotter.removePercentBar(pb);
                });
                this.GetPercentBarState().PercentBars.forEach(function (pb) {
                    _this.blotter.editPercentBar(pb);
                });
                this.blotter.redraw();
            }
            this.PercentBarState = this.GetPercentBarState();
        }
    };
    PercentBarStrategy.prototype.GetPercentBarState = function () {
        return this.blotter.api.percentBarApi.getPercentBarState();
    };
    return PercentBarStrategy;
}(AdaptableStrategyBase_1.AdaptableStrategyBase));
exports.PercentBarStrategy = PercentBarStrategy;
