"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var AdaptableStrategyBase_1 = require("./AdaptableStrategyBase");
var StrategyConstants = require("../Utilities/Constants/StrategyConstants");
var ScreenPopups = require("../Utilities/Constants/ScreenPopups");
var ShortcutRedux = require("../Redux/ActionsReducers/ShortcutRedux");
var Enums_1 = require("../PredefinedConfig/Common/Enums");
var ArrayExtensions_1 = require("../Utilities/Extensions/ArrayExtensions");
var ColumnHelper_1 = require("../Utilities/Helpers/ColumnHelper");
var Helper_1 = require("../Utilities/Helpers/Helper");
var ObjectFactory_1 = require("../Utilities/ObjectFactory");
var CellValidationHelper_1 = require("../Utilities/Helpers/CellValidationHelper");
var GeneralConstants_1 = require("../Utilities/Constants/GeneralConstants");
var ShortcutStrategy = /** @class */ (function (_super) {
    tslib_1.__extends(ShortcutStrategy, _super);
    function ShortcutStrategy(blotter) {
        var _this = _super.call(this, StrategyConstants.ShortcutStrategyId, blotter) || this;
        _this.blotter.on(GeneralConstants_1.KEY_DOWN_EVENT, function (keyEvent) {
            _this.handleKeyDown(keyEvent);
        });
        return _this;
    }
    ShortcutStrategy.prototype.addPopupMenuItem = function () {
        this.createMenuItemShowPopup(StrategyConstants.ShortcutStrategyName, ScreenPopups.ShortcutPopup, StrategyConstants.ShortcutGlyph);
    };
    ShortcutStrategy.prototype.handleKeyDown = function (keyEvent) {
        var shortcuts = this.blotter.api.shortcutApi.getAllShortcut();
        if (ArrayExtensions_1.ArrayExtensions.IsNullOrEmpty(shortcuts)) {
            return;
        }
        var activeCell = this.blotter.getActiveCell();
        if (!activeCell) {
            return;
        }
        var selectedColumn = ColumnHelper_1.ColumnHelper.getColumnFromId(activeCell.columnId, this.blotter.api.gridApi.getColumns());
        if (activeCell && !selectedColumn.ReadOnly) {
            var columnDataType = selectedColumn.DataType;
            var keyEventString_1 = Helper_1.Helper.getStringRepresentionFromKey(keyEvent);
            var activeShortcut = void 0;
            var valueToReplace = void 0;
            switch (columnDataType) {
                case Enums_1.DataType.Number: {
                    activeShortcut = shortcuts
                        .filter(function (s) { return s.ColumnType == Enums_1.DataType.Number; })
                        .find(function (x) { return keyEventString_1 == x.ShortcutKey.toLowerCase(); });
                    if (activeShortcut) {
                        var currentCellValue = void 0;
                        // Another complication is that the cell might have been edited or not, so we need to work out which method to use...
                        if (this.blotter.gridHasCurrentEditValue()) {
                            currentCellValue = this.blotter.getCurrentCellEditValue();
                            valueToReplace = this.CalculateShortcut(currentCellValue, activeShortcut.ShortcutResult, activeShortcut.ShortcutOperation);
                        }
                        else {
                            currentCellValue = activeCell.value;
                            valueToReplace = this.CalculateShortcut(currentCellValue, activeShortcut.ShortcutResult, activeShortcut.ShortcutOperation);
                        }
                    }
                    break;
                }
                case Enums_1.DataType.Date: {
                    activeShortcut = shortcuts
                        .filter(function (s) { return s.ColumnType == Enums_1.DataType.Date; })
                        .find(function (x) { return keyEventString_1 == x.ShortcutKey.toLowerCase(); });
                    if (activeShortcut) {
                        // Date we ONLY replace so dont need to worry about replacing values
                        if (activeShortcut.IsDynamic) {
                            valueToReplace = this.blotter.CalendarService.GetDynamicDate(activeShortcut.ShortcutResult);
                        }
                        else {
                            valueToReplace = new Date(activeShortcut.ShortcutResult);
                        }
                    }
                    break;
                }
            }
            if (activeShortcut) {
                var dataChangedEvent = {
                    OldValue: activeCell.value,
                    NewValue: valueToReplace,
                    ColumnId: activeCell.columnId,
                    IdentifierValue: activeCell.primaryKeyValue,
                    Record: null,
                };
                var validationRules = this.blotter.ValidationService.ValidateCellChanging(dataChangedEvent);
                var hasErrorPrevent = validationRules.length > 0 && validationRules[0].ActionMode == Enums_1.ActionMode.StopEdit;
                var hasErrorWarning = validationRules.length > 0 && validationRules[0].ActionMode == Enums_1.ActionMode.WarnUser;
                //   this.AuditFunctionAction("HandleKeyDown",                     "Key Pressed: " + keyEventString,                     { Shortcut: activeShortcut, PrimaryKey: activeCell.Id, ColumnId: activeCell.ColumnId })
                //We cancel the edit before doing anything so there is no issue when showing a popup or performing the shortcut
                this.blotter.cancelEdit();
                if (hasErrorPrevent) {
                    this.ShowErrorPreventMessage(validationRules[0]);
                }
                else {
                    if (hasErrorWarning) {
                        this.ShowWarningMessages(validationRules, activeShortcut, activeCell, keyEventString_1, valueToReplace);
                    }
                    else {
                        this.applyShortcut(activeShortcut, activeCell, valueToReplace, keyEventString_1);
                    }
                }
                // useful feature - prevents the main thing happening you want to on the keypress.
                keyEvent.preventDefault();
            }
        }
    };
    ShortcutStrategy.prototype.CalculateShortcut = function (first, second, shortcutOperation) {
        var firstNumber = Number(first);
        var secondNumber = Number(second);
        switch (shortcutOperation) {
            case Enums_1.MathOperation.Add:
                return firstNumber + secondNumber;
            case Enums_1.MathOperation.Subtract:
                return firstNumber - secondNumber;
            case Enums_1.MathOperation.Multiply:
                return firstNumber * secondNumber;
            case Enums_1.MathOperation.Divide:
                return firstNumber / secondNumber;
            case Enums_1.MathOperation.Replace:
                return secondNumber;
        }
    };
    ShortcutStrategy.prototype.applyShortcut = function (activeShortcut, activeCell, newValue, keyEventString) {
        this.blotter.api.gridApi.setGridCellBatch([
            {
                primaryKeyValue: activeCell.primaryKeyValue,
                columnId: activeCell.columnId,
                value: newValue,
            },
        ]);
        var functionAppliedDetails = {
            name: StrategyConstants.ShortcutStrategyId,
            action: ShortcutRedux.SHORTCUT_APPLY,
            info: 'KeyPressed:' + keyEventString,
            data: {
                Shortcut: activeShortcut,
                PrimaryKey: activeCell.primaryKeyValue,
                ColumnId: activeCell.columnId,
                NewValue: newValue,
            },
        };
        this.blotter.AuditLogService.addFunctionAppliedAuditLog(functionAppliedDetails);
    };
    ShortcutStrategy.prototype.ShowErrorPreventMessage = function (failedRule) {
        this.blotter.api.alertApi.showAlertError('Shortcut Failed', ObjectFactory_1.ObjectFactory.CreateCellValidationMessage(failedRule, this.blotter), true);
    };
    ShortcutStrategy.prototype.ShowWarningMessages = function (failedRules, shortcut, activeCell, keyEventString, newValue) {
        var _this = this;
        var warningMessage = '';
        failedRules.forEach(function (f) {
            warningMessage =
                warningMessage + ObjectFactory_1.ObjectFactory.CreateCellValidationMessage(f, _this.blotter) + '\n';
        });
        var confirmAction = ShortcutRedux.ShortcutApply(shortcut, activeCell, keyEventString, newValue);
        var cancelAction = null;
        var confirmation = CellValidationHelper_1.CellValidationHelper.createCellValidationUIConfirmation(confirmAction, cancelAction, warningMessage);
        this.blotter.api.internalApi.showPopupConfirmation(confirmation);
    };
    return ShortcutStrategy;
}(AdaptableStrategyBase_1.AdaptableStrategyBase));
exports.ShortcutStrategy = ShortcutStrategy;
