"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var AdaptableStrategyBase_1 = require("./AdaptableStrategyBase");
var StrategyConstants = require("../Utilities/Constants/StrategyConstants");
var ScreenPopups = require("../Utilities/Constants/ScreenPopups");
var Enums_1 = require("../PredefinedConfig/Common/Enums");
var PreviewHelper_1 = require("../Utilities/Helpers/PreviewHelper");
var SmartEditRedux_1 = require("../Redux/ActionsReducers/SmartEditRedux");
var ArrayExtensions_1 = require("../Utilities/Extensions/ArrayExtensions");
var SmartEditStrategy = /** @class */ (function (_super) {
    tslib_1.__extends(SmartEditStrategy, _super);
    function SmartEditStrategy(blotter) {
        return _super.call(this, StrategyConstants.SmartEditStrategyId, blotter) || this;
    }
    SmartEditStrategy.prototype.addPopupMenuItem = function () {
        this.createMenuItemShowPopup(StrategyConstants.SmartEditStrategyName, ScreenPopups.SmartEditPopup, StrategyConstants.SmartEditGlyph);
    };
    SmartEditStrategy.prototype.ApplySmartEdit = function (newValues) {
        if (this.blotter.AuditLogService.isAuditFunctionEventsEnabled) {
            // logging audit log function here as there is no obvious Action to listen to in the Store - not great but not end of the world...
            var functionAppliedDetails = {
                name: StrategyConstants.SmartEditStrategyId,
                action: SmartEditRedux_1.SMARTEDIT_APPLY,
                info: 'Smart Edit Applied',
                data: newValues,
            };
            this.blotter.AuditLogService.addFunctionAppliedAuditLog(functionAppliedDetails);
        }
        this.blotter.api.gridApi.setGridCellBatch(newValues);
    };
    SmartEditStrategy.prototype.CheckCorrectCellSelection = function () {
        var selectedCellInfo = this.blotter.api.gridApi.getSelectedCellInfo();
        if (selectedCellInfo == null || ArrayExtensions_1.default.IsNullOrEmpty(selectedCellInfo.Columns)) {
            return {
                Alert: {
                    Header: 'Smart Edit Error',
                    Msg: 'No cells are selected.\nPlease select some cells.',
                    MessageType: Enums_1.MessageType.Error,
                    ShowAsPopup: true,
                },
            };
        }
        if (ArrayExtensions_1.default.NotCorrectLength(selectedCellInfo.Columns, 1)) {
            return {
                Alert: {
                    Header: 'Smart Edit Error',
                    Msg: 'Smart Edit only supports single column edit.\nPlease adjust cell selection.',
                    MessageType: Enums_1.MessageType.Error,
                    ShowAsPopup: true,
                },
            };
        }
        if (selectedCellInfo.Columns[0].DataType != Enums_1.DataType.Number) {
            return {
                Alert: {
                    Header: 'Smart Edit Error',
                    Msg: 'Smart Edit only supports editing of numeric columns.\nPlease adjust the cell selection.',
                    MessageType: Enums_1.MessageType.Error,
                    ShowAsPopup: true,
                },
            };
        }
        if (selectedCellInfo.Columns[0].ReadOnly) {
            return {
                Alert: {
                    Header: 'Smart Edit Error',
                    Msg: 'Smart Edit is not permitted on readonly columns.\nPlease adjust the cell selection.',
                    MessageType: Enums_1.MessageType.Error,
                    ShowAsPopup: true,
                },
            };
        }
        return { ActionReturn: true };
    };
    SmartEditStrategy.prototype.BuildPreviewValues = function (smartEditValue, smartEditOperation) {
        var _this = this;
        var selectedCellInfo = this.blotter.api.gridApi.getSelectedCellInfo();
        var previewResults = [];
        var columnId = '';
        if (ArrayExtensions_1.default.IsNotNullOrEmpty(selectedCellInfo.Columns)) {
            columnId = selectedCellInfo.Columns[0].ColumnId;
            selectedCellInfo.GridCells.forEach(function (selectedCell) {
                var newValue;
                switch (smartEditOperation) {
                    case Enums_1.MathOperation.Add:
                        newValue = Number(selectedCell.value) + smartEditValue;
                        break;
                    case Enums_1.MathOperation.Subtract:
                        newValue = Number(selectedCell.value) - smartEditValue;
                        break;
                    case Enums_1.MathOperation.Multiply:
                        newValue = Number(selectedCell.value) * smartEditValue;
                        break;
                    case Enums_1.MathOperation.Divide:
                        newValue = Number(selectedCell.value) / smartEditValue;
                        break;
                }
                //avoid the 0.0000000000x
                newValue = parseFloat(newValue.toFixed(12));
                var dataChangedEvent = {
                    OldValue: Number(selectedCell.value),
                    NewValue: newValue,
                    ColumnId: selectedCell.columnId,
                    IdentifierValue: selectedCell.primaryKeyValue,
                    Record: null,
                };
                var validationRules = _this.blotter.ValidationService.ValidateCellChanging(dataChangedEvent);
                var previewResult = {
                    Id: selectedCell.primaryKeyValue,
                    InitialValue: Number(selectedCell.value),
                    ComputedValue: newValue,
                    ValidationRules: validationRules,
                };
                previewResults.push(previewResult);
            });
        }
        return {
            ColumnId: columnId,
            PreviewResults: previewResults,
            PreviewValidationSummary: PreviewHelper_1.PreviewHelper.GetPreviewValidationSummary(previewResults),
        };
    };
    return SmartEditStrategy;
}(AdaptableStrategyBase_1.AdaptableStrategyBase));
exports.SmartEditStrategy = SmartEditStrategy;
