"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var lodash_1 = require("lodash");
var DefaultAdaptableBlotterOptions_1 = require("../Defaults/DefaultAdaptableBlotterOptions");
var ColumnHelper_1 = require("./ColumnHelper");
var LoggingHelper_1 = require("./LoggingHelper");
var StringExtensions_1 = require("../Extensions/StringExtensions");
var Uuid_1 = require("../../PredefinedConfig/Uuid");
function assignBlotterOptions(blotterOptions) {
    var returnBlotterOptions = Object.assign({}, DefaultAdaptableBlotterOptions_1.DefaultAdaptableBlotterOptions, blotterOptions);
    returnBlotterOptions.auditOptions = Object.assign({}, DefaultAdaptableBlotterOptions_1.DefaultAdaptableBlotterOptions.auditOptions, blotterOptions.auditOptions);
    returnBlotterOptions.configServerOptions = Object.assign({}, DefaultAdaptableBlotterOptions_1.DefaultAdaptableBlotterOptions.configServerOptions, blotterOptions.configServerOptions);
    returnBlotterOptions.layoutOptions = Object.assign({}, DefaultAdaptableBlotterOptions_1.DefaultAdaptableBlotterOptions.layoutOptions, blotterOptions.layoutOptions);
    returnBlotterOptions.filterOptions = Object.assign({}, DefaultAdaptableBlotterOptions_1.DefaultAdaptableBlotterOptions.filterOptions, blotterOptions.filterOptions);
    returnBlotterOptions.queryOptions = Object.assign({}, DefaultAdaptableBlotterOptions_1.DefaultAdaptableBlotterOptions.queryOptions, blotterOptions.queryOptions);
    returnBlotterOptions.containerOptions = Object.assign({}, DefaultAdaptableBlotterOptions_1.DefaultAdaptableBlotterOptions.containerOptions, blotterOptions.containerOptions);
    returnBlotterOptions.generalOptions = Object.assign({}, DefaultAdaptableBlotterOptions_1.DefaultAdaptableBlotterOptions.generalOptions, blotterOptions.generalOptions);
    returnBlotterOptions.chartOptions = Object.assign({}, DefaultAdaptableBlotterOptions_1.DefaultAdaptableBlotterOptions.chartOptions, blotterOptions.chartOptions);
    var predefinedConfig = returnBlotterOptions.predefinedConfig;
    if (predefinedConfig) {
        // this customizer function is called by lodash.cloneDeepWith
        // to determine how to clone each property
        var customizer = function (value) {
            // so whenever we clone a plain object,
            // we add a Uuid property
            if (lodash_1.isPlainObject(value) && value != predefinedConfig) {
                value.Uuid = Uuid_1.createUuid();
            }
        };
        returnBlotterOptions.predefinedConfig = lodash_1.cloneDeepWith(predefinedConfig, customizer);
    }
    return returnBlotterOptions;
}
exports.assignBlotterOptions = assignBlotterOptions;
function isValidPrimaryKey(blotter, columns) {
    var pkColumn = ColumnHelper_1.ColumnHelper.getColumnFromId(blotter.blotterOptions.primaryKey, columns);
    if (pkColumn == null) {
        var errorMessage = "The PK Column '" + blotter.blotterOptions.primaryKey + "' does not exist.  This will affect many functions in the Adaptable Blotter.";
        if (blotter.blotterOptions.generalOptions.showMissingPrimaryKeyWarning == true) {
            // show an alert if that is the option
            blotter.api.alertApi.showAlertError('No Primary Key', errorMessage, true);
        }
        else {
            // otherwise just log it
            LoggingHelper_1.LoggingHelper.LogAdaptableBlotterError(errorMessage);
        }
        return false;
    }
    return true;
}
exports.isValidPrimaryKey = isValidPrimaryKey;
function isConfigServerEnabled(blotterOptions) {
    return (blotterOptions.configServerOptions != null &&
        blotterOptions.configServerOptions.enableConfigServer != null &&
        blotterOptions.configServerOptions.enableConfigServer == true &&
        StringExtensions_1.StringExtensions.IsNotNullOrEmpty(blotterOptions.configServerOptions.configServerUrl));
}
exports.isConfigServerEnabled = isConfigServerEnabled;
function BlotterObjectExistsInState(array, itemToCheck) {
    if (array == null) {
        return false;
    }
    return array.findIndex(function (abObject) { return abObject.Uuid == itemToCheck.Uuid; }) > -1;
}
exports.BlotterObjectExistsInState = BlotterObjectExistsInState;
function isDemoSite() {
    return window.location.hostname == 'demo.adaptableblotter.com';
}
exports.isDemoSite = isDemoSite;
// perform any checks that are necessary here
// for now just blotterId
function CheckBlotterOptions(blotterOptions) {
    if (blotterOptions.blotterId) {
        if (blotterOptions.blotterId.includes('.')) {
            LoggingHelper_1.LoggingHelper.LogWarning("The 'blotterId' property in BlotterOptions should not include a '.'.  We strongly recommend that you remove this.");
        }
    }
}
exports.CheckBlotterOptions = CheckBlotterOptions;
exports.BlotterHelper = {
    isDemoSite: isDemoSite,
    assignBlotterOptions: assignBlotterOptions,
    isValidPrimaryKey: isValidPrimaryKey,
    isConfigServerEnabled: isConfigServerEnabled,
    BlotterObjectExistsInState: BlotterObjectExistsInState,
    CheckBlotterOptions: CheckBlotterOptions,
};
exports.default = exports.BlotterHelper;
