"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var ColumnHelper_1 = require("./ColumnHelper");
function getColumnListFromExpression(expression) {
    var columnList = [];
    var regEx = /\b(?:Col\(")([a-zA-Z0-9 ]+)(?:"\))/g;
    var match = regEx.exec(expression);
    while (match !== null) {
        columnList.push(match[1]);
        match = regEx.exec(expression);
    }
    return columnList;
}
exports.getColumnListFromExpression = getColumnListFromExpression;
function cleanExpressionColumnNames(expression, columns) {
    var newExpression = expression;
    var columnNameList = [];
    var regEx = /\b(?:Col\(")([a-zA-Z0-9 ]+)(?:"\))/g;
    var match = regEx.exec(expression);
    while (match !== null) {
        var columnId = match[1];
        // check if its a column name
        var col = ColumnHelper_1.ColumnHelper.getColumnFromId(columnId, columns, false);
        if (!col) {
            // no column so lets see if they are using FriendlyName
            col = ColumnHelper_1.ColumnHelper.getColumnFromFriendlyName(columnId, columns, false);
            if (col) {
                columnNameList.push(columnId);
            }
        }
        match = regEx.exec(expression);
    }
    columnNameList.forEach(function (c) {
        var stringToReplace = 'Col("' + c + '")';
        var columnId = ColumnHelper_1.ColumnHelper.getColumnIdFromFriendlyName(c, columns);
        var newString = 'Col("' + columnId + '")';
        newExpression = newExpression.replace(stringToReplace, newString);
    });
    return newExpression;
}
exports.cleanExpressionColumnNames = cleanExpressionColumnNames;
function getExpressionString(expression, columns) {
    var cleanExpression = cleanExpressionColumnNames(expression, columns);
    var columnIds = getColumnListFromExpression(cleanExpression);
    columnIds.forEach(function (c) {
        var stringToReplace = 'Col("' + c + '")';
        var columnFriendName = ColumnHelper_1.ColumnHelper.getFriendlyNameFromColumnId(c, columns);
        var newString = '[' + columnFriendName + ']';
        cleanExpression = cleanExpression.replace(stringToReplace, newString);
    });
    return cleanExpression;
}
exports.getExpressionString = getExpressionString;
exports.CalculatedColumnHelper = {
    getColumnListFromExpression: getColumnListFromExpression,
    cleanExpressionColumnNames: cleanExpressionColumnNames,
    getExpressionString: getExpressionString,
};
exports.default = exports.CalculatedColumnHelper;
