"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var ExpressionHelper_1 = require("./ExpressionHelper");
var ColumnHelper_1 = require("./ColumnHelper");
var StringExtensions_1 = require("../Extensions/StringExtensions");
var Enums_1 = require("../../PredefinedConfig/Common/Enums");
function createCellValidationDescription(cellValidationRule, columns) {
    if (cellValidationRule.Range.Operator == Enums_1.LeafExpressionOperator.PrimaryKeyDuplicate) {
        return 'Primary Key column cannot contain duplicate values';
    }
    var operator = cellValidationRule.Range
        .Operator;
    var valueDescription = ExpressionHelper_1.ExpressionHelper.OperatorToLongFriendlyString(operator, ColumnHelper_1.ColumnHelper.getColumnDataTypeFromColumnId(cellValidationRule.ColumnId, columns));
    if (!ExpressionHelper_1.ExpressionHelper.OperatorRequiresValue(operator)) {
        return valueDescription;
    }
    var dataType = ColumnHelper_1.ColumnHelper.getColumnDataTypeFromColumnId(cellValidationRule.ColumnId, columns);
    var operand1Text = dataType == Enums_1.DataType.Boolean || dataType == Enums_1.DataType.Number
        ? cellValidationRule.Range.Operand1
        : "'" + cellValidationRule.Range.Operand1 + "'";
    valueDescription = valueDescription + operand1Text;
    if (cellValidationRule.Range.Operator == Enums_1.LeafExpressionOperator.PercentChange) {
        valueDescription = valueDescription + '%';
    }
    if (StringExtensions_1.StringExtensions.IsNotNullOrEmpty(cellValidationRule.Range.Operand2)) {
        var operand2Text = dataType == Enums_1.DataType.Number
            ? ' and ' + cellValidationRule.Range.Operand2
            : " and '" + cellValidationRule.Range.Operand2 + "'";
        valueDescription = valueDescription + operand2Text;
    }
    return valueDescription;
}
exports.createCellValidationDescription = createCellValidationDescription;
function createCellValidationUIConfirmation(confirmAction, cancelAction, warningMessage) {
    if (warningMessage === void 0) { warningMessage = 'Do you want to continue?'; }
    return {
        CancelButtonText: 'Cancel Edit',
        Header: 'Cell Validation Failed',
        Msg: warningMessage,
        ConfirmButtonText: 'Bypass Rule',
        CancelAction: cancelAction,
        ConfirmAction: confirmAction,
        ShowInputBox: true,
        MessageType: Enums_1.MessageType.Warning,
    };
}
exports.createCellValidationUIConfirmation = createCellValidationUIConfirmation;
exports.CellValidationHelper = {
    createCellValidationDescription: createCellValidationDescription,
    createCellValidationUIConfirmation: createCellValidationUIConfirmation,
};
exports.default = exports.CellValidationHelper;
