"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var Helper_1 = require("./Helper");
var ColumnHelper_1 = require("./ColumnHelper");
var ArrayExtensions_1 = require("../Extensions/ArrayExtensions");
var Enums_1 = require("../../PredefinedConfig/Common/Enums");
var ExpressionHelper_1 = require("./ExpressionHelper");
var glue42office; // =   Glue4Office();
var excelAPIEntryPoint;
function init() {
    return tslib_1.__awaiter(this, void 0, void 0, function () {
        var error_1;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    _a.trys.push([0, 2, , 3]);
                    return [4 /*yield*/, Glue4Office()];
                case 1:
                    glue42office = _a.sent();
                    excelAPIEntryPoint = glue42office.excel;
                    return [3 /*break*/, 3];
                case 2:
                    error_1 = _a.sent();
                    console.log(error_1);
                    return [3 /*break*/, 3];
                case 3: return [2 /*return*/];
            }
        });
    });
}
exports.init = init;
function isRunningGlue42() {
    /**
     * Checks if the glue4office.js file is referenced and if we are running inside of a Glue42 container.
     * v2 will support browser.
     */
    return false; // typeof window !== "undefined" && "glue42gd" in window && "Glue4Office" in window;
}
exports.isRunningGlue42 = isRunningGlue42;
function exportData(data, gridColumns, blotter) {
    return tslib_1.__awaiter(this, void 0, void 0, function () {
        var exportColumns, exportData, sentRows, sheetData, sheet, error_2;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    exportColumns = data[0];
                    exportData = createData(data, exportColumns);
                    sentRows = Helper_1.Helper.cloneObject(exportData);
                    sheetData = {
                        columnConfig: createColumns(data),
                        data: exportData,
                        options: {
                            workbook: 'Glue42 Excel Integration Demo',
                            worksheet: 'Data Sheet',
                        },
                    };
                    _a.label = 1;
                case 1:
                    _a.trys.push([1, 3, , 4]);
                    console.log(sheetData);
                    return [4 /*yield*/, excelAPIEntryPoint.openSheet(sheetData)];
                case 2:
                    sheet = _a.sent();
                    sheet.onChanged(function (data, errorCallback, doneCallback) {
                        var primaryKeyColumnFriendlyName = ColumnHelper_1.ColumnHelper.getFriendlyNameFromColumnId(blotter.blotterOptions.primaryKey, gridColumns);
                        var cellInfos = [];
                        var errors = [];
                        for (var rowIndex = 0; rowIndex < data.length; rowIndex++) {
                            var returnedRow = data[rowIndex];
                            var sentRow = sentRows[rowIndex];
                            for (var columnIndex = 0; columnIndex < exportColumns.length; columnIndex++) {
                                var col = exportColumns[columnIndex];
                                var returnedValue = returnedRow[col];
                                var originalValue = sentRow[col];
                                if (returnedValue != originalValue) {
                                    var column = ColumnHelper_1.ColumnHelper.getColumnFromFriendlyName(col, gridColumns);
                                    var primaryKeyValue = returnedRow[primaryKeyColumnFriendlyName];
                                    if (isValidEdit(column, originalValue, returnedValue, primaryKeyValue, rowIndex, columnIndex, errors, gridColumns, blotter)) {
                                        var cellInfo = {
                                            primaryKeyValue: primaryKeyValue,
                                            columnId: column.ColumnId,
                                            value: returnedValue,
                                        };
                                        cellInfos.push(cellInfo);
                                    }
                                    sentRows[rowIndex][col] = returnedValue; // we always set (even if invalid) so dont update after future edits
                                }
                            }
                        }
                        blotter.setValueBatch(cellInfos);
                        ArrayExtensions_1.ArrayExtensions.IsNullOrEmpty(errors) ? doneCallback() : errorCallback(errors);
                    });
                    return [3 /*break*/, 4];
                case 3:
                    error_2 = _a.sent();
                    console.log(error_2);
                    return [3 /*break*/, 4];
                case 4: return [2 /*return*/];
            }
        });
    });
}
exports.exportData = exportData;
function isValidEdit(column, originalValue, returnedValue, primaryKeyValue, rowIndex, columnIndex, errors, columns, blotter) {
    if (column.ReadOnly) {
        errors.push(addValidationError(rowIndex + 1, columnIndex + 1, column.FriendlyName + ' is read only'));
        return false;
    }
    // check for type -- do properly in due course, but for now just check numbers...
    if (column.DataType == Enums_1.DataType.Number) {
        if (isNaN(Number(returnedValue))) {
            errors.push(addValidationError(rowIndex + 1, columnIndex + 1, column.FriendlyName + ' is numeric'));
            return false;
        }
    }
    var dataChangedInfo = {
        OldValue: originalValue,
        NewValue: returnedValue,
        ColumnId: column.ColumnId,
        IdentifierValue: primaryKeyValue,
        Record: null,
    };
    // check for any validation issues
    var cellValidationRules = blotter.ValidationService.ValidateCellChanging(dataChangedInfo);
    if (ArrayExtensions_1.ArrayExtensions.IsNotNullOrEmpty(cellValidationRules)) {
        cellValidationRules.forEach(function (cv) {
            var failedvalidationMessage = 'Validation failed for ' +
                column.FriendlyName +
                ': ' +
                ExpressionHelper_1.ExpressionHelper.ConvertRangeToString(cv.Range, columns);
            if (cv.ActionMode == Enums_1.ActionMode.StopEdit) {
                errors.push(addValidationError(rowIndex + 1, columnIndex + 1, failedvalidationMessage));
            }
            else {
                errors.push(addValidationWarning(rowIndex + 1, columnIndex + 1, failedvalidationMessage));
            }
        });
        return false;
    }
    return true;
}
function addValidationWarning(rowIndex, columnIndex, errorDescription) {
    return {
        row: rowIndex,
        column: columnIndex,
        description: errorDescription,
        foregroundColor: 'orange',
        backgroundColor: 'white',
    };
}
function addValidationError(rowIndex, columnIndex, errorDescription) {
    return {
        row: rowIndex,
        column: columnIndex,
        description: errorDescription,
        foregroundColor: 'red',
        backgroundColor: 'white',
    };
}
function createColumns(data) {
    var firstRow = data[0];
    var headers = [];
    firstRow.forEach(function (element) {
        headers.push({
            header: element.replace(' ', ''),
            fieldName: element,
        });
    });
    return headers;
}
exports.createColumns = createColumns;
function createData(data, headers) {
    var returnArray = [];
    for (var i = 1; i < data.length; i++) {
        var row = data[i];
        var returnItem = {};
        for (var j = 0; j < headers.length; j++) {
            returnItem[headers[j]] = row[j];
        }
        returnArray.push(returnItem);
    }
    return returnArray;
}
exports.createData = createData;
exports.Glue42Helper = {
    init: init,
    isRunningGlue42: isRunningGlue42,
    exportData: exportData,
    createColumns: createColumns,
    createData: createData,
};
exports.default = exports.Glue42Helper;
