"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var GeneralConstants = require("../../Utilities/Constants/GeneralConstants");
var ColumnHelper_1 = require("./ColumnHelper");
var Enums_1 = require("../../PredefinedConfig/Common/Enums");
function getLayoutDescription(layout, columns) {
    var returnString = '';
    returnString += layout.Columns.length + ' Columns; ';
    returnString += '\n';
    returnString += ' Sort: ' + getColumnSort(layout.ColumnSorts, columns);
    return returnString;
}
exports.getLayoutDescription = getLayoutDescription;
function getColumnSort(columnSorts, columns) {
    if (columnSorts.length == 0) {
        return 'None';
    }
    var returnString = '';
    columnSorts.forEach(function (gs) {
        returnString +=
            ColumnHelper_1.ColumnHelper.getFriendlyNameFromColumnId(gs.Column, columns) + getSortOrder(gs.SortOrder);
    });
    return returnString;
}
exports.getColumnSort = getColumnSort;
function getSortOrder(sortOrder) {
    return sortOrder == Enums_1.SortOrder.Ascending ? ' [asc] ' : ' [desc] ';
}
exports.getSortOrder = getSortOrder;
function autoSaveLayout(blotter) {
    var layoutState = blotter.api.layoutApi.getLayoutState();
    if (blotter.isInitialised && layoutState.CurrentLayout != GeneralConstants.DEFAULT_LAYOUT) {
        if (blotter.blotterOptions.layoutOptions != null &&
            blotter.blotterOptions.layoutOptions.autoSaveLayouts != null &&
            blotter.blotterOptions.layoutOptions.autoSaveLayouts) {
            var layout = blotter.api.layoutApi.getCurrentLayout();
            if (layout != null) {
                var gridState = blotter.api.gridApi.getGridState();
                var visibleColumns = gridState.Columns.filter(function (c) { return c.Visible; });
                var gridVendorState = blotter.getVendorGridState(visibleColumns.map(function (vc) { return vc.ColumnId; }), false);
                var layoutToSave = {
                    Uuid: layout.Uuid,
                    Name: layoutState.CurrentLayout,
                    Columns: visibleColumns ? visibleColumns.map(function (x) { return x.ColumnId; }) : [],
                    ColumnSorts: gridState.ColumnSorts,
                    VendorGridInfo: gridVendorState,
                };
                blotter.api.layoutApi.saveLayout(layoutToSave);
            }
        }
        blotter.api.eventApi._onColumnStateChanged.Dispatch(blotter, {
            currentLayout: layoutState.CurrentLayout,
        });
    }
}
exports.autoSaveLayout = autoSaveLayout;
exports.LayoutHelper = {
    getLayoutDescription: getLayoutDescription,
    getColumnSort: getColumnSort,
    getSortOrder: getSortOrder,
    autoSaveLayout: autoSaveLayout,
};
exports.default = exports.LayoutHelper;
