"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var ExpressionHelper_1 = require("./ExpressionHelper");
var Enums_1 = require("../../PredefinedConfig/Common/Enums");
var Uuid_1 = require("../../PredefinedConfig/Uuid");
var ColumnHelper_1 = require("./ColumnHelper");
var ArrayExtensions_1 = require("../Extensions/ArrayExtensions");
var OpenfinHelper_1 = require("./OpenfinHelper");
var iPushPullHelper_1 = require("./iPushPullHelper");
var Glue42Helper_1 = require("./Glue42Helper");
exports.ALL_DATA_REPORT = 'All Data';
exports.VISIBLE_DATA_REPORT = 'Visible Data';
exports.SELECTED_CELLS_REPORT = 'Selected Cells';
exports.SELECTED_ROWS_REPORT = 'Selected Rows';
function IsSystemReport(Report) {
    return (Report == null ||
        Report.Name == exports.ALL_DATA_REPORT ||
        Report.Name == exports.VISIBLE_DATA_REPORT ||
        Report.Name == exports.SELECTED_CELLS_REPORT ||
        Report.Name == exports.SELECTED_ROWS_REPORT);
}
exports.IsSystemReport = IsSystemReport;
function GetReportColumnsDescription(report, cols) {
    switch (report.ReportColumnScope) {
        case Enums_1.ReportColumnScope.AllColumns:
            return '[All Columns]';
        case Enums_1.ReportColumnScope.VisibleColumns:
            return '[Visible Columns]';
        case Enums_1.ReportColumnScope.SelectedColumns:
            return '[Selected Columns]';
        case Enums_1.ReportColumnScope.BespokeColumns:
            return ColumnHelper_1.default.getFriendlyNamesFromColumnIds(report.ColumnIds, cols).join(', ');
    }
}
exports.GetReportColumnsDescription = GetReportColumnsDescription;
function GetReportExpressionDescription(Report, cols) {
    if (IsSystemReport(Report)) {
        if (Report.Name == exports.ALL_DATA_REPORT) {
            return '[All Blotter Data]';
        }
        else if (Report.Name == exports.VISIBLE_DATA_REPORT) {
            return '[All Visible Data]';
        }
        else if (Report.Name == exports.SELECTED_CELLS_REPORT) {
            return '[Selected Cells Data]';
        }
        else if (Report.Name == exports.SELECTED_ROWS_REPORT) {
            return '[Selected Rows Data]';
        }
    }
    else {
        switch (Report.ReportRowScope) {
            case Enums_1.ReportRowScope.AllRows:
                return '[All Rows]';
            case Enums_1.ReportRowScope.VisibleRows:
                return '[Visible Rows]';
            case Enums_1.ReportRowScope.SelectedRows:
                return '[Selected Rows]';
            case Enums_1.ReportRowScope.ExpressionRows:
                return ExpressionHelper_1.ExpressionHelper.ConvertExpressionToString(Report.Expression, cols);
        }
    }
}
exports.GetReportExpressionDescription = GetReportExpressionDescription;
function IsReportDestinationActive(exportDestination) {
    switch (exportDestination) {
        case Enums_1.ExportDestination.CSV:
        case Enums_1.ExportDestination.Clipboard:
            return true;
        case Enums_1.ExportDestination.OpenfinExcel:
            return OpenfinHelper_1.default.isRunningInOpenfin() && OpenfinHelper_1.default.isExcelOpenfinLoaded();
        case Enums_1.ExportDestination.iPushPull:
            return iPushPullHelper_1.default.isIPushPullLoaded();
        case Enums_1.ExportDestination.Glue42:
            return Glue42Helper_1.default.isRunningGlue42();
    }
    return false;
}
exports.IsReportDestinationActive = IsReportDestinationActive;
function ConvertReportToArray(blotter, Report) {
    var ReportColumns = [];
    var gridColumns = blotter.api.gridApi.getColumns();
    // first get the cols depending on the Column Scope
    switch (Report.ReportColumnScope) {
        case Enums_1.ReportColumnScope.AllColumns:
            ReportColumns = gridColumns;
            break;
        case Enums_1.ReportColumnScope.VisibleColumns:
            ReportColumns = gridColumns.filter(function (c) { return c.Visible; });
            break;
        case Enums_1.ReportColumnScope.SelectedColumns:
            var selectedCellInfo = blotter.api.gridApi.getSelectedCellInfo();
            if (ArrayExtensions_1.default.IsNullOrEmpty(selectedCellInfo.Columns)) {
                // some way of saying we cannot export anything
                return {
                    ActionReturn: dataToExport,
                    Alert: {
                        Header: 'Export Error',
                        Msg: 'No cells are selected',
                        MessageType: Enums_1.MessageType.Error,
                        ShowAsPopup: true,
                    },
                };
            }
            // otherwise get columns
            ReportColumns = selectedCellInfo.Columns;
            break;
        case Enums_1.ReportColumnScope.BespokeColumns:
            ReportColumns = Report.ColumnIds.map(function (c) { return gridColumns.find(function (col) { return col.ColumnId == c; }); });
            break;
    }
    // populate the first row
    var dataToExport = [];
    dataToExport[0] = ReportColumns.map(function (c) { return c.FriendlyName; });
    // now populate the rest of the rows
    switch (Report.ReportRowScope) {
        case Enums_1.ReportRowScope.AllRows:
            blotter.forAllRecordsDo(function (row) {
                var newRow = getRowValues(row, ReportColumns, blotter);
                dataToExport.push(newRow);
            });
            break;
        case Enums_1.ReportRowScope.VisibleRows:
            blotter.forAllVisibleRecordsDo(function (row) {
                var newRow = getRowValues(row, ReportColumns, blotter);
                dataToExport.push(newRow);
            });
            break;
        case Enums_1.ReportRowScope.ExpressionRows:
            var expressionToCheck_1 = Report.Expression;
            blotter.forAllRecordsDo(function (row) {
                if (ExpressionHelper_1.ExpressionHelper.checkForExpressionFromRecord(expressionToCheck_1, row, ReportColumns, blotter)) {
                    var newRow = getRowValues(row, ReportColumns, blotter);
                    dataToExport.push(newRow);
                }
            });
            break;
        case Enums_1.ReportRowScope.SelectedCells:
            var selectedCellInfo = blotter.api.gridApi.getSelectedCellInfo();
            var Columns = selectedCellInfo.Columns, GridCells = selectedCellInfo.GridCells;
            var colCount = Columns.length;
            var rowCount = GridCells.length / colCount;
            for (var i = 0; i < rowCount; i++) {
                var newRow = [];
                for (var j = 0; j < colCount; j++) {
                    var index = i + j * rowCount;
                    newRow.push(String(GridCells[index].value));
                }
                dataToExport.push(newRow);
            }
            break;
        case Enums_1.ReportRowScope.SelectedRows:
            var selectedRowInfo = blotter.api.gridApi.getSelectedRowInfo();
            if (selectedRowInfo != null && ArrayExtensions_1.default.IsNotNullOrEmpty(selectedRowInfo.GridRows)) {
                var columnIds_1 = ReportColumns.map(function (rc) { return rc.ColumnId; });
                selectedRowInfo.GridRows.filter(function (gr) { return gr.rowInfo.isGroup == false; }).forEach(function (gridRow) {
                    var rowData = gridRow.rowData;
                    var newRow = [];
                    columnIds_1.forEach(function (colId) {
                        var cellValue = rowData[colId];
                        newRow.push(cellValue ? String(cellValue) : '');
                    });
                    dataToExport.push(newRow);
                });
            }
            break;
    }
    return { ActionReturn: dataToExport };
}
exports.ConvertReportToArray = ConvertReportToArray;
function getRowValues(row, ReportColumns, blotter) {
    var newRow = [];
    ReportColumns.forEach(function (col) {
        var columnValue = blotter.getDisplayValueFromRecord(row, col.ColumnId);
        newRow.push(columnValue);
    });
    return newRow;
}
function CreateSystemReports() {
    var _systemReports = [];
    _systemReports.push({
        Uuid: Uuid_1.createUuid(),
        Name: exports.ALL_DATA_REPORT,
        ReportColumnScope: Enums_1.ReportColumnScope.AllColumns,
        ReportRowScope: Enums_1.ReportRowScope.AllRows,
        ColumnIds: [],
        Expression: ExpressionHelper_1.ExpressionHelper.CreateEmptyExpression(),
    });
    _systemReports.push({
        Uuid: Uuid_1.createUuid(),
        Name: exports.VISIBLE_DATA_REPORT,
        ReportColumnScope: Enums_1.ReportColumnScope.VisibleColumns,
        ReportRowScope: Enums_1.ReportRowScope.VisibleRows,
        ColumnIds: [],
        Expression: ExpressionHelper_1.ExpressionHelper.CreateEmptyExpression(),
    });
    _systemReports.push({
        Uuid: Uuid_1.createUuid(),
        Name: exports.SELECTED_CELLS_REPORT,
        ReportColumnScope: Enums_1.ReportColumnScope.SelectedColumns,
        ReportRowScope: Enums_1.ReportRowScope.SelectedCells,
        ColumnIds: [],
        Expression: ExpressionHelper_1.ExpressionHelper.CreateEmptyExpression(),
    });
    _systemReports.push({
        Uuid: Uuid_1.createUuid(),
        Name: exports.SELECTED_ROWS_REPORT,
        ReportColumnScope: Enums_1.ReportColumnScope.VisibleColumns,
        ReportRowScope: Enums_1.ReportRowScope.SelectedRows,
        ColumnIds: [],
        Expression: ExpressionHelper_1.ExpressionHelper.CreateEmptyExpression(),
    });
    return _systemReports;
}
exports.CreateSystemReports = CreateSystemReports;
exports.ReportHelper = {
    ALL_DATA_REPORT: exports.ALL_DATA_REPORT,
    VISIBLE_DATA_REPORT: exports.VISIBLE_DATA_REPORT,
    SELECTED_CELLS_REPORT: exports.SELECTED_CELLS_REPORT,
    SELECTED_ROWS_REPORT: exports.SELECTED_ROWS_REPORT,
    IsSystemReport: IsSystemReport,
    IsReportDestinationActive: IsReportDestinationActive,
    GetReportColumnsDescription: GetReportColumnsDescription,
    GetReportExpressionDescription: GetReportExpressionDescription,
    ConvertReportToArray: ConvertReportToArray,
    CreateSystemReports: CreateSystemReports,
};
exports.default = exports.ReportHelper;
