"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var math = require("mathjs");
var LoggingHelper_1 = require("../Helpers/LoggingHelper");
var CalculatedColumnHelper_1 = require("../Helpers/CalculatedColumnHelper");
var Enums_1 = require("../../PredefinedConfig/Common/Enums");
var CalculatedColumnExpressionService = /** @class */ (function () {
    function CalculatedColumnExpressionService(blotter, colFunctionValue) {
        this.blotter = blotter;
        this.colFunctionValue = colFunctionValue;
        this.blotter = blotter;
        this.colFunctionValue = colFunctionValue;
    }
    CalculatedColumnExpressionService.prototype.GetCalculatedColumnDataType = function (expression) {
        var _this = this;
        try {
            var firstRecord_1 = this.blotter.getFirstRecord();
            var firstRowValue = math.eval(expression, {
                Col: function (columnId) {
                    try {
                        return _this.colFunctionValue(columnId, firstRecord_1);
                    }
                    catch (e) {
                        throw Error('Unknown column ' + columnId);
                    }
                },
            });
            return !isNaN(Number(firstRowValue)) ? Enums_1.DataType.Number : Enums_1.DataType.String;
        }
        catch (e) {
            LoggingHelper_1.LoggingHelper.LogAdaptableBlotterWarning(e);
            return Enums_1.DataType.Number;
        }
    };
    CalculatedColumnExpressionService.prototype.IsExpressionValid = function (expression) {
        var _this = this;
        try {
            var columns = this.blotter.api.gridApi.getColumns();
            var cleanedExpression = CalculatedColumnHelper_1.CalculatedColumnHelper.cleanExpressionColumnNames(expression, columns);
            var firstRecord_2 = this.blotter.getFirstRecord();
            math.eval(cleanedExpression, {
                Col: function (columnId) {
                    try {
                        return _this.colFunctionValue(columnId, firstRecord_2);
                    }
                    catch (e) {
                        throw Error('Unknown column ' + columnId);
                    }
                },
            });
            return { IsValid: true };
        }
        catch (e) {
            LoggingHelper_1.LoggingHelper.LogAdaptableBlotterWarning(e);
            return { IsValid: false, ErrorMsg: e.message };
        }
    };
    CalculatedColumnExpressionService.prototype.ComputeExpressionValue = function (expression, record) {
        var _this = this;
        try {
            if (this.blotter.isGroupRecord(record)) {
                return null;
            }
            return math.eval(expression, {
                node: record,
                Col: function (columnId) {
                    try {
                        return _this.colFunctionValue(columnId, record);
                    }
                    catch (e) {
                        throw Error('Unknown column ' + columnId);
                    }
                },
            });
        }
        catch (e) {
            LoggingHelper_1.LoggingHelper.LogAdaptableBlotterError(e);
            return null;
        }
    };
    return CalculatedColumnExpressionService;
}());
exports.CalculatedColumnExpressionService = CalculatedColumnExpressionService;
