"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var StyleConstants = require("../../Utilities/Constants/StyleConstants");
var StrategyConstants = require("../../Utilities/Constants/StrategyConstants");
var StyleHelper_1 = require("../Helpers/StyleHelper");
var EnumExtensions_1 = require("../Extensions/EnumExtensions");
var Enums_1 = require("../../PredefinedConfig/Common/Enums");
var StringExtensions_1 = require("../Extensions/StringExtensions");
var QuickSearchRedux = require("../../Redux/ActionsReducers/QuickSearchRedux");
var FormatColumnRedux = require("../../Redux/ActionsReducers/FormatColumnRedux");
var ConditionalStyleRedux = require("../../Redux/ActionsReducers/ConditionalStyleRedux");
var FlashingCellsRedux = require("../../Redux/ActionsReducers/FlashingCellsRedux");
var GeneralConstants_1 = require("../Constants/GeneralConstants");
//Somehow all the CSSRules do not work so I end up just forcing the innerHTML......
var StyleService = /** @class */ (function () {
    function StyleService(blotter) {
        var _this = this;
        this.blotter = blotter;
        this.blotter = blotter;
        // Create the <style> tag
        this.style = document.createElement('style');
        this.style.id =
            blotter.blotterOptions.containerOptions.adaptableBlotterContainer +
                '_' +
                blotter.blotterOptions.blotterId +
                '-style';
        // WebKit hack :(
        this.style.appendChild(document.createTextNode(''));
        // Add the <style> element to the page
        document.head.appendChild(this.style);
        this.setUpStoreListeners();
        this.blotter.on(GeneralConstants_1.BLOTTER_READY_EVENT, function () {
            _this.setUpFirstUsage();
        });
    }
    StyleService.prototype.setUpFirstUsage = function () {
        // need to check that its all initiliased - perhps onready is better?
        this.setUpFormatColumn();
        this.setUpFlashingCells();
        this.setUpConditionalStyle();
        this.createAdaptableBlotterFunctionStyles();
    };
    StyleService.prototype.setUpFormatColumn = function () {
        var formatColumnStrategy = (this.blotter.strategies.get(StrategyConstants.FormatColumnStrategyId));
        formatColumnStrategy.initStyles();
    };
    StyleService.prototype.setUpFlashingCells = function () {
        var flashingCellsStrategy = (this.blotter.strategies.get(StrategyConstants.FlashingCellsStrategyId));
        flashingCellsStrategy.initStyles();
    };
    StyleService.prototype.setUpConditionalStyle = function () {
        var conditionalStyleStrategy = (this.blotter.strategies.get(StrategyConstants.ConditionalStyleStrategyId));
        conditionalStyleStrategy.initStyles();
    };
    /**
     * this method is still not great but its better than the old version at least as it uses the new ever On... from the Store which is better
     * this class is still not perfect as we still delete and recreate all styles every time we create a conditional style, format column or flashing cell
     * but actually that is not the end of the world as it doenst happen so often and at least we are not doing it when quick search is applied.
     */
    StyleService.prototype.createAdaptableBlotterFunctionStyles = function () {
        var _this = this;
        this.clearCSSRules();
        // Format Column
        this.blotter.api.formatColumnApi.getAllFormatColumn().forEach(function (formatColumn) {
            var styleName = StyleHelper_1.StyleHelper.CreateUniqueStyleName(StrategyConstants.FormatColumnStrategyId, _this.blotter, formatColumn);
            _this.addCSSRule('.' + styleName, 'background-color: ' +
                formatColumn.Style.BackColor +
                ' !important;color: ' +
                formatColumn.Style.ForeColor +
                ' !important;font-weight: ' +
                formatColumn.Style.FontWeight +
                ' !important;font-style: ' +
                formatColumn.Style.FontStyle +
                ' !important;' +
                (formatColumn.Style.FontSize
                    ? 'font-size: ' +
                        EnumExtensions_1.EnumExtensions.getCssFontSizeFromFontSizeEnum(formatColumn.Style.FontSize) +
                        ' !important'
                    : ''));
        });
        //we define first the row conditions and then columns so priority of CS col > CS Row and allow a record to have both
        var conditioonalStyles = this.blotter.api.conditionalStyleApi.getAllConditionalStyle();
        conditioonalStyles
            .filter(function (x) { return x.ConditionalStyleScope == Enums_1.ConditionalStyleScope.Row; })
            .forEach(function (element) {
            var styleName = StyleHelper_1.StyleHelper.CreateUniqueStyleName(StrategyConstants.ConditionalStyleStrategyId, _this.blotter, element);
            _this.addCSSRule('.' + styleName, 'background-color: ' +
                element.Style.BackColor +
                ' !important;color: ' +
                element.Style.ForeColor +
                ' !important;font-weight: ' +
                element.Style.FontWeight +
                ' !important;font-style: ' +
                element.Style.FontStyle +
                ' !important;' +
                (element.Style.FontSize
                    ? 'font-size: ' +
                        EnumExtensions_1.EnumExtensions.getCssFontSizeFromFontSizeEnum(element.Style.FontSize) +
                        ' !important'
                    : ''));
        });
        conditioonalStyles
            .filter(function (x) { return x.ConditionalStyleScope == Enums_1.ConditionalStyleScope.ColumnCategory; })
            .forEach(function (element) {
            var styleName = StyleHelper_1.StyleHelper.CreateUniqueStyleName(StrategyConstants.ConditionalStyleStrategyId, _this.blotter, element);
            _this.addCSSRule('.' + styleName, 'background-color: ' +
                element.Style.BackColor +
                ' !important;color: ' +
                element.Style.ForeColor +
                ' !important;font-weight: ' +
                element.Style.FontWeight +
                ' !important;font-style: ' +
                element.Style.FontStyle +
                ' !important;' +
                (element.Style.FontSize
                    ? 'font-size: ' +
                        EnumExtensions_1.EnumExtensions.getCssFontSizeFromFontSizeEnum(element.Style.FontSize) +
                        ' !important'
                    : ''));
        });
        conditioonalStyles
            .filter(function (cs) { return cs.ConditionalStyleScope == Enums_1.ConditionalStyleScope.Column; })
            .forEach(function (element) {
            var styleName = StyleHelper_1.StyleHelper.CreateUniqueStyleName(StrategyConstants.ConditionalStyleStrategyId, _this.blotter, element);
            _this.addCSSRule('.' + styleName, 'background-color: ' +
                element.Style.BackColor +
                ' !important;color: ' +
                element.Style.ForeColor +
                ' !important;font-weight: ' +
                element.Style.FontWeight +
                ' !important;font-style: ' +
                element.Style.FontStyle +
                ' !important;' +
                (element.Style.FontSize
                    ? 'font-size: ' +
                        EnumExtensions_1.EnumExtensions.getCssFontSizeFromFontSizeEnum(element.Style.FontSize) +
                        ' !important'
                    : ''));
        });
        // quick search
        var quickSearchStyle = this.blotter.api.quickSearchApi.getQuickSearchStyle();
        if (StringExtensions_1.StringExtensions.IsNullOrEmpty(quickSearchStyle.ClassName)) {
            var styleName = StyleHelper_1.StyleHelper.CreateStyleName(StrategyConstants.QuickSearchStrategyId, this.blotter);
            this.addCSSRule('.' + styleName, 'background-color: ' +
                quickSearchStyle.BackColor +
                ' !important;color: ' +
                quickSearchStyle.ForeColor +
                ' !important;font-weight: ' +
                quickSearchStyle.FontWeight +
                ' !important;font-style: ' +
                quickSearchStyle.FontStyle +
                ' !important;' +
                (quickSearchStyle.FontSize
                    ? 'font-size: ' +
                        EnumExtensions_1.EnumExtensions.getCssFontSizeFromFontSizeEnum(quickSearchStyle.FontSize) +
                        ' !important'
                    : ''));
        }
        //we define last Flash since it has the highest priority
        this.blotter.api.flashingCellApi.getAllFlashingCell().forEach(function (element) {
            if (element.IsLive) {
                _this.addCSSRule('.' + StyleConstants.FLASH_UP_STYLE + '-' + element.Uuid, 'background-color: ' + element.UpColor + ' !important');
                _this.addCSSRule('.' + StyleConstants.FLASH_DOWN_STYLE + '-' + element.Uuid, 'background-color: ' + element.DownColor + ' !important');
            }
        });
    };
    StyleService.prototype.clearCSSRules = function () {
        this.style.innerHTML = '';
    };
    StyleService.prototype.addCSSRule = function (selector, rules) {
        this.style.innerHTML += selector + '{' + rules + '}' + '\n';
    };
    // not sure if this is better than us keeping a copy of the state and listening to it which is what we used to do.
    // I suspsect it is so we dont have lots of bits of state being stored and compared
    StyleService.prototype.setUpStoreListeners = function () {
        var _this = this;
        //  Quick Search - no need to set up styles for Quick Search as done in AB not the Strategy = need to test!!!
        this.blotter.adaptableBlotterStore.on(QuickSearchRedux.QUICK_SEARCH_SET_DISPLAY, function () {
            _this.createAdaptableBlotterFunctionStyles();
        });
        this.blotter.adaptableBlotterStore.on(QuickSearchRedux.QUICK_SEARCH_SET_STYLE, function () {
            _this.createAdaptableBlotterFunctionStyles();
        });
        // Format Column
        this.blotter.adaptableBlotterStore.on(FormatColumnRedux.FORMAT_COLUMN_ADD, function () {
            _this.setUpFormatColumn();
            _this.createAdaptableBlotterFunctionStyles();
        });
        this.blotter.adaptableBlotterStore.on(FormatColumnRedux.FORMAT_COLUMN_EDIT, function () {
            _this.setUpFormatColumn();
            _this.createAdaptableBlotterFunctionStyles();
        });
        this.blotter.adaptableBlotterStore.on(FormatColumnRedux.FORMAT_COLUMN_DELETE, function () {
            _this.setUpFormatColumn();
            _this.createAdaptableBlotterFunctionStyles();
        });
        // Conditional Style
        this.blotter.adaptableBlotterStore.on(ConditionalStyleRedux.CONDITIONAL_STYLE_ADD, function () {
            _this.setUpConditionalStyle();
            _this.createAdaptableBlotterFunctionStyles();
        });
        this.blotter.adaptableBlotterStore.on(ConditionalStyleRedux.CONDITIONAL_STYLE_EDIT, function () {
            _this.setUpConditionalStyle();
            _this.createAdaptableBlotterFunctionStyles();
        });
        this.blotter.adaptableBlotterStore.on(ConditionalStyleRedux.CONDITIONAL_STYLE_DELETE, function () {
            _this.setUpConditionalStyle();
            _this.createAdaptableBlotterFunctionStyles();
        });
        // Flashing Cell
        this.blotter.adaptableBlotterStore.on(FlashingCellsRedux.FLASHING_CELL_SELECT, function () {
            _this.setUpFlashingCells();
            _this.createAdaptableBlotterFunctionStyles();
        });
        this.blotter.adaptableBlotterStore.on(FlashingCellsRedux.FLASHING_CELL_SELECT_ALL, function () {
            _this.setUpFlashingCells();
            _this.createAdaptableBlotterFunctionStyles();
        });
        this.blotter.adaptableBlotterStore.on(FlashingCellsRedux.FLASHING_CELL_CHANGE_UP_COLOR, function () {
            _this.setUpFlashingCells();
            _this.createAdaptableBlotterFunctionStyles();
        });
        this.blotter.adaptableBlotterStore.on(FlashingCellsRedux.FLASHING_CELL_CHANGE_DOWN_COLOR, function () {
            _this.setUpFlashingCells();
            _this.createAdaptableBlotterFunctionStyles();
        });
        this.blotter.adaptableBlotterStore.on(FlashingCellsRedux.FLASHING_CELL_CHANGE_DURATION, function () {
            _this.setUpFlashingCells();
            _this.createAdaptableBlotterFunctionStyles();
        });
    };
    return StyleService;
}());
exports.StyleService = StyleService;
