"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var StrategyConstants = require("../../Utilities/Constants/StrategyConstants");
var ExpressionHelper_1 = require("../Helpers/ExpressionHelper");
var ArrayExtensions_1 = require("../Extensions/ArrayExtensions");
var ObjectFactory_1 = require("../../Utilities/ObjectFactory");
var ColumnHelper_1 = require("../Helpers/ColumnHelper");
var Enums_1 = require("../../PredefinedConfig/Common/Enums");
var ValidationService = /** @class */ (function () {
    function ValidationService(blotter) {
        this.blotter = blotter;
        this.blotter = blotter;
    }
    // Not sure where to put this: was in the strategy but might be better here until I can work out a way of having an event with a callback...
    ValidationService.prototype.ValidateCellChanging = function (dataChangedEvent) {
        var e_1, _a, e_2, _b;
        var failedWarningRules = [];
        // if the new value is the same as the old value then we can get out as we dont see it as an edit?
        if (dataChangedEvent.OldValue == dataChangedEvent.NewValue) {
            return failedWarningRules;
        }
        // first check that if primary key change, the new value is unique
        if (dataChangedEvent.ColumnId == this.blotter.blotterOptions.primaryKey) {
            if (this.blotter.blotterOptions.generalOptions.preventDuplicatePrimaryKeyValues) {
                if (dataChangedEvent.OldValue != dataChangedEvent.NewValue) {
                    var displayValuePair = this.blotter.getColumnValueDisplayValuePairDistinctList(dataChangedEvent.ColumnId, Enums_1.DistinctCriteriaPairValue.DisplayValue, false);
                    var existingItem = displayValuePair.find(function (dv) { return dv.DisplayValue == dataChangedEvent.NewValue; });
                    if (existingItem) {
                        var range = ObjectFactory_1.ObjectFactory.CreateRange(Enums_1.LeafExpressionOperator.PrimaryKeyDuplicate, dataChangedEvent.ColumnId, null, Enums_1.RangeOperandType.Column, null);
                        var cellValidationRule = ObjectFactory_1.ObjectFactory.CreateCellValidationRule(dataChangedEvent.ColumnId, range, Enums_1.ActionMode.StopEdit, ExpressionHelper_1.ExpressionHelper.CreateEmptyExpression());
                        failedWarningRules.push(cellValidationRule);
                    }
                }
            }
        }
        var editingRules = this.GetCellValidationState().CellValidations.filter(function (v) { return v.ColumnId == dataChangedEvent.ColumnId; });
        if (ArrayExtensions_1.ArrayExtensions.IsEmpty(failedWarningRules) && ArrayExtensions_1.ArrayExtensions.IsNotEmpty(editingRules)) {
            var columns = this.blotter.api.gridApi.getColumns();
            // first check the rules which have expressions
            var expressionRules = editingRules.filter(function (r) {
                return ExpressionHelper_1.ExpressionHelper.IsNotNullOrEmptyExpression(r.Expression);
            });
            if (expressionRules.length > 0) {
                try {
                    // loop through all rules with an expression (checking the prevent rules first)
                    // if the expression is satisfied check if validation rule passes; if it fails then return immediately (if its prevent) or put the rule in return array (if its warning).
                    // if expression isnt satisfied then we can ignore the rule but it means that we need subsequently to check all the rules with no expressions
                    for (var expressionRules_1 = tslib_1.__values(expressionRules), expressionRules_1_1 = expressionRules_1.next(); !expressionRules_1_1.done; expressionRules_1_1 = expressionRules_1.next()) {
                        var expressionRule = expressionRules_1_1.value;
                        var isSatisfiedExpression = ExpressionHelper_1.ExpressionHelper.checkForExpression(expressionRule.Expression, dataChangedEvent.IdentifierValue, columns, this.blotter);
                        if (isSatisfiedExpression &&
                            this.IsCellValidationRuleBroken(expressionRule, dataChangedEvent, columns)) {
                            // if we fail then get out if its prevent and keep the rule and stop looping if its warning...
                            if (expressionRule.ActionMode == 'Stop Edit') {
                                this.logAuditValidationEvent('Validating Cell Edit', 'Failed', {
                                    Errors: [expressionRule],
                                    DataChangingEvent: dataChangedEvent,
                                });
                                return [expressionRule];
                            }
                            else {
                                failedWarningRules.push(expressionRule);
                            }
                        }
                    }
                }
                catch (e_1_1) { e_1 = { error: e_1_1 }; }
                finally {
                    try {
                        if (expressionRules_1_1 && !expressionRules_1_1.done && (_a = expressionRules_1.return)) _a.call(expressionRules_1);
                    }
                    finally { if (e_1) throw e_1.error; }
                }
            }
            // now check the rules without expressions
            var noExpressionRules = editingRules.filter(function (r) {
                return ExpressionHelper_1.ExpressionHelper.IsNullOrEmptyExpression(r.Expression);
            });
            try {
                for (var noExpressionRules_1 = tslib_1.__values(noExpressionRules), noExpressionRules_1_1 = noExpressionRules_1.next(); !noExpressionRules_1_1.done; noExpressionRules_1_1 = noExpressionRules_1.next()) {
                    var noExpressionRule = noExpressionRules_1_1.value;
                    if (this.IsCellValidationRuleBroken(noExpressionRule, dataChangedEvent, columns)) {
                        if (noExpressionRule.ActionMode == 'Stop Edit') {
                            this.logAuditValidationEvent('Validating Cell Edit', 'Failed', {
                                Errors: [noExpressionRule],
                                DataChangingEvent: dataChangedEvent,
                            });
                            return [noExpressionRule];
                        }
                        else {
                            failedWarningRules.push(noExpressionRule);
                        }
                    }
                }
            }
            catch (e_2_1) { e_2 = { error: e_2_1 }; }
            finally {
                try {
                    if (noExpressionRules_1_1 && !noExpressionRules_1_1.done && (_b = noExpressionRules_1.return)) _b.call(noExpressionRules_1);
                }
                finally { if (e_2) throw e_2.error; }
            }
        }
        if (failedWarningRules.length > 0) {
            this.logAuditValidationEvent('Validating Cell Edit', 'Warning Shown', {
                Warnings: failedWarningRules,
                DataChangingEvent: dataChangedEvent,
            });
        }
        else {
            this.logAuditValidationEvent('Validating Cell Edit', 'Success', {
                DataChangingEvent: dataChangedEvent,
            });
        }
        return failedWarningRules;
    };
    // changing this so that it now checks the opposite!
    ValidationService.prototype.IsCellValidationRuleBroken = function (cellValidationRule, dataChangedEvent, columns) {
        // if its any change then validation fails immediately
        if (cellValidationRule.Range.Operator == Enums_1.LeafExpressionOperator.AnyChange) {
            return true;
        }
        // todo: change the last argument from null as we might want to do evaluation based on other cells...
        var column = ColumnHelper_1.ColumnHelper.getColumnFromId(dataChangedEvent.ColumnId, columns);
        var rangeEvaluation = ExpressionHelper_1.ExpressionHelper.GetRangeEvaluation(cellValidationRule.Range, dataChangedEvent.NewValue, dataChangedEvent.OldValue, column, this.blotter, null);
        return ExpressionHelper_1.ExpressionHelper.TestRangeEvaluation(rangeEvaluation, this.blotter);
    };
    ValidationService.prototype.GetCellValidationState = function () {
        return this.blotter.api.cellValidationApi.getCellValidationState();
    };
    ValidationService.prototype.logAuditValidationEvent = function (action, info, data) {
        if (this.blotter.AuditLogService.isAuditFunctionEventsEnabled) {
            var functionAppliedDetails = {
                name: StrategyConstants.CellValidationStrategyId,
                action: action,
                info: info,
                data: data,
            };
            this.blotter.AuditLogService.addFunctionAppliedAuditLog(functionAppliedDetails);
        }
    };
    return ValidationService;
}());
exports.ValidationService = ValidationService;
