"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var React = require("react");
var react_redux_1 = require("react-redux");
var SystemRedux = require("../../Redux/ActionsReducers/SystemRedux");
var DashboardRedux = require("../../Redux/ActionsReducers/DashboardRedux");
var PopupRedux = require("../../Redux/ActionsReducers/PopupRedux");
var PanelDashboard_1 = require("../Components/Panels/PanelDashboard");
var StrategyConstants = require("../../Utilities/Constants/StrategyConstants");
var ScreenPopups = require("../../Utilities/Constants/ScreenPopups");
var AdaptablePopover_1 = require("../AdaptablePopover");
var Enums_1 = require("../../PredefinedConfig/Common/Enums");
var AlertsPanel_1 = require("./AlertsPanel");
var rebass_1 = require("rebass");
var ArrayExtensions_1 = require("../../Utilities/Extensions/ArrayExtensions");
var AlertToolbarControlComponent = /** @class */ (function (_super) {
    tslib_1.__extends(AlertToolbarControlComponent, _super);
    function AlertToolbarControlComponent(props) {
        var _this = _super.call(this, props) || this;
        _this.state = {
            ShowMessage: false,
            Alerts: _this.props.Alerts,
        };
        return _this;
    }
    AlertToolbarControlComponent.prototype.componentDidUpdate = function () {
        if (this.state.Alerts.length != this.props.Alerts.length) {
            this.setState({ ShowMessage: true, Alerts: this.props.Alerts });
        }
    };
    AlertToolbarControlComponent.prototype.render = function () {
        var _this = this;
        var alertsPanel = (React.createElement(AlertsPanel_1.AlertsPanel, { Alerts: this.props.Alerts, ShowPanel: true, ShowHeader: false, onClearAlert: this.props.onDeleteAlert, onRender: function () { return _this.setState({ ShowMessage: false }); }, onClearAllAlerts: this.props.onDeleteAllAlert }));
        var collapsedText = this.props.Alerts.length == 0
            ? '0 Alerts'
            : this.props.Alerts.length == 1
                ? '1 Alert'
                : this.props.Alerts.length + ' Alerts';
        var buttonColor = ArrayExtensions_1.default.IsNotNullOrEmpty(this.props.Alerts)
            ? 'secondary'
            : 'primary';
        var buttonTextColor = ArrayExtensions_1.default.IsNotNullOrEmpty(this.props.Alerts)
            ? 'text-on-secondary'
            : 'text-on-primary';
        var content = (React.createElement(rebass_1.Flex, { alignItems: "stretch" },
            React.createElement(rebass_1.Flex, { style: { borderRadius: 'var(--ab__border-radius)' }, marginRight: 2, padding: 2, color: buttonTextColor, backgroundColor: buttonColor, fontSize: 'var( --ab-font-size-2)', alignItems: "center" }, collapsedText),
            this.props.Alerts.length > 0 && (React.createElement(rebass_1.Flex, { alignItems: "center" },
                React.createElement(AdaptablePopover_1.AdaptablePopover, { headerText: "", 
                    // tooltipText="Alerts"
                    bodyText: [alertsPanel], MessageType: this.getMessageType(), useButton: true, showEvent: 'focus', hideEvent: "blur" })))));
        return (React.createElement(PanelDashboard_1.PanelDashboard, { headerText: StrategyConstants.AlertStrategyName, glyphicon: StrategyConstants.AlertGlyph, onClose: function () { return _this.props.onClose(StrategyConstants.AlertStrategyId); }, onConfigure: function () { return _this.props.onConfigure(); } }, content));
    };
    AlertToolbarControlComponent.prototype.getMessageType = function () {
        if (this.props.Alerts.find(function (a) { return a.MessageType == Enums_1.MessageType.Error; }) != null) {
            return Enums_1.MessageType.Error;
        }
        if (this.props.Alerts.find(function (a) { return a.MessageType == Enums_1.MessageType.Warning; }) != null) {
            return Enums_1.MessageType.Warning;
        }
        return Enums_1.MessageType.Info;
    };
    return AlertToolbarControlComponent;
}(React.Component));
function mapStateToProps(state, ownProps) {
    return {
        AlertDefinitions: state.Alert.AlertDefinitions,
        Alerts: state.System.Alerts,
    };
}
function mapDispatchToProps(dispatch) {
    return {
        onDeleteAlert: function (index) { return dispatch(SystemRedux.SystemAlertDelete(index)); },
        onDeleteAllAlert: function () { return dispatch(SystemRedux.SystemAlertDeleteAll()); },
        onClose: function (dashboardControl) {
            return dispatch(DashboardRedux.DashboardHideToolbar(dashboardControl));
        },
        onConfigure: function () {
            return dispatch(PopupRedux.PopupShowScreen(StrategyConstants.AlertStrategyId, ScreenPopups.AlertPopup));
        },
    };
}
exports.AlertToolbarControl = react_redux_1.connect(mapStateToProps, mapDispatchToProps)(AlertToolbarControlComponent);
var smallFormControlStyle = {
    fontSize: 'xsmall',
    height: '22px',
    width: '80px',
};
var standardFormControlStyle = {
    width: '80px',
};
