"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var React = require("react");
var react_redux_1 = require("react-redux");
var PopupRedux = require("../../Redux/ActionsReducers/PopupRedux");
var DashboardRedux = require("../../Redux/ActionsReducers/DashboardRedux");
var SelectedCellsRedux = require("../../Redux/ActionsReducers/CellSummaryRedux");
var GridRedux = require("../../Redux/ActionsReducers/GridRedux");
var StrategyConstants = require("../../Utilities/Constants/StrategyConstants");
var ScreenPopups = require("../../Utilities/Constants/ScreenPopups");
var PanelDashboard_1 = require("../Components/Panels/PanelDashboard");
var Enums_1 = require("../../PredefinedConfig/Common/Enums");
var EnumExtensions_1 = require("../../Utilities/Extensions/EnumExtensions");
var GeneralConstants = require("../../Utilities/Constants/GeneralConstants");
var AdaptablePopover_1 = require("../AdaptablePopover");
var CellSummaryPopover_1 = require("./CellSummaryPopover");
var ArrayExtensions_1 = require("../../Utilities/Extensions/ArrayExtensions");
var GeneralConstants_1 = require("../../Utilities/Constants/GeneralConstants");
var DropdownButton_1 = require("../../components/DropdownButton");
var rebass_1 = require("rebass");
var CellSummaryToolbarControlComponent = /** @class */ (function (_super) {
    tslib_1.__extends(CellSummaryToolbarControlComponent, _super);
    function CellSummaryToolbarControlComponent(props) {
        return _super.call(this, props) || this;
    }
    CellSummaryToolbarControlComponent.prototype.componentDidMount = function () {
        var _this = this;
        if (this.props.Blotter) {
            this.props.Blotter.on(GeneralConstants_1.CELLS_SELECTED_EVENT, function () {
                _this.props.onCreateCellSummary();
            });
        }
    };
    // needed?
    // public componentWillUnmount() {
    //   if (this.props.Blotter) {
    //     this.props.Blotter.onSelectedCellsChanged().Unsubscribe(this.state.SubFunc);
    //   }
    // }
    CellSummaryToolbarControlComponent.prototype.render = function () {
        var _this = this;
        var operationMenuItems = EnumExtensions_1.EnumExtensions.getNames(Enums_1.CellSummaryOperation).map(function (summaryOperation, index) {
            return {
                label: summaryOperation,
                onClick: function () { return _this.props.onCellSummaryOperationChange(summaryOperation); },
            };
        });
        var operationOptionalMenuItems = EnumExtensions_1.EnumExtensions.getNames(Enums_1.CellSummaryOptionalOperation)
            .map(function (summaryOperation, index) {
            if (ArrayExtensions_1.ArrayExtensions.ContainsItem(_this.props.OptionalSummaryOperations, summaryOperation)) {
                return {
                    onClick: function () { return _this.props.onCellSummaryOperationChange(summaryOperation); },
                    label: summaryOperation,
                };
            }
        })
            .filter(function (x) { return !!x; });
        var cellSummaryPopover = React.createElement(CellSummaryPopover_1.CellSummaryPopover, { CellSummary: this.props.CellSummary });
        var content = (React.createElement(rebass_1.Flex, { flexDirection: "row", alignItems: "center", width: "100%", className: this.props.AccessLevel == Enums_1.AccessLevel.ReadOnly ? GeneralConstants.READ_ONLY_STYLE : '' },
            React.createElement(DropdownButton_1.default, { marginRight: 2, columns: ['label'], items: tslib_1.__spread(operationMenuItems, operationOptionalMenuItems) }, this.props.CellSummaryOperation),
            this.props.CellSummary != null && (React.createElement(React.Fragment, null,
                React.createElement(rebass_1.Flex, { flex: 1, marginRight: 2, justifyContent: "center", color: 'var(--ab-color-text-on-primary)' }, this.getOperationValue()),
                this.props.CellSummary != null && this.props.CellSummary.Count > 0 && (React.createElement(AdaptablePopover_1.AdaptablePopover, { bodyText: [cellSummaryPopover], 
                    // tooltipText={'Show Cell Summary'}
                    useButton: true, showEvent: 'focus', hideEvent: "blur" }))))));
        return (React.createElement(PanelDashboard_1.PanelDashboard, { headerText: StrategyConstants.CellSummaryStrategyName, glyphicon: StrategyConstants.CellSummaryGlyph, onClose: function () { return _this.props.onClose(StrategyConstants.CellSummaryStrategyId); }, onConfigure: function () { return _this.props.onConfigure(); } }, content));
    };
    CellSummaryToolbarControlComponent.prototype.onSelectionChanged = function () {
        this.props.onCreateCellSummary();
    };
    CellSummaryToolbarControlComponent.prototype.getOperationValue = function () {
        switch (this.props.CellSummaryOperation) {
            case Enums_1.CellSummaryOperation.Sum:
                return this.props.CellSummary.Sum;
            case Enums_1.CellSummaryOperation.Average:
                return this.props.CellSummary.Average;
            case Enums_1.CellSummaryOperation.Median:
                return this.props.CellSummary.Median;
            case Enums_1.CellSummaryOperation.Max:
                return this.props.CellSummary.Max;
            case Enums_1.CellSummaryOperation.Min:
                return this.props.CellSummary.Min;
            case Enums_1.CellSummaryOperation.Distinct:
                return this.props.CellSummary.Distinct;
            case Enums_1.CellSummaryOperation.Count:
                return this.props.CellSummary.Count;
            case Enums_1.CellSummaryOptionalOperation.Only:
                return this.props.CellSummary.Only;
            case Enums_1.CellSummaryOptionalOperation.VWAP:
                return this.props.CellSummary.VWAP;
        }
    };
    return CellSummaryToolbarControlComponent;
}(React.Component));
function mapStateToProps(state, ownProps) {
    return {
        SelectedCellInfo: state.Grid.SelectedCellInfo,
        CellSummaryOperation: state.CellSummary.SummaryOperation,
        OptionalSummaryOperations: state.CellSummary.OptionalSummaryOperations,
        CellSummary: state.Grid.CellSummary,
    };
}
function mapDispatchToProps(dispatch) {
    return {
        onCellSummaryOperationChange: function (summaryOperation) { return dispatch(SelectedCellsRedux.CellSummaryChangeOperation(summaryOperation)); },
        onCreateCellSummary: function () { return dispatch(GridRedux.GridCreateCellSummary()); },
        onClose: function (dashboardControl) {
            return dispatch(DashboardRedux.DashboardHideToolbar(dashboardControl));
        },
        onConfigure: function () {
            return dispatch(PopupRedux.PopupShowScreen(StrategyConstants.CellSummaryStrategyId, ScreenPopups.CellSummaryPopup));
        },
    };
}
exports.CellSummaryToolbarControl = react_redux_1.connect(mapStateToProps, mapDispatchToProps)(CellSummaryToolbarControlComponent);
