"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var React = require("react");
var react_redux_1 = require("react-redux");
var StringExtensions_1 = require("../../Utilities/Extensions/StringExtensions");
var ExportRedux = require("../../Redux/ActionsReducers/ExportRedux");
var SystemRedux = require("../../Redux/ActionsReducers/SystemRedux");
var PopupRedux = require("../../Redux/ActionsReducers/PopupRedux");
var DashboardRedux = require("../../Redux/ActionsReducers/DashboardRedux");
//import { IDashboardStrategyControlConfiguration } from '../../Strategy/Interface/IDashboardStrategy';
var ButtonDelete_1 = require("../Components/Buttons/ButtonDelete");
var ButtonNew_1 = require("../Components/Buttons/ButtonNew");
var ButtonEdit_1 = require("../Components/Buttons/ButtonEdit");
var PanelDashboard_1 = require("../Components/Panels/PanelDashboard");
var StrategyConstants = require("../../Utilities/Constants/StrategyConstants");
var ScreenPopups = require("../../Utilities/Constants/ScreenPopups");
var GeneralConstants = require("../../Utilities/Constants/GeneralConstants");
var ReportHelper_1 = require("../../Utilities/Helpers/ReportHelper");
var Enums_1 = require("../../PredefinedConfig/Common/Enums");
var rebass_1 = require("rebass");
var Dropdown_1 = require("../../components/Dropdown");
var DropdownButton_1 = require("../../components/DropdownButton");
var icons_1 = require("../../components/icons");
var ExportIcon = icons_1.default.export;
var ExportToolbarControlComponent = /** @class */ (function (_super) {
    tslib_1.__extends(ExportToolbarControlComponent, _super);
    function ExportToolbarControlComponent() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ExportToolbarControlComponent.prototype.render = function () {
        var _this = this;
        var selectReportString = 'Select a Report';
        var allReports = this.props.SystemReports.concat(this.props.Reports);
        var currentReport = this.props.Blotter.api.exportApi.getCurrentReport();
        var savedReport = allReports.find(function (s) { return s.Name == _this.props.CurrentReport; });
        var savedReportIndex = this.props.Reports.findIndex(function (s) { return s.Name == _this.props.CurrentReport; });
        var currentReportId = StringExtensions_1.StringExtensions.IsNullOrEmpty(this.props.CurrentReport)
            ? selectReportString
            : this.props.CurrentReport;
        var availableReports = allReports.map(function (report, index) {
            return {
                label: report.Name,
                value: report.Name,
            };
        });
        var csvMenuItem = {
            onClick: function () { return _this.props.onApplyExport(currentReport, Enums_1.ExportDestination.CSV); },
            label: 'CSV',
        };
        var clipboardMenuItem = {
            label: 'Clipboard',
            onClick: function () { return _this.props.onApplyExport(currentReport, Enums_1.ExportDestination.Clipboard); },
        };
        var openfinExcelMenuItem;
        if (this.props.LiveReports.find(function (x) { return x.Report == currentReport && x.ExportDestination == Enums_1.ExportDestination.OpenfinExcel; })) {
            openfinExcelMenuItem = {
                onClick: function () { return _this.props.onReportStopLive(currentReport, Enums_1.ExportDestination.OpenfinExcel); },
                label: 'Stop Live Openfin Excel',
            };
        }
        else {
            openfinExcelMenuItem = {
                onClick: function () { return _this.props.onApplyExport(currentReport, Enums_1.ExportDestination.OpenfinExcel); },
                label: 'Start Live Openfin Excel',
            };
        }
        var iPushPullExcelMenuItem;
        if (this.props.LiveReports.find(function (x) { return x.Report == currentReport && x.ExportDestination == Enums_1.ExportDestination.iPushPull; })) {
            iPushPullExcelMenuItem = {
                onClick: function () { return _this.props.onReportStopLive(currentReport, Enums_1.ExportDestination.iPushPull); },
                label: 'Stop Sync with iPushPull',
            };
        }
        else {
            iPushPullExcelMenuItem = {
                onClick: function () { return _this.props.onApplyExport(currentReport, Enums_1.ExportDestination.iPushPull); },
                label: 'Start Sync with iPushPull',
            };
        }
        var glue42MenuItem = {
            onClick: function () { return _this.props.onApplyExport(currentReport, Enums_1.ExportDestination.Glue42); },
            label: 'Export to Excel (via Glue42)',
        };
        var deleteMessage = "Are you sure you want to delete '";
        if (savedReport != null) {
            deleteMessage = deleteMessage + savedReport.Name + '?';
        }
        var exportItems = [
            csvMenuItem,
            clipboardMenuItem,
            ,
            ReportHelper_1.ReportHelper.IsReportDestinationActive(Enums_1.ExportDestination.OpenfinExcel) &&
                openfinExcelMenuItem,
            ReportHelper_1.ReportHelper.IsReportDestinationActive(Enums_1.ExportDestination.iPushPull) && iPushPullExcelMenuItem,
            ReportHelper_1.ReportHelper.IsReportDestinationActive(Enums_1.ExportDestination.Glue42) && glue42MenuItem,
        ].filter(function (x) { return !!x; });
        var content = (React.createElement(rebass_1.Flex, { alignItems: "stretch" },
            React.createElement(Dropdown_1.default, { disabled: allReports.length == 0, style: { minWidth: 160 }, options: availableReports, placeholder: "Select Report", onChange: function (reportName) { return _this.onSelectedReportChanged(reportName); }, value: currentReport ? currentReport.Name : null, showClearButton: true, marginRight: 2 }),
            React.createElement(DropdownButton_1.default, { columns: ['label'], variant: "text", disabled: currentReportId == selectReportString, items: exportItems },
                React.createElement(ExportIcon, null)),
            React.createElement(rebass_1.Flex, { className: this.props.AccessLevel == Enums_1.AccessLevel.ReadOnly ? GeneralConstants.READ_ONLY_STYLE : '', alignItems: "stretch" },
                React.createElement(ButtonEdit_1.ButtonEdit, { onClick: function () { return _this.props.onEditReport(); }, tooltip: "Edit Report", disabled: savedReport == null || ReportHelper_1.ReportHelper.IsSystemReport(savedReport), AccessLevel: this.props.AccessLevel }),
                React.createElement(ButtonNew_1.ButtonNew, { variant: "text", children: null, onClick: function () { return _this.props.onNewReport(); }, tooltip: "Create New Report", AccessLevel: this.props.AccessLevel }),
                React.createElement(ButtonDelete_1.ButtonDelete, { tooltip: "Delete Report", disabled: savedReport == null || ReportHelper_1.ReportHelper.IsSystemReport(savedReport), ConfirmAction: ExportRedux.ReportDelete(savedReport), ConfirmationMsg: deleteMessage, ConfirmationTitle: 'Delete Report', AccessLevel: this.props.AccessLevel }))));
        return (React.createElement(PanelDashboard_1.PanelDashboard, { headerText: StrategyConstants.ExportStrategyName, glyphicon: StrategyConstants.ExportGlyph, onClose: function () { return _this.props.onClose(StrategyConstants.ExportStrategyId); }, onConfigure: function () { return _this.props.onConfigure(); } }, content));
    };
    ExportToolbarControlComponent.prototype.onSelectedReportChanged = function (reportName) {
        this.props.onSelectReport(reportName);
    };
    return ExportToolbarControlComponent;
}(React.Component));
function mapStateToProps(state, ownProps) {
    return {
        CurrentReport: state.Export.CurrentReport,
        Reports: state.Export.Reports,
        SystemReports: state.System.SystemReports,
        LiveReports: state.System.CurrentLiveReports,
    };
}
function mapDispatchToProps(dispatch) {
    return {
        onApplyExport: function (Report, exportDestination) {
            return dispatch(ExportRedux.ExportApply(Report, exportDestination));
        },
        onSelectReport: function (Report) { return dispatch(ExportRedux.ReportSelect(Report)); },
        onReportStopLive: function (Report, exportDestination) { return dispatch(SystemRedux.ReportStopLive(Report, exportDestination)); },
        onNewReport: function () {
            return dispatch(PopupRedux.PopupShowScreen(StrategyConstants.ExportStrategyId, ScreenPopups.ExportPopup, 'New'));
        },
        onEditReport: function () {
            return dispatch(PopupRedux.PopupShowScreen(StrategyConstants.ExportStrategyId, ScreenPopups.ExportPopup, 'Edit'));
        },
        onClose: function (dashboardControl) {
            return dispatch(DashboardRedux.DashboardHideToolbar(dashboardControl));
        },
        onConfigure: function () {
            return dispatch(PopupRedux.PopupShowScreen(StrategyConstants.ExportStrategyId, ScreenPopups.ExportPopup));
        },
    };
}
exports.ExportToolbarControl = react_redux_1.connect(mapStateToProps, mapDispatchToProps)(ExportToolbarControlComponent);
