"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var React = require("react");
var WizardPanel_1 = require("../../../components/WizardPanel");
var Radio_1 = require("../../../components/Radio");
var CheckBox_1 = require("../../../components/CheckBox");
var Dropdown_1 = require("../../../components/Dropdown");
var Enums_1 = require("../../../PredefinedConfig/Common/Enums");
var EnumExtensions_1 = require("../../../Utilities/Extensions/EnumExtensions");
var ObjectFactory_1 = require("../../../Utilities/ObjectFactory");
var ArrayExtensions_1 = require("../../../Utilities/Extensions/ArrayExtensions");
var rebass_1 = require("rebass");
var Input_1 = require("../../../components/Input");
var ReportHelper_1 = require("../../../Utilities/Helpers/ReportHelper");
var ReportScheduleWizard = /** @class */ (function (_super) {
    tslib_1.__extends(ReportScheduleWizard, _super);
    function ReportScheduleWizard(props) {
        var _this = _super.call(this, props) || this;
        _this.onOneOffDateChanged = function (event) {
            var e = event.target;
            _this.setState({ OneOffDate: e.value }, function () {
                return _this.props.UpdateGoBackState();
            });
        };
        var autoExport = _this.props.Data.AutoExport
            ? _this.props.Data.AutoExport
            : ObjectFactory_1.ObjectFactory.CreateEmptyAutoExport();
        _this.state = {
            HasAutoExport: _this.props.Data.AutoExport != null,
            IsRecurringDate: autoExport.Schedule.OneOffDate == null ? true : false,
            Hour: autoExport.Schedule.Hour,
            Minute: autoExport.Schedule.Minute,
            DaysOfWeek: autoExport.Schedule.DaysOfWeek,
            OneOffDate: autoExport.Schedule.OneOffDate == null ? new Date() : autoExport.Schedule.OneOffDate,
            ExportDestination: autoExport.ExportDestination,
        };
        return _this;
    }
    ReportScheduleWizard.prototype.render = function () {
        var _this = this;
        var destinations = EnumExtensions_1.EnumExtensions.getNames(Enums_1.ExportDestination)
            .filter(function (type) { return ReportHelper_1.default.IsReportDestinationActive(type); })
            .map(function (type) {
            return {
                label: type,
                value: type,
            };
        });
        var hours = [];
        var i;
        for (i = 0; i < 24; i++) {
            hours.push({
                value: i,
                label: i,
            });
        }
        var minutes = [];
        var j;
        for (j = 0; j < 60; j++) {
            minutes.push({
                value: j,
                label: j,
            });
        }
        return (React.createElement(WizardPanel_1.default, null,
            React.createElement(CheckBox_1.default, { marginLeft: 2, checked: this.state.HasAutoExport == true, onChange: function (checked) { return _this.onHasAutoExportChanged(checked); } }, "Create a Schedule"),
            this.state.HasAutoExport == true && (React.createElement(rebass_1.Box, { marginTop: 3 },
                React.createElement(rebass_1.Flex, { flexDirection: "row", alignItems: "center", marginTop: 3 },
                    React.createElement(rebass_1.Text, { style: { flex: 3 }, textAlign: "end", marginRight: 2 }, "Export To:"),
                    React.createElement(rebass_1.Flex, { flex: 7 },
                        React.createElement(Dropdown_1.default, { placeholder: "select", showEmptyItem: false, showClearButton: false, value: this.state.ExportDestination, onChange: function (x) { return _this.onExportDestinationChanged(x); }, options: destinations }))),
                React.createElement(rebass_1.Flex, { flexDirection: "row", alignItems: "center", marginTop: 3 },
                    React.createElement(rebass_1.Text, { style: { flex: 3 }, textAlign: "end", marginRight: 2 }, "Hour:"),
                    React.createElement(rebass_1.Flex, { flex: 7 },
                        React.createElement(Dropdown_1.default, { placeholder: "select", showEmptyItem: false, showClearButton: false, value: this.state.Hour, onChange: function (x) { return _this.onHourChanged(x); }, options: hours }))),
                React.createElement(rebass_1.Flex, { flexDirection: "row", alignItems: "center", marginTop: 3 },
                    React.createElement(rebass_1.Text, { style: { flex: 3 }, textAlign: "end", marginRight: 2 }, "Minute:"),
                    React.createElement(rebass_1.Flex, { flex: 7 },
                        React.createElement(Dropdown_1.default, { showEmptyItem: false, showClearButton: false, placeholder: "select", value: this.state.Minute, onChange: function (x) { return _this.onMinuteChanged(x); }, options: minutes }))),
                React.createElement(rebass_1.Flex, { flexDirection: "row", alignItems: "center", marginTop: 3 },
                    React.createElement(rebass_1.Text, { style: { flex: 3 }, textAlign: "end", marginRight: 2 }, "Date:"),
                    React.createElement(rebass_1.Flex, { flex: 7, flexDirection: "row", alignItems: "center" },
                        React.createElement(Radio_1.default, { marginRight: 3, value: "recurring", checked: this.state.IsRecurringDate == true, onChange: function (_, e) { return _this.onRecurringDateChanged(e); } }, "Recurring Days"),
                        React.createElement(Radio_1.default, { value: "oneoff", checked: this.state.IsRecurringDate == false, onChange: function (_, e) { return _this.onRecurringDateChanged(e); } }, "One Off Date"))),
                this.state.IsRecurringDate ? (React.createElement(rebass_1.Flex, { flexDirection: "row", alignItems: "center", marginTop: 3 },
                    React.createElement(rebass_1.Flex, { flex: 3 }),
                    React.createElement(rebass_1.Flex, { flex: 7 },
                        React.createElement(rebass_1.Flex, { flexDirection: "column" },
                            React.createElement(CheckBox_1.default, { marginLeft: 2, value: Enums_1.DayOfWeek.Monday, checked: ArrayExtensions_1.ArrayExtensions.ContainsItem(this.state.DaysOfWeek, Enums_1.DayOfWeek.Monday), onChange: function (_, e) { return _this.onDayChecked(e); } }, "Monday"),
                            React.createElement(CheckBox_1.default, { marginLeft: 2, marginTop: 2, value: Enums_1.DayOfWeek.Tuesday, checked: ArrayExtensions_1.ArrayExtensions.ContainsItem(this.state.DaysOfWeek, Enums_1.DayOfWeek.Tuesday), onChange: function (_, e) { return _this.onDayChecked(e); } }, "Tuesday"),
                            React.createElement(CheckBox_1.default, { marginLeft: 2, marginTop: 2, value: Enums_1.DayOfWeek.Wednesday, checked: ArrayExtensions_1.ArrayExtensions.ContainsItem(this.state.DaysOfWeek, Enums_1.DayOfWeek.Wednesday), onChange: function (_, e) { return _this.onDayChecked(e); } }, "Wednesday"),
                            React.createElement(CheckBox_1.default, { marginLeft: 2, marginTop: 2, value: Enums_1.DayOfWeek.Thursday, checked: ArrayExtensions_1.ArrayExtensions.ContainsItem(this.state.DaysOfWeek, Enums_1.DayOfWeek.Thursday), onChange: function (_, e) { return _this.onDayChecked(e); } }, "Thursday"),
                            React.createElement(CheckBox_1.default, { marginLeft: 2, value: Enums_1.DayOfWeek.Friday, checked: ArrayExtensions_1.ArrayExtensions.ContainsItem(this.state.DaysOfWeek, Enums_1.DayOfWeek.Friday), marginTop: 2, onChange: function (_, e) { return _this.onDayChecked(e); } }, "Friday"),
                            React.createElement(CheckBox_1.default, { marginLeft: 2, marginTop: 2, value: Enums_1.DayOfWeek.Saturday, checked: ArrayExtensions_1.ArrayExtensions.ContainsItem(this.state.DaysOfWeek, Enums_1.DayOfWeek.Saturday), onChange: function (_, e) { return _this.onDayChecked(e); } }, "Saturday"),
                            React.createElement(CheckBox_1.default, { marginLeft: 2, marginTop: 2, value: Enums_1.DayOfWeek.Sunday, checked: ArrayExtensions_1.ArrayExtensions.ContainsItem(this.state.DaysOfWeek, Enums_1.DayOfWeek.Sunday), onChange: function (_, e) { return _this.onDayChecked(e); } }, "Sunday"))))) : (React.createElement(rebass_1.Flex, { flexDirection: "row", alignItems: "center", marginTop: 3 },
                    React.createElement(rebass_1.Flex, { flex: 3 }),
                    React.createElement(rebass_1.Flex, { flex: 7 },
                        React.createElement(Input_1.default, { type: "date", placeholder: "Date", onChange: function (x) { return _this.onOneOffDateChanged(x); }, value: this.state.OneOffDate }))))))));
    };
    ReportScheduleWizard.prototype.onHasAutoExportChanged = function (checked) {
        var _this = this;
        if (checked) {
            this.setState({ HasAutoExport: true }, function () {
                return _this.props.UpdateGoBackState();
            });
        }
        else {
            this.setState({ HasAutoExport: false }, function () {
                return _this.props.UpdateGoBackState();
            });
        }
    };
    ReportScheduleWizard.prototype.onDayChecked = function (event) {
        var _this = this;
        var e = event.target;
        var dayOfWeek = Number(e.value);
        var daysOfWeek = this.state.DaysOfWeek;
        if (e.checked) {
            daysOfWeek.push(dayOfWeek);
        }
        else {
            var index = daysOfWeek.indexOf(dayOfWeek);
            daysOfWeek.splice(index, 1);
        }
        this.setState({ DaysOfWeek: daysOfWeek }, function () {
            return _this.props.UpdateGoBackState();
        });
    };
    ReportScheduleWizard.prototype.onRecurringDateChanged = function (event) {
        var _this = this;
        var e = event.target;
        this.setState({ IsRecurringDate: e.value == 'recurring' }, function () {
            return _this.props.UpdateGoBackState();
        });
    };
    ReportScheduleWizard.prototype.onHourChanged = function (value) {
        var _this = this;
        this.setState({ Hour: Number(value) }, function () {
            return _this.props.UpdateGoBackState();
        });
    };
    ReportScheduleWizard.prototype.onMinuteChanged = function (value) {
        var _this = this;
        this.setState({ Minute: Number(value) }, function () {
            return _this.props.UpdateGoBackState();
        });
    };
    ReportScheduleWizard.prototype.onExportDestinationChanged = function (value) {
        var _this = this;
        this.setState({ ExportDestination: value }, function () { return _this.props.UpdateGoBackState(); });
    };
    ReportScheduleWizard.prototype.canNext = function () {
        if (this.state.HasAutoExport) {
            if (this.state.Hour == null || this.state.Minute == null) {
                return false;
            }
            if (this.state.IsRecurringDate && ArrayExtensions_1.ArrayExtensions.IsEmpty(this.state.DaysOfWeek)) {
                return false;
            }
            if (!this.state.IsRecurringDate && this.state.OneOffDate == null) {
                return false;
            }
            return true;
        }
        else {
            return true;
        }
    };
    ReportScheduleWizard.prototype.canBack = function () {
        return true;
    };
    ReportScheduleWizard.prototype.Next = function () {
        // TODO:  need to build up the object ;(
        if (this.state.HasAutoExport) {
            var schedule = {
                Hour: this.state.Hour,
                Minute: this.state.Minute,
                OneOffDate: this.state.IsRecurringDate ? null : this.state.OneOffDate,
                DaysOfWeek: this.state.IsRecurringDate ? this.state.DaysOfWeek : [],
            };
            var autoExport = {
                Schedule: schedule,
                ExportDestination: this.state.ExportDestination,
            };
            this.props.Data.AutoExport = autoExport;
        }
        else {
            this.props.Data.AutoExport = null;
        }
    };
    ReportScheduleWizard.prototype.Back = function () {
        //todo
    };
    ReportScheduleWizard.prototype.GetIndexStepIncrement = function () {
        return 1;
    };
    ReportScheduleWizard.prototype.GetIndexStepDecrement = function () {
        return this.props.Data.ReportRowScope == Enums_1.ReportRowScope.ExpressionRows ? 1 : 2;
    };
    return ReportScheduleWizard;
}(React.Component));
exports.ReportScheduleWizard = ReportScheduleWizard;
