"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var React = require("react");
var react_redux_1 = require("react-redux");
var PopupRedux = require("../../Redux/ActionsReducers/PopupRedux");
var DashboardRedux = require("../../Redux/ActionsReducers/DashboardRedux");
var SystemRedux = require("../../Redux/ActionsReducers/SystemRedux");
var PanelDashboard_1 = require("../Components/Panels/PanelDashboard");
var StrategyConstants = require("../../Utilities/Constants/StrategyConstants");
var ScreenPopups = require("../../Utilities/Constants/ScreenPopups");
var GeneralConstants = require("../../Utilities/Constants/GeneralConstants");
var Enums_1 = require("../../PredefinedConfig/Common/Enums");
var StringExtensions_1 = require("../../Utilities/Extensions/StringExtensions");
var ArrayExtensions_1 = require("../../Utilities/Extensions/ArrayExtensions");
var ColumnHelper_1 = require("../../Utilities/Helpers/ColumnHelper");
var UIHelper_1 = require("../UIHelper");
var CheckBox_1 = require("../../components/CheckBox");
var SimpleButton_1 = require("../../components/SimpleButton");
var DropdownButton_1 = require("../../components/DropdownButton");
var rebass_1 = require("rebass");
var icons_1 = require("../../components/icons");
var preventDefault = function (e) { return e.preventDefault(); };
var HomeToolbarControlComponent = /** @class */ (function (_super) {
    tslib_1.__extends(HomeToolbarControlComponent, _super);
    function HomeToolbarControlComponent(props) {
        var _this = _super.call(this, props) || this;
        _this.state = { configMenuItems: [] };
        return _this;
    }
    HomeToolbarControlComponent.prototype.render = function () {
        var _this = this;
        var functionsGlyph = React.createElement(icons_1.Icon, { name: 'home' });
        var colsGlyph = React.createElement(icons_1.Icon, { name: 'list' });
        var toolbarsGlyph = React.createElement(icons_1.Icon, { name: 'align-justify' });
        // List strategies that are allowed - i.e. are offered by the Blotter instance and are not Hidden Entitlement
        var strategyKeys = tslib_1.__spread(this.props.Blotter.strategies.keys());
        var allowedMenuItems = this.props.MenuState.MainMenuItems.filter(function (x) { return x.IsVisible && ArrayExtensions_1.ArrayExtensions.NotContainsItem(strategyKeys, x); });
        // function menu items
        var menuItems = allowedMenuItems.map(function (menuItem) {
            return {
                disabled: _this.props.AccessLevel == Enums_1.AccessLevel.ReadOnly,
                onClick: function () { return _this.onClick(menuItem); },
                icon: React.createElement(icons_1.Icon, { name: menuItem.GlyphIcon }),
                label: menuItem.Label,
            };
        });
        // column items
        var colItems = [
            {
                clickable: false,
                label: (React.createElement("div", { key: "colTitle" },
                    ' ',
                    "\u00A0\u00A0",
                    React.createElement("b", null, 'Columns'))),
            },
        ];
        this.props.Columns.forEach(function (col, index) {
            colItems.push({
                id: col.ColumnId,
                onClick: function (e) {
                    _this.onSetColumnVisibility(col.ColumnId);
                },
                label: (React.createElement(CheckBox_1.default, { as: "div", className: "ab-dd-checkbox", my: 0, value: col.ColumnId, key: col.ColumnId, checked: col.Visible, onMouseDown: preventDefault }, col.FriendlyName)),
            });
        });
        // toolbar items
        var toolbarItems = [];
        var allowedMenuNames = allowedMenuItems.map(function (vm) {
            return vm.StrategyId;
        });
        toolbarItems.push({
            clickable: false,
            label: (React.createElement("div", { key: "toolbarTitle" },
                ' ',
                "\u00A0\u00A0",
                React.createElement("b", null, 'Toolbars'))),
        });
        this.props.DashboardState.AvailableToolbars.forEach(function (toolbar, index) {
            if (ArrayExtensions_1.ArrayExtensions.ContainsItem(allowedMenuNames, toolbar)) {
                var isVisible_1 = ArrayExtensions_1.ArrayExtensions.ContainsItem(_this.props.DashboardState.VisibleToolbars, toolbar);
                var functionName = StrategyConstants.getNameForStrategyId(toolbar);
                toolbarItems.push({
                    id: toolbar,
                    onClick: function (e) {
                        _this.onSetToolbarVisibility(toolbar, !isVisible_1);
                    },
                    label: (React.createElement(CheckBox_1.default, { className: "ab-dd-checkbox", my: 0, as: "div", value: toolbar, key: toolbar, checked: isVisible_1, onMouseDown: preventDefault }, functionName)),
                });
            }
        });
        // status button
        var statusButton = (React.createElement(SimpleButton_1.default, { variant: "text", key: 'systemstatus', icon: UIHelper_1.UIHelper.getGlyphForMessageType(this.props.SystemStatus.StatusType), style: UIHelper_1.UIHelper.getStyleForMessageType(this.props.SystemStatus.StatusType), tooltip: 'Status: ' + this.props.SystemStatus.StatusMessage, disabled: false, onClick: function () { return _this.onClickStatus(); }, AccessLevel: Enums_1.AccessLevel.Full }));
        // gridInfo button
        var gridInfoButton = (React.createElement(SimpleButton_1.default, { tooltip: "Grid Info", icon: 'info', variant: "text", onClick: function () { return _this.onClickGridInfo(); }, AccessLevel: Enums_1.AccessLevel.Full }));
        // functions dropdown
        var functionsDropdown = (React.createElement(DropdownButton_1.default, { variant: "text", items: menuItems, tooltip: "Grid Functions", key: 'dropdown-functions', id: 'dropdown-functions' }, functionsGlyph));
        // columns dropdown
        var columnsDropDown = (React.createElement(DropdownButton_1.default, { variant: "text", collapseOnItemClick: false, items: colItems, columns: ['label'], key: 'dropdown-cols', id: 'dropdown-cols', tooltip: "Select Columns" }, colsGlyph));
        // toolbars dropdown
        var toolbarsDropDown = (React.createElement(DropdownButton_1.default, { variant: "text", collapseOnItemClick: false, key: 'dropdown-toolbars', id: 'dropdown-toolbars', columns: ['label'], items: toolbarItems, tooltip: "Manage Toolbars" }, toolbarsGlyph));
        // shortcuts
        var shortcutsArray = this.props.DashboardState.VisibleButtons;
        var shortcuts;
        if (shortcutsArray) {
            shortcuts = shortcutsArray.map(function (x) {
                var menuItem = _this.props.MenuState.MainMenuItems.find(function (y) { return y.IsVisible && y.StrategyId == x; });
                if (menuItem) {
                    return (React.createElement(SimpleButton_1.default, { key: menuItem.Label, icon: menuItem.GlyphIcon, variant: "text", tooltip: menuItem.Label, disabled: _this.props.AccessLevel == Enums_1.AccessLevel.ReadOnly, onClick: function () { return _this.onClick(menuItem); }, AccessLevel: Enums_1.AccessLevel.Full }));
                }
            });
        }
        var toolbarTitle = this.props.DashboardState.HomeToolbarTitle;
        if (StringExtensions_1.StringExtensions.IsNullOrEmpty(toolbarTitle)) {
            toolbarTitle = this.props.Blotter.blotterOptions.blotterId;
            if (toolbarTitle == GeneralConstants.USER_NAME) {
                toolbarTitle = 'Blotter ';
            }
        }
        return (React.createElement(PanelDashboard_1.PanelDashboard, { showCloseButton: false, showMinimiseButton: true, onMinimise: function () { return _this.props.onSetDashboardVisibility(Enums_1.Visibility.Minimised); }, headerText: toolbarTitle, glyphicon: 'home', showGlyphIcon: false, onClose: function () { return _this.props.onClose(StrategyConstants.HomeStrategyId); }, onConfigure: function () { return _this.props.onConfigure(); } },
            React.createElement(rebass_1.Flex, { flexDirection: "row" },
                this.props.DashboardState.ShowFunctionsDropdown && functionsDropdown,
                this.props.DashboardState.ShowSystemStatusButton && statusButton,
                this.props.DashboardState.ShowGridInfoButton && gridInfoButton,
                shortcuts,
                this.props.DashboardState.ShowColumnsDropdown && columnsDropDown,
                this.props.DashboardState.ShowToolbarsDropdown && toolbarsDropDown)));
    };
    HomeToolbarControlComponent.prototype.onClick = function (menuItem) {
        this.props.onClick(menuItem.Action);
    };
    HomeToolbarControlComponent.prototype.onClickStatus = function () {
        var messageType = this.props.SystemStatus.StatusType;
        switch (messageType) {
            case Enums_1.MessageType.Success:
                var success = {
                    Header: 'System Status',
                    Msg: StringExtensions_1.StringExtensions.IsNotNullOrEmpty(this.props.SystemStatus.StatusMessage)
                        ? this.props.SystemStatus.StatusMessage
                        : 'No issues',
                    MessageType: Enums_1.MessageType.Success,
                    ShowAsPopup: true,
                };
                this.props.onShowStatusMessage(success);
                return;
            case Enums_1.MessageType.Info:
                var info = {
                    Header: 'System Status',
                    Msg: this.props.SystemStatus.StatusMessage,
                    MessageType: Enums_1.MessageType.Info,
                    ShowAsPopup: true,
                };
                this.props.onShowStatusMessage(info);
                return;
            case Enums_1.MessageType.Warning:
                var warning = {
                    Header: 'System Status',
                    Msg: this.props.SystemStatus.StatusMessage,
                    MessageType: Enums_1.MessageType.Warning,
                    ShowAsPopup: true,
                };
                this.props.onShowStatusMessage(warning);
                return;
            case Enums_1.MessageType.Error:
                var error = {
                    Header: 'System Status',
                    Msg: this.props.SystemStatus.StatusMessage,
                    MessageType: Enums_1.MessageType.Error,
                    ShowAsPopup: true,
                };
                this.props.onShowStatusMessage(error);
                return;
        }
    };
    HomeToolbarControlComponent.prototype.onClickGridInfo = function () {
        this.props.onShowGridInfo();
    };
    HomeToolbarControlComponent.prototype.onSetColumnVisibility = function (name) {
        var changedColumn = ColumnHelper_1.ColumnHelper.getColumnFromId(name, this.props.Columns);
        var columns = [].concat(this.props.Columns);
        changedColumn = Object.assign({}, changedColumn, {
            Visible: !changedColumn.Visible,
        });
        var index = columns.findIndex(function (x) { return x.ColumnId == name; });
        columns[index] = changedColumn;
        this.props.onNewColumnListOrder(columns.filter(function (c) { return c.Visible; }));
    };
    HomeToolbarControlComponent.prototype.onSetToolbarVisibility = function (name, checked) {
        var strategy = this.props.DashboardState.AvailableToolbars.find(function (at) { return at == name; });
        var visibleToolbars = [].concat(this.props.DashboardState.VisibleToolbars);
        if (checked) {
            visibleToolbars.push(strategy);
        }
        else {
            var index = visibleToolbars.findIndex(function (vt) { return vt == strategy; });
            visibleToolbars.splice(index, 1);
        }
        this.props.onSetToolbarVisibility(visibleToolbars);
    };
    return HomeToolbarControlComponent;
}(React.Component));
function mapStateToProps(state, ownProps) {
    return {
        MenuState: state.Menu,
        DashboardState: state.Dashboard,
        Columns: state.Grid.Columns,
        SystemStatus: state.System.SystemStatus,
    };
}
function mapDispatchToProps(dispatch) {
    return {
        onClick: function (action) { return dispatch(action); },
        onClose: function (dashboardControl) {
            return dispatch(DashboardRedux.DashboardHideToolbar(dashboardControl));
        },
        onConfigure: function () {
            return dispatch(PopupRedux.PopupShowScreen(StrategyConstants.HomeStrategyId, ScreenPopups.DashboardPopup));
        },
        onNewColumnListOrder: function (VisibleColumnList) {
            return dispatch(SystemRedux.SetNewColumnListOrder(VisibleColumnList));
        },
        onSetDashboardVisibility: function (visibility) {
            return dispatch(DashboardRedux.DashboardSetVisibility(visibility));
        },
        onSetToolbarVisibility: function (strategyIds) {
            return dispatch(DashboardRedux.DashboardSetToolbars(strategyIds));
        },
        onShowStatusMessage: function (alert) { return dispatch(PopupRedux.PopupShowAlert(alert)); },
        onShowGridInfo: function () { return dispatch(PopupRedux.PopupShowGridInfo()); },
    };
}
exports.HomeToolbarControl = react_redux_1.connect(mapStateToProps, mapDispatchToProps)(HomeToolbarControlComponent);
