"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var React = require("react");
var react_redux_1 = require("react-redux");
var LayoutRedux = require("../../Redux/ActionsReducers/LayoutRedux");
var PopupRedux = require("../../Redux/ActionsReducers/PopupRedux");
var DashboardRedux = require("../../Redux/ActionsReducers/DashboardRedux");
var ButtonSave_1 = require("../Components/Buttons/ButtonSave");
var ButtonDelete_1 = require("../Components/Buttons/ButtonDelete");
var ButtonNew_1 = require("../Components/Buttons/ButtonNew");
var ButtonUndo_1 = require("../Components/Buttons/ButtonUndo");
var PanelDashboard_1 = require("../Components/Panels/PanelDashboard");
var StrategyConstants = require("../../Utilities/Constants/StrategyConstants");
var ScreenPopups = require("../../Utilities/Constants/ScreenPopups");
var GeneralConstants = require("../../Utilities/Constants/GeneralConstants");
var ArrayExtensions_1 = require("../../Utilities/Extensions/ArrayExtensions");
var Enums_1 = require("../../PredefinedConfig/Common/Enums");
var Dropdown_1 = require("../../components/Dropdown");
var rebass_1 = require("rebass");
var LayoutToolbarControlComponent = /** @class */ (function (_super) {
    tslib_1.__extends(LayoutToolbarControlComponent, _super);
    function LayoutToolbarControlComponent() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    LayoutToolbarControlComponent.prototype.render = function () {
        var _this = this;
        var nonDefaultLayouts = this.props.Layouts.filter(function (l) { return l.Name != GeneralConstants.DEFAULT_LAYOUT; });
        var layoutEntity = nonDefaultLayouts.find(function (x) { return x.Name == _this.props.CurrentLayout || x.Uuid == _this.props.CurrentLayout; });
        var currentLayoutTitle = layoutEntity ? layoutEntity.Name : 'Select a Layout';
        var availableLayouts = nonDefaultLayouts.filter(function (l) { return l.Name != currentLayoutTitle; });
        var availableLayoutOptions = nonDefaultLayouts.map(function (layout, index) {
            return tslib_1.__assign({}, layout, { label: layout.Name, value: layout.Name });
        });
        if (this.isLayoutModified(layoutEntity)) {
            currentLayoutTitle += ' (Modified)';
        }
        var content = (React.createElement(rebass_1.Flex, { flexDirection: "row" },
            React.createElement(Dropdown_1.default, { disabled: availableLayoutOptions.length == 0, style: { minWidth: 160 }, marginRight: 2, placeholder: "Select Layout", value: layoutEntity ? layoutEntity.Name : null, options: availableLayoutOptions, onChange: function (layoutName) {
                    if (layoutName) {
                        _this.onLayoutChanged(layoutName);
                        return;
                    }
                    _this.onLayoutChanged(GeneralConstants.DEFAULT_LAYOUT);
                }, clearButtonProps: {
                    tooltip: 'Clear layout',
                    disabled: this.props.CurrentLayout == GeneralConstants.DEFAULT_LAYOUT,
                    AccessLevel: this.props.AccessLevel,
                }, showClearButton: this.props.CurrentLayout !== GeneralConstants.DEFAULT_LAYOUT }),
            React.createElement(rebass_1.Flex, { flexDirection: "row", className: this.props.AccessLevel == Enums_1.AccessLevel.ReadOnly ? GeneralConstants.READ_ONLY_STYLE : '' },
                React.createElement(ButtonSave_1.ButtonSave, { onClick: function () { return _this.onSave(); }, tooltip: "Save Changes to Current Layout", disabled: this.props.CurrentLayout == GeneralConstants.DEFAULT_LAYOUT, AccessLevel: this.props.AccessLevel }),
                React.createElement(ButtonNew_1.ButtonNew, { children: null, tone: "none", variant: "text", onClick: function () { return _this.props.onNewLayout(); }, tooltip: "Create a new Layout", AccessLevel: this.props.AccessLevel }),
                React.createElement(ButtonUndo_1.ButtonUndo, { onClick: function () { return _this.props.onSelectLayout(_this.props.CurrentLayout); }, tooltip: "Undo Layout Changes", disabled: !currentLayoutTitle.endsWith('(Modified)'), AccessLevel: this.props.AccessLevel }),
                React.createElement(ButtonDelete_1.ButtonDelete, { tooltip: "Delete Layout", disabled: this.props.CurrentLayout == GeneralConstants.DEFAULT_LAYOUT, ConfirmAction: LayoutRedux.LayoutDelete(layoutEntity), ConfirmationMsg: "Are you sure you want to delete '" + this.props.CurrentLayout + "'?", ConfirmationTitle: 'Delete Layout', AccessLevel: this.props.AccessLevel }))));
        return (React.createElement(PanelDashboard_1.PanelDashboard, { headerText: StrategyConstants.LayoutStrategyName, glyphicon: StrategyConstants.LayoutGlyph, onClose: function () { return _this.props.onClose(StrategyConstants.LayoutStrategyId); }, onConfigure: function () { return _this.props.onConfigure(); } }, content));
    };
    LayoutToolbarControlComponent.prototype.isLayoutModified = function (layoutEntity) {
        if (layoutEntity) {
            if (!ArrayExtensions_1.ArrayExtensions.areArraysEqualWithOrder(layoutEntity.Columns, this.props.Columns.filter(function (y) { return y.Visible; }).map(function (x) { return x.ColumnId; }))) {
                return true;
            }
            if (!ArrayExtensions_1.ArrayExtensions.areArraysEqualWithOrderandProperties(layoutEntity.ColumnSorts, this.props.ColumnSorts)) {
                return true;
            }
        }
        return false;
    };
    LayoutToolbarControlComponent.prototype.onLayoutChanged = function (layoutName) {
        this.props.onSelectLayout(layoutName);
    };
    LayoutToolbarControlComponent.prototype.onSelectedLayoutChanged = function (event) {
        var e = event.target;
        this.props.onSelectLayout(e.value);
    };
    LayoutToolbarControlComponent.prototype.onSave = function () {
        var _this = this;
        var currentLayoutObject = this.props.Layouts.find(function (l) { return l.Name == _this.props.CurrentLayout; });
        var gridState = currentLayoutObject ? currentLayoutObject.VendorGridInfo : null;
        var visibleColumns = this.props.Columns.filter(function (c) { return c.Visible; });
        var layoutToSave = {
            Uuid: currentLayoutObject.Uuid,
            Name: this.props.CurrentLayout,
            Columns: visibleColumns ? visibleColumns.map(function (x) { return x.ColumnId; }) : [],
            ColumnSorts: this.props.ColumnSorts,
            VendorGridInfo: gridState,
        };
        this.props.onSaveLayout(layoutToSave);
    };
    LayoutToolbarControlComponent.prototype.onUndo = function () {
        this.props.onSelectLayout(this.props.CurrentLayout);
    };
    return LayoutToolbarControlComponent;
}(React.Component));
function mapStateToProps(state, ownProps) {
    return {
        CurrentLayout: state.Layout.CurrentLayout,
        Layouts: state.Layout.Layouts,
    };
}
function mapDispatchToProps(dispatch) {
    return {
        onSelectLayout: function (layoutName) { return dispatch(LayoutRedux.LayoutSelect(layoutName)); },
        onSaveLayout: function (layout) { return dispatch(LayoutRedux.LayoutSave(layout)); },
        onNewLayout: function () {
            return dispatch(PopupRedux.PopupShowScreen(StrategyConstants.LayoutStrategyId, ScreenPopups.LayoutPopup, 'New'));
        },
        onClose: function (dashboardControl) {
            return dispatch(DashboardRedux.DashboardHideToolbar(dashboardControl));
        },
        onConfigure: function () {
            return dispatch(PopupRedux.PopupShowScreen(StrategyConstants.LayoutStrategyId, ScreenPopups.LayoutPopup));
        },
    };
}
exports.LayoutToolbarControl = react_redux_1.connect(mapStateToProps, mapDispatchToProps)(LayoutToolbarControlComponent);
