"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var React = require("react");
var Enums_1 = require("../../../PredefinedConfig/Common/Enums");
var EnumExtensions_1 = require("../../../Utilities/Extensions/EnumExtensions");
var StringExtensions_1 = require("../../../Utilities/Extensions/StringExtensions");
var Dropdown_1 = require("../../../components/Dropdown");
var rebass_1 = require("rebass");
var WizardPanel_1 = require("../../../components/WizardPanel");
var Input_1 = require("../../../components/Input");
var CheckBox_1 = require("../../../components/CheckBox");
var ReminderMessageWizard = /** @class */ (function (_super) {
    tslib_1.__extends(ReminderMessageWizard, _super);
    function ReminderMessageWizard(props) {
        var _this = _super.call(this, props) || this;
        _this.state = {
            Header: _this.props.Data.Alert.Header,
            Msg: _this.props.Data.Alert.Msg,
            MessageType: _this.props.Data.Alert.MessageType,
            ShowAsPopup: _this.props.Data.Alert.ShowAsPopup,
        };
        return _this;
    }
    ReminderMessageWizard.prototype.render = function () {
        var _this = this;
        var messageTypes = EnumExtensions_1.EnumExtensions.getNames(Enums_1.MessageType).map(function (type) {
            return {
                label: type,
                value: type,
            };
        });
        return (React.createElement("div", { style: { height: '100%' } },
            React.createElement(WizardPanel_1.default, null,
                React.createElement(rebass_1.Flex, { flexDirection: "column" },
                    React.createElement(rebass_1.Flex, { marginTop: 2, alignItems: "center" },
                        React.createElement(rebass_1.Text, { style: { flex: 2 }, textAlign: "end", marginRight: 2 }, "Header:"),
                        React.createElement(Input_1.default, { style: { flex: 7 }, value: this.state.Header, type: "string", placeholder: "Enter Reminder Header (optional)", onChange: function (e) { return _this.onHeaderChanged(e); } })),
                    React.createElement(rebass_1.Flex, { marginTop: 2, alignItems: "center" },
                        React.createElement(rebass_1.Text, { style: { flex: 2 }, textAlign: "end", marginRight: 2 }, "Message:"),
                        React.createElement(Input_1.default, { value: this.state.Msg, style: { flex: 7 }, type: "string", placeholder: "Enter Reminder Message", onChange: function (e) { return _this.onMessageChanged(e); } })),
                    React.createElement(rebass_1.Flex, { marginTop: 2, alignItems: "center" },
                        React.createElement(rebass_1.Text, { style: { flex: 2 }, textAlign: "end", marginRight: 2 }, "Message Type:"),
                        React.createElement(rebass_1.Box, { style: { flex: 7 } },
                            React.createElement(Dropdown_1.default, { style: { maxWidth: '100%' }, placeholder: "select", value: this.state.MessageType, onChange: function (value) { return _this.onMessageTypeChanged(value); }, options: messageTypes }, messageTypes))),
                    React.createElement(rebass_1.Flex, { marginTop: 2 },
                        React.createElement("div", { style: { flex: 2 } }),
                        React.createElement(rebass_1.Box, { style: { flex: 7 } },
                            React.createElement(CheckBox_1.default, { marginLeft: 2, checked: this.state.ShowAsPopup == true, onChange: function (checked) { return _this.onShowAsPopupChanged(checked); } }, "Show the Reminder as a Popup"),
                            ' '))))));
    };
    ReminderMessageWizard.prototype.onHeaderChanged = function (event) {
        var _this = this;
        var e = event.target;
        this.setState({ Header: e.value }, function () {
            return _this.props.UpdateGoBackState();
        });
    };
    ReminderMessageWizard.prototype.onMessageChanged = function (event) {
        var _this = this;
        var e = event.target;
        this.setState({ Msg: e.value }, function () {
            return _this.props.UpdateGoBackState();
        });
    };
    ReminderMessageWizard.prototype.onMessageTypeChanged = function (value) {
        var _this = this;
        this.setState({ MessageType: value }, function () {
            return _this.props.UpdateGoBackState();
        });
    };
    ReminderMessageWizard.prototype.onShowAsPopupChanged = function (checked) {
        var _this = this;
        this.setState({ ShowAsPopup: checked }, function () {
            return _this.props.UpdateGoBackState();
        });
    };
    ReminderMessageWizard.prototype.canNext = function () {
        return this.state.MessageType != null && StringExtensions_1.StringExtensions.IsNotNullOrEmpty(this.state.Msg);
    };
    ReminderMessageWizard.prototype.canBack = function () {
        return true;
    };
    ReminderMessageWizard.prototype.Next = function () {
        this.props.Data.Alert.Header = this.state.Header;
        this.props.Data.Alert.Msg = this.state.Msg;
        this.props.Data.Alert.MessageType = this.state.MessageType;
        this.props.Data.Alert.ShowAsPopup = this.state.ShowAsPopup;
    };
    ReminderMessageWizard.prototype.Back = function () {
        // todo
    };
    ReminderMessageWizard.prototype.GetIndexStepIncrement = function () {
        return 1;
    };
    ReminderMessageWizard.prototype.GetIndexStepDecrement = function () {
        return 1;
    };
    return ReminderMessageWizard;
}(React.Component));
exports.ReminderMessageWizard = ReminderMessageWizard;
