"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var EditableConfigEntityState_1 = require("./Components/SharedProps/EditableConfigEntityState");
var Enums_1 = require("../PredefinedConfig/Common/Enums");
var StringExtensions_1 = require("../Utilities/Extensions/StringExtensions");
var LoggingHelper_1 = require("../Utilities/Helpers/LoggingHelper");
var ArrayExtensions_1 = require("../Utilities/Extensions/ArrayExtensions");
var ExpressionHelper_1 = require("../Utilities/Helpers/ExpressionHelper");
function getDefaultColors() {
    return [
        '#000000',
        '#ffffff',
        '#C0C0C0',
        '#808080',
        '#800000',
        '#808000',
        '#008000',
        '#00FF00',
        '#FFFF00',
        '#FFFFCC',
        '#000080',
        '#0000FF',
        '#008080',
        '#00FFFF',
        '#FF00FF',
        '#800080',
        '#8B0000',
        '#FF0000',
        '#FF6961',
        '#FFA500',
    ];
}
exports.getDefaultColors = getDefaultColors;
function getEmptyConfigState() {
    return {
        EditedAdaptableBlotterObject: null,
        WizardStartIndex: 0,
        WizardStatus: EditableConfigEntityState_1.WizardStatus.None,
    };
}
exports.getEmptyConfigState = getEmptyConfigState;
function getExpressionBuilderState(expression) {
    // add any missing arrays here to avoid issues later
    ExpressionHelper_1.default.AddMissingProperties(expression);
    return {
        Expression: expression,
        SelectedColumnId: '',
        SelectedTab: null,
    };
}
exports.getExpressionBuilderState = getExpressionBuilderState;
function getExpressionBuilderStateWithColumn(expression, columnId) {
    return {
        Expression: expression,
        SelectedColumnId: columnId,
        SelectedTab: null,
    };
}
exports.getExpressionBuilderStateWithColumn = getExpressionBuilderStateWithColumn;
function getDescriptionForDataType(dataType) {
    switch (dataType) {
        case Enums_1.DataType.String:
            return 'string';
        case Enums_1.DataType.Number:
            return 'number';
        case Enums_1.DataType.Date:
            return 'date';
    }
}
exports.getDescriptionForDataType = getDescriptionForDataType;
function getPlaceHolderforDataType(dataType) {
    switch (dataType) {
        case Enums_1.DataType.String:
            return 'Enter Value';
        case Enums_1.DataType.Number:
            return 'Enter Number';
        case Enums_1.DataType.Date:
            return 'Enter Date';
    }
}
exports.getPlaceHolderforDataType = getPlaceHolderforDataType;
function getModalContainer(blotterOptions, document) {
    var modalContainer;
    if (blotterOptions.containerOptions.modalContainer) {
        // this has been set, so we use the property
        modalContainer = document.getElementById(blotterOptions.containerOptions.modalContainer);
        if (modalContainer) {
            var modalContainerClassName = ' modal-container';
            if (!modalContainer.className.includes(modalContainerClassName)) {
                modalContainer.className += modalContainerClassName;
            }
        }
    }
    if (!modalContainer) {
        modalContainer = document.body;
    }
    return modalContainer;
}
exports.getModalContainer = getModalContainer;
function getChartContainer(blotterOptions, document, showModal) {
    var chartContainer;
    if (StringExtensions_1.StringExtensions.IsNotNullOrEmpty(blotterOptions.containerOptions.chartContainer)) {
        // they have provided one so get that
        chartContainer = document.getElementById(blotterOptions.containerOptions.chartContainer);
        if (chartContainer) {
            var chartContainerClassName = ' chart-container';
            if (!chartContainer.className.includes(chartContainerClassName)) {
                chartContainer.className += chartContainerClassName;
            }
        }
        else {
            LoggingHelper_1.LoggingHelper.LogAdaptableBlotterError("Chart div called '" + blotterOptions.containerOptions.chartContainer + "' not found: so creating standard div");
            chartContainer = document.getElementById('ad');
        }
    }
    else {
        // not provided one so return whole document if modal, or 'chart' if not
        chartContainer = showModal ? document.body : document.getElementById('ad');
    }
    return chartContainer;
}
exports.getChartContainer = getChartContainer;
function isValidUserChartContainer(blotterOptions, document) {
    if (StringExtensions_1.StringExtensions.IsNotNullOrEmpty(blotterOptions.containerOptions.chartContainer)) {
        return document.getElementById(blotterOptions.containerOptions.chartContainer) != null;
    }
    return false;
}
exports.isValidUserChartContainer = isValidUserChartContainer;
function IsNotEmptyStyle(style) {
    return (style.BackColor != null ||
        style.ForeColor != null ||
        style.FontWeight != Enums_1.FontWeight.Normal ||
        style.FontStyle != Enums_1.FontStyle.Normal ||
        style.FontSize != null ||
        StringExtensions_1.StringExtensions.IsNotNullOrEmpty(style.ClassName));
}
exports.IsNotEmptyStyle = IsNotEmptyStyle;
function getMessageTypeByStatusColour(statusColour) {
    switch (statusColour) {
        case Enums_1.StatusColour.Red:
            return Enums_1.MessageType.Error;
        case Enums_1.StatusColour.Amber:
            return Enums_1.MessageType.Warning;
        case Enums_1.StatusColour.Green:
            return Enums_1.MessageType.Success;
        case Enums_1.StatusColour.Blue:
            return Enums_1.MessageType.Info;
    }
}
exports.getMessageTypeByStatusColour = getMessageTypeByStatusColour;
function getGlyphByMessageType(messageType) {
    switch (messageType) {
        case Enums_1.MessageType.Info:
            return 'info';
        case Enums_1.MessageType.Success:
            return 'check';
        case Enums_1.MessageType.Warning:
            return 'warning';
        case Enums_1.MessageType.Error:
            return 'error';
    }
}
exports.getGlyphByMessageType = getGlyphByMessageType;
function getColorByMessageType(messageType) {
    switch (messageType) {
        case Enums_1.MessageType.Error:
            return 'var(--ab-color-error)';
        case Enums_1.MessageType.Warning:
            return 'var(--ab-color-warn)';
        case Enums_1.MessageType.Success:
            return 'var(--ab-color-success)';
        case Enums_1.MessageType.Info:
            return 'var(--ab-color-info)';
    }
}
exports.getColorByMessageType = getColorByMessageType;
function getStyleForStatusColour(statusColour) {
    var result;
    switch (statusColour) {
        case Enums_1.StatusColour.Blue:
            result = {
                fill: 'var(--ab-color-info)',
            };
            break;
        case Enums_1.StatusColour.Green:
            result = {
                fill: 'var(--ab-color-success)',
            };
            break;
        case Enums_1.StatusColour.Amber:
            result = {
                fill: 'var(--ab-color-warn)',
            };
            break;
        case Enums_1.StatusColour.Red:
            result = {
                fill: 'var(--ab-color-error)',
            };
            break;
    }
    if (result) {
        result.color = result.fill;
    }
    return result;
}
exports.getStyleForStatusColour = getStyleForStatusColour;
function getStyleForMessageType(messageType) {
    var result;
    switch (messageType) {
        case Enums_1.MessageType.Info:
            result = {
                fill: 'var(--ab-color-info)',
            };
            break;
        case Enums_1.MessageType.Success:
            result = {
                fill: 'var(--ab-color-success)',
            };
            break;
        case Enums_1.MessageType.Warning:
            result = {
                fill: 'var(--ab-color-warn)',
            };
            break;
        case Enums_1.MessageType.Error:
            result = {
                fill: 'var(--ab-color-error)',
            };
            break;
    }
    if (result) {
        result.color = result.fill;
    }
    return result;
}
exports.getStyleForMessageType = getStyleForMessageType;
function getGlyphForStatusColour(statusColour) {
    switch (statusColour) {
        case Enums_1.StatusColour.Blue:
            return 'info';
        case Enums_1.StatusColour.Green:
            return 'check';
        case Enums_1.StatusColour.Amber:
            return 'warning';
        case Enums_1.StatusColour.Red:
            return 'error';
    }
}
exports.getGlyphForStatusColour = getGlyphForStatusColour;
function getGlyphForMessageType(messageType) {
    switch (messageType) {
        case Enums_1.MessageType.Info:
            return 'info';
        case Enums_1.MessageType.Success:
            return 'check';
        case Enums_1.MessageType.Warning:
            return 'warning';
        case Enums_1.MessageType.Error:
            return 'error';
    }
}
exports.getGlyphForMessageType = getGlyphForMessageType;
function getScheduleDescription(schedule) {
    if (schedule == null) {
        return '[No Schedule]';
    }
    var dateString;
    if (schedule.OneOffDate == null) {
        if (ArrayExtensions_1.default.ContainsItem(schedule.DaysOfWeek, Enums_1.DayOfWeek.Monday) &&
            ArrayExtensions_1.default.ContainsItem(schedule.DaysOfWeek, Enums_1.DayOfWeek.Tuesday) &&
            ArrayExtensions_1.default.ContainsItem(schedule.DaysOfWeek, Enums_1.DayOfWeek.Wednesday) &&
            ArrayExtensions_1.default.ContainsItem(schedule.DaysOfWeek, Enums_1.DayOfWeek.Thursday) &&
            ArrayExtensions_1.default.ContainsItem(schedule.DaysOfWeek, Enums_1.DayOfWeek.Friday)) {
            if (ArrayExtensions_1.default.ContainsItem(schedule.DaysOfWeek, Enums_1.DayOfWeek.Sunday) &&
                ArrayExtensions_1.default.ContainsItem(schedule.DaysOfWeek, Enums_1.DayOfWeek.Saturday)) {
                dateString = 'Everyday';
            }
            else {
                dateString = 'Weekdays';
            }
        }
        else {
            var names = schedule.DaysOfWeek.sort().map(function (d) { return Enums_1.DayOfWeek[d]; });
            dateString = ArrayExtensions_1.default.createCommaSeparatedString(names);
        }
    }
    else {
        dateString = new Date(schedule.OneOffDate).toDateString();
    }
    return dateString + " at " + addLeadingZero(schedule.Hour) + ":" + addLeadingZero(schedule.Minute);
}
exports.getScheduleDescription = getScheduleDescription;
function addLeadingZero(item) {
    item = item || 0;
    if (item < 10) {
        return "0" + (item && item.toString ? item.toString() : item);
    }
    return item.toString();
}
exports.UIHelper = {
    getDefaultColors: getDefaultColors,
    getEmptyConfigState: getEmptyConfigState,
    getExpressionBuilderState: getExpressionBuilderState,
    getExpressionBuilderStateWithColumn: getExpressionBuilderStateWithColumn,
    getDescriptionForDataType: getDescriptionForDataType,
    getPlaceHolderforDataType: getPlaceHolderforDataType,
    getModalContainer: getModalContainer,
    getChartContainer: getChartContainer,
    isValidUserChartContainer: isValidUserChartContainer,
    IsNotEmptyStyle: IsNotEmptyStyle,
    getMessageTypeByStatusColour: getMessageTypeByStatusColour,
    getGlyphByMessageType: getGlyphByMessageType,
    getStyleForStatusColour: getStyleForStatusColour,
    getGlyphForStatusColour: getGlyphForStatusColour,
    getScheduleDescription: getScheduleDescription,
    getColorByMessageType: getColorByMessageType,
    getGlyphForMessageType: getGlyphForMessageType,
    getStyleForMessageType: getStyleForMessageType,
};
exports.default = exports.UIHelper;
