"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var ArrayExtensions_1 = require("../Utilities/Extensions/ArrayExtensions");
var StringExtensions_1 = require("../Utilities/Extensions/StringExtensions");
var ActionColumnRenderer = /** @class */ (function () {
    function ActionColumnRenderer() {
    }
    // gets called once before the renderer is used
    ActionColumnRenderer.prototype.init = function (params) {
        var blotter = params.api.__blotter;
        var actionCol = blotter.api.actionColumnApi
            .getAllActionColumn()
            .find(function (ac) { return ac.ColumnId == params.colDef.colId; });
        if (actionCol) {
            // create the cell
            this.eGui = document.createElement('div');
            this.eGui.style.display = 'inline-block';
            var renderFunc = void 0;
            if (StringExtensions_1.default.IsNotNullOrEmpty(actionCol.RenderFunctionName)) {
                if (ArrayExtensions_1.default.IsNotNullOrEmpty(blotter.blotterOptions.advancedOptions.userFunctions.actionColumnFunctions)) {
                    renderFunc = blotter.blotterOptions.advancedOptions.userFunctions.actionColumnFunctions.find(function (acf) { return acf.name == actionCol.RenderFunctionName; });
                }
            }
            if (renderFunc) {
                var satisfyFunction = renderFunc.func;
                this.eGui.innerHTML = satisfyFunction(params, blotter);
            }
            else {
                this.eGui.innerHTML =
                    '<span class="my-css-class"><button class="btn-simple">' +
                        actionCol.ButtonText +
                        '</button></span>';
            }
            // add event listener to button
            this.eventListener = function () {
                var eventArgs = {
                    actionColumn: actionCol,
                    primaryKeyValue: blotter.getPrimaryKeyValueFromRecord(params.node),
                    rowData: params.data,
                };
                blotter.api.eventApi._onActionColumnClicked.Dispatch(blotter, eventArgs);
            };
            this.eGui.addEventListener('click', this.eventListener);
        }
    };
    // gets called once when grid ready to insert the element
    ActionColumnRenderer.prototype.getGui = function () {
        return this.eGui;
    };
    // gets called whenever the user gets the cell to refresh
    ActionColumnRenderer.prototype.refresh = function (params) {
        // return true to tell the grid we refreshed successfully
        return true;
    };
    // gets called when the cell is removed from the grid
    ActionColumnRenderer.prototype.destroy = function () {
        // do cleanup, remove event listener from button
        if (this.eGui) {
            this.eGui.removeEventListener('click', this.eventListener);
        }
    };
    return ActionColumnRenderer;
}());
exports.ActionColumnRenderer = ActionColumnRenderer;
