"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var ag_grid_community_1 = require("ag-grid-community");
require("ag-grid-enterprise");
var ReactDOM = require("react-dom");
var _ = require("lodash");
var eventKeys_1 = require("ag-grid-community/dist/lib/eventKeys");
var Emitter_1 = require("../Utilities/Emitter");
var AdaptableBlotterView_1 = require("../View/AdaptableBlotterView");
var icons_1 = require("../components/icons");
var StrategyConstants = require("../Utilities/Constants/StrategyConstants");
var StyleConstants = require("../Utilities/Constants/StyleConstants");
var ScreenPopups = require("../Utilities/Constants/ScreenPopups");
var AdaptableBlotterStore_1 = require("../Redux/Store/AdaptableBlotterStore");
var MenuRedux = require("../Redux/ActionsReducers/MenuRedux");
var GridRedux = require("../Redux/ActionsReducers/GridRedux");
var SystemRedux = require("../Redux/ActionsReducers/SystemRedux");
var PopupRedux = require("../Redux/ActionsReducers/PopupRedux");
var AuditLogService_1 = require("../Utilities/Services/AuditLogService");
var StyleService_1 = require("../Utilities/Services/StyleService");
var CalendarService_1 = require("../Utilities/Services/CalendarService");
var DataService_1 = require("../Utilities/Services/DataService");
var ValidationService_1 = require("../Utilities/Services/ValidationService");
var ChartService_1 = require("../Utilities/Services/ChartService");
var FreeTextColumnService_1 = require("../Utilities/Services/FreeTextColumnService");
var CalculatedColumnExpressionService_1 = require("../Utilities/Services/CalculatedColumnExpressionService");
// components
var FilterWrapper_1 = require("./FilterWrapper");
var FloatingFilterWrapper_1 = require("./FloatingFilterWrapper");
var Enums_1 = require("../PredefinedConfig/Common/Enums");
var ObjectFactory_1 = require("../Utilities/ObjectFactory");
var color_1 = require("../Utilities/color");
// Helpers
var iPushPullHelper_1 = require("../Utilities/Helpers/iPushPullHelper");
var ColumnHelper_1 = require("../Utilities/Helpers/ColumnHelper");
var StyleHelper_1 = require("../Utilities/Helpers/StyleHelper");
var LayoutHelper_1 = require("../Utilities/Helpers/LayoutHelper");
var ExpressionHelper_1 = require("../Utilities/Helpers/ExpressionHelper");
var LoggingHelper_1 = require("../Utilities/Helpers/LoggingHelper");
var StringExtensions_1 = require("../Utilities/Extensions/StringExtensions");
var ArrayExtensions_1 = require("../Utilities/Extensions/ArrayExtensions");
var Helper_1 = require("../Utilities/Helpers/Helper");
var RangeHelper_1 = require("../Utilities/Helpers/RangeHelper");
var BlotterHelper_1 = require("../Utilities/Helpers/BlotterHelper");
var BlotterApi_1 = require("../Api/BlotterApi");
var GeneralConstants_1 = require("../Utilities/Constants/GeneralConstants");
var CellValidationHelper_1 = require("../Utilities/Helpers/CellValidationHelper");
var agGridHelper_1 = require("./agGridHelper");
var CalculatedColumnHelper_1 = require("../Utilities/Helpers/CalculatedColumnHelper");
var AdaptableBlotterToolPanel_1 = require("../View/Components/ToolPanel/AdaptableBlotterToolPanel");
var ScheduleService_1 = require("../Utilities/Services/ScheduleService");
var Glue42Helper_1 = require("../Utilities/Helpers/Glue42Helper");
var SearchService_1 = require("../Utilities/Services/SearchService");
var Uuid_1 = require("../PredefinedConfig/Uuid");
var ActionColumnRenderer_1 = require("./ActionColumnRenderer");
var RowNodeProto = ag_grid_community_1.RowNode.prototype;
var RowNode_dispatchLocalEvent = RowNodeProto.dispatchLocalEvent;
var AdaptableBlotter = /** @class */ (function () {
    function AdaptableBlotter(blotterOptions, renderGrid, runtimeConfig) {
        var _this = this;
        if (renderGrid === void 0) { renderGrid = true; }
        this.calculatedColumnPathMap = new Map();
        this.on = function (eventName, callback) {
            return _this.emitter.on(eventName, callback);
        };
        this.emit = function (eventName, data) { return _this.emitter.emit(eventName, data); };
        // debounced methods
        this.debouncedSetColumnIntoStore = _.debounce(function () { return _this.setColumnIntoStore(); }, GeneralConstants_1.HALF_SECOND);
        this.debouncedSaveGridLayout = _.debounce(function () { return _this.saveGridLayout(); }, GeneralConstants_1.HALF_SECOND);
        this.debouncedSetSelectedCells = _.debounce(function () { return _this.setSelectedCells(); }, GeneralConstants_1.HALF_SECOND);
        this.debouncedSetSelectedRows = _.debounce(function () { return _this.setSelectedRows(); }, GeneralConstants_1.HALF_SECOND);
        this.debouncedFilterGrid = _.debounce(function () { return _this.applyGridFiltering(); }, GeneralConstants_1.HALF_SECOND);
        this.emitter = new Emitter_1.default();
        this.renderGrid = renderGrid;
        // we create the Blotter Options by merging the values provided by the user with the defaults (where no value has been set)
        this.blotterOptions = BlotterHelper_1.BlotterHelper.assignBlotterOptions(blotterOptions);
        BlotterHelper_1.BlotterHelper.CheckBlotterOptions(this.blotterOptions);
        this.runtimeConfig = runtimeConfig;
        this.gridOptions = this.blotterOptions.vendorGrid;
        this.vendorGridName = 'agGrid';
        this.embedColumnMenu = true;
        this.isInitialised = false;
        this.hasQuickFilter = true;
        this.useRowNodeLookUp = false; // we will set later in instantiate if possible to be true
        // get the api ready
        this.api = new BlotterApi_1.BlotterApi(this);
        // data source needs to be created before Audit Log Service
        this.DataService = new DataService_1.DataService(this);
        // the audit service needs to be created before the store
        this.AuditLogService = new AuditLogService_1.AuditLogService(this);
        // create the store
        this.initStore();
        // set up the helper
        this.agGridHelper = new agGridHelper_1.agGridHelper(this, this.gridOptions);
        // create the services
        this.CalendarService = new CalendarService_1.CalendarService(this);
        this.ValidationService = new ValidationService_1.ValidationService(this);
        this.StyleService = new StyleService_1.StyleService(this);
        this.ChartService = new ChartService_1.ChartService(this);
        this.FreeTextColumnService = new FreeTextColumnService_1.FreeTextColumnService(this);
        this.ScheduleService = new ScheduleService_1.ScheduleService(this);
        this.SearchService = new SearchService_1.SearchService(this);
        this.CalculatedColumnExpressionService = new CalculatedColumnExpressionService_1.CalculatedColumnExpressionService(this, function (columnId, record) { return _this.gridOptions.api.getValue(columnId, record); });
        // we prefer the grid to be NOT instantiated so that we can do it
        // perhaps in future we will force instantiation only?
        var isGridInstantiated = this.gridOptions.api && typeof this.gridOptions.api.getValue === 'function';
        if (!isGridInstantiated) {
            var canInstantiateGrid = this.tryInstantiateAgGrid();
            if (!canInstantiateGrid) {
                // we have no grid, we can't do anything
                LoggingHelper_1.LoggingHelper.LogAdaptableBlotterError('Unable to set up ag-Grid');
                return;
            }
        }
        // add our blotter to the grid options api object
        // this is VERY useful for when we need to access the Blotter inside of agGrid only functions
        if (this.gridOptions.api) {
            this.gridOptions.api.__blotter = this;
        }
        // set up iPushPull
        iPushPullHelper_1.iPushPullHelper.init(this.blotterOptions.iPushPullConfig);
        // set up Glue42 - note this is currently not working in the browser but will be done shortly
        if (Glue42Helper_1.Glue42Helper.isRunningGlue42()) {
            Glue42Helper_1.Glue42Helper.init();
        }
        // Set up strategies - we set up all the strategies suitable for the vendor grid
        // But users can make some hidden or readonly in their entitlements
        this.strategies = this.agGridHelper.setUpStrategies();
        // Load the store
        this.adaptableBlotterStore.Load.then(function () { return _this.strategies.forEach(function (strat) { return strat.initializeWithRedux(); }); }, function (e) {
            LoggingHelper_1.LoggingHelper.LogAdaptableBlotterError('Failed to Init AdaptableBlotterStore : ', e);
            // for now we initiliaze the strategies even if loading state has failed (perhaps revisit this?)
            _this.strategies.forEach(function (strat) { return strat.initializeWithRedux(); });
            _this.dispatchAction(PopupRedux.PopupHideLoading()); // doesnt really help but at least clears the screen
        })
            .then(function () { return _this.initInternalGridLogic(); }, function (e) {
            LoggingHelper_1.LoggingHelper.LogAdaptableBlotterError('Failed to Init Strategies : ', e);
            // for now we initiliaze the grid even if initialising strategies has failed (perhaps revisit this?)
            _this.initInternalGridLogic();
            _this.dispatchAction(PopupRedux.PopupHideLoading()); // doesnt really help but at least clears the screen
        })
            .then(function () {
            _this.applyFinalRendering();
            _this.isInitialised = true;
            _this.dispatchAction(PopupRedux.PopupHideLoading());
        });
        if (renderGrid) {
            if (this.abContainerElement == null) {
                this.abContainerElement = this.getBlotterContainerElement();
            }
            if (this.abContainerElement != null) {
                this.abContainerElement.innerHTML = '';
                ReactDOM.render(AdaptableBlotterView_1.AdaptableBlotterApp({ AdaptableBlotter: this }), this.abContainerElement);
            }
        }
        // create debounce methods that take a time based on user settings
        this.throttleOnDataChangedUser = _.throttle(this.applyDataChange, this.blotterOptions.filterOptions.filterActionOnUserDataChange.ThrottleDelay);
        this.throttleOnDataChangedExternal = _.throttle(this.applyDataChange, this.blotterOptions.filterOptions.filterActionOnExternalDataChange.ThrottleDelay);
    }
    AdaptableBlotter.prototype.initStore = function () {
        var _this = this;
        this.adaptableBlotterStore = new AdaptableBlotterStore_1.AdaptableBlotterStore(this);
        this.adaptableBlotterStore.onAny(function (eventName) {
            if (eventName == AdaptableBlotterStore_1.INIT_STATE) {
                _this.emit(GeneralConstants_1.BLOTTER_READY_EVENT);
            }
        });
    };
    AdaptableBlotter.prototype.tryInstantiateAgGrid = function () {
        var vendorContainer = this.getGridContainerElement();
        if (!vendorContainer) {
            LoggingHelper_1.LoggingHelper.LogAdaptableBlotterError('You must provide an element id in `containerOptions.vendorContainer`');
            return false;
        }
        // set up whether we use the getRowNode method or loop when finding a record (former is preferable)
        // can only do that here as the gridOptions not yet set up
        this.useRowNodeLookUp = this.agGridHelper.TrySetUpNodeIds();
        // Create Adaptable Blotter Tool Panel
        if (this.blotterOptions.generalOptions.showAdaptableBlotterToolPanel) {
            LoggingHelper_1.LoggingHelper.LogAdaptableBlotterInfo('Adding Adaptable Blotter Tool Panel');
            this.gridOptions.sideBar = this.gridOptions.sideBar || {};
            this.gridOptions.components = this.gridOptions.components || {};
            // https://www.ag-grid.com/javascript-grid-side-bar/
            if (this.gridOptions.sideBar) {
                var sidebar = this.gridOptions.sideBar;
                if (sidebar === true) {
                    // Possibility 1: Sidebar is true - meaning that they want the default filter and columns, so create both:
                    this.gridOptions.sideBar = this.agGridHelper.createAdaptableBlotterSideBarDefs(true, true);
                }
                else if (sidebar === 'columns') {
                    // Possibility 2: Sidebar is 'columns' (string) - meaning column only so create just that
                    this.gridOptions.sideBar = this.agGridHelper.createAdaptableBlotterSideBarDefs(false, true);
                }
                else if (sidebar === 'filters') {
                    // Possibility 3: Sidebar is 'filters' (string) - meaning filters only so create just that
                    this.gridOptions.sideBar = this.agGridHelper.createAdaptableBlotterSideBarDefs(true, false);
                }
                else {
                    // Possibilty 4: either no sidebar or they created their own; in either case, should add Blotter Tool panel
                    var sidebarDef = this.gridOptions.sideBar;
                    if (sidebarDef) {
                        sidebarDef.toolPanels = sidebarDef.toolPanels || [];
                        sidebarDef.toolPanels.push(this.agGridHelper.createAdaptableBlotterToolPanel());
                    }
                }
                var toolpanelContext = { Blotter: this };
                this.gridOptions.components.adaptableBlotterToolPanel = AdaptableBlotterToolPanel_1.AdaptableBlotterToolPanelBuilder(toolpanelContext);
            }
        }
        // now create the grid itself - we have to do it this way as previously when we instantiated the Grid 'properly' it got created as J.Grid
        // console.log('creating the grid as not created by user')
        var grid;
        if (this.runtimeConfig && this.runtimeConfig.instantiateGrid) {
            grid = this.runtimeConfig.instantiateGrid(vendorContainer, this.gridOptions);
        }
        else {
            grid = new ag_grid_community_1.Grid(vendorContainer, this.gridOptions);
        }
        // global.grid = grid;
        return grid != null;
    };
    AdaptableBlotter.prototype.filterOnUserDataChange = function () {
        if (this.blotterOptions.filterOptions.filterActionOnUserDataChange.RunFilter ==
            Enums_1.FilterOnDataChangeOptions.Always) {
            this.applyDataChange();
        }
        else if (this.blotterOptions.filterOptions.filterActionOnUserDataChange.RunFilter ==
            Enums_1.FilterOnDataChangeOptions.Throttle) {
            this.throttleOnDataChangedUser();
        }
    };
    AdaptableBlotter.prototype.filterOnExternalDataChange = function () {
        if (this.blotterOptions.filterOptions.filterActionOnExternalDataChange.RunFilter ==
            Enums_1.FilterOnDataChangeOptions.Always) {
            this.applyDataChange();
        }
        else if (this.blotterOptions.filterOptions.filterActionOnExternalDataChange.RunFilter ==
            Enums_1.FilterOnDataChangeOptions.Throttle) {
            this.throttleOnDataChangedExternal();
        }
    };
    AdaptableBlotter.prototype.createFilterWrapper = function (col) {
        this.gridOptions.api.destroyFilter(col);
        this.gridOptions.api.getColumnDef(col).filter = FilterWrapper_1.FilterWrapperFactory(this);
        col.initialise();
    };
    AdaptableBlotter.prototype.createQuickFilterWrapper = function (col) {
        this.gridOptions.api.getColumnDef(col).floatingFilterComponentParams = {
            suppressFilterButton: false,
        };
        this.gridOptions.api.getColumnDef(col).floatingFilterComponent = FloatingFilterWrapper_1.FloatingFilterWrapperFactory(this);
    };
    AdaptableBlotter.prototype.reloadGrid = function () {
        this.emit(GeneralConstants_1.GRID_RELOADED_EVENT);
    };
    AdaptableBlotter.prototype.applyGridFiltering = function () {
        this.gridOptions.api.onFilterChanged();
        this.emit(GeneralConstants_1.SEARCH_APPLIED_EVENT);
        this.emit(GeneralConstants_1.GRID_REFRESHED_EVENT);
    };
    AdaptableBlotter.prototype.applyDataChange = function () {
        this.gridOptions.api.onFilterChanged();
        this.emit(GeneralConstants_1.GRID_REFRESHED_EVENT);
    };
    AdaptableBlotter.prototype.clearGridFiltering = function () {
        this.gridOptions.columnApi.getAllColumns().forEach(function (c) {
            c.setFilterActive(false);
        });
    };
    AdaptableBlotter.prototype.clearColumnFiltering = function (columnIds) {
        var _this = this;
        columnIds.forEach(function (c) {
            var column = _this.gridOptions.columnApi
                .getAllColumns()
                .find(function (col) { return col.getColId() == c; });
            if (column) {
                column.setFilterActive(false);
            }
        });
    };
    AdaptableBlotter.prototype.hideFilterForm = function () {
        if (this.hideFilterFormPopup) {
            this.hideFilterFormPopup();
        }
    };
    AdaptableBlotter.prototype.setNewColumnListOrder = function (VisibleColumnList) {
        var _this = this;
        var allColumns = this.gridOptions.columnApi.getAllGridColumns();
        var startIndex = 0;
        //  this is not quite right as it assumes that only the first column can be grouped
        //  but lets do this for now and then refine and refactor later to deal with weirder use cases
        if (ColumnHelper_1.ColumnHelper.isSpecialColumn(allColumns[0].getColId())) {
            startIndex++;
        }
        VisibleColumnList.forEach(function (column, index) {
            var col = _this.gridOptions.columnApi.getColumn(column.ColumnId);
            if (!col) {
                LoggingHelper_1.LoggingHelper.LogAdaptableBlotterError("Cannot find vendor column:" + column.ColumnId);
            }
            if (!col.isVisible()) {
                _this.setColumnVisible(_this.gridOptions.columnApi, col, true, 'api');
            }
            _this.moveColumn(_this.gridOptions.columnApi, col, startIndex + index, 'api');
        });
        allColumns
            .filter(function (x) { return VisibleColumnList.findIndex(function (y) { return y.ColumnId == x.getColId(); }) < 0; })
            .forEach(function (col) {
            _this.setColumnVisible(_this.gridOptions.columnApi, col, false, 'api');
        });
        // we need to do this to make sure agGrid and Blotter column collections are in sync
        this.setColumnIntoStore();
    };
    AdaptableBlotter.prototype.setColumnIntoStore = function () {
        var _this = this;
        var allColumns = [];
        var existingColumns = this.api.gridApi.getColumns();
        var vendorCols = this.gridOptions.columnApi.getAllGridColumns();
        var quickSearchClassName = this.getQuickSearchClassName();
        vendorCols.forEach(function (vendorColumn) {
            var colId = vendorColumn.getColId();
            if (!ColumnHelper_1.ColumnHelper.isSpecialColumn(colId)) {
                var existingColumn = ColumnHelper_1.ColumnHelper.getColumnFromId(colId, existingColumns);
                if (existingColumn) {
                    existingColumn.Visible = vendorColumn.isVisible();
                    if (existingColumn.DataType == Enums_1.DataType.Unknown) {
                        existingColumn.DataType = _this.getColumnDataType(vendorColumn);
                    }
                }
                else {
                    existingColumn = _this.createColumn(vendorColumn, quickSearchClassName);
                }
                allColumns.push(existingColumn);
            }
        });
        this.dispatchAction(GridRedux.GridSetColumns(allColumns));
        // Save the layout if required
        LayoutHelper_1.LayoutHelper.autoSaveLayout(this);
    };
    AdaptableBlotter.prototype.createColumn = function (vendorColumn, quickSearchClassName) {
        var colId = vendorColumn.getColId();
        var abColumn = {
            Uuid: Uuid_1.createUuid(),
            ColumnId: colId,
            FriendlyName: this.gridOptions.columnApi.getDisplayNameForColumn(vendorColumn, 'header'),
            DataType: this.getColumnDataType(vendorColumn),
            Visible: vendorColumn.isVisible(),
            ReadOnly: this.isColumnReadonly(colId),
            Sortable: this.isColumnSortable(colId),
            Filterable: this.isColumnFilterable(colId),
        };
        this.addQuickSearchStyleToColumn(abColumn, quickSearchClassName);
        this.addFiltersToVendorColumn(vendorColumn);
        return abColumn;
    };
    AdaptableBlotter.prototype.addFiltersToVendorColumn = function (vendorColumn) {
        if (vendorColumn.getColDef().filter &&
            this.blotterOptions.filterOptions.useAdaptableBlotterFilterForm) {
            this.createFilterWrapper(vendorColumn);
        }
        if (this.gridOptions.floatingFilter &&
            this.blotterOptions.filterOptions.useAdaptableBlotterQuickFilter) {
            this.createQuickFilterWrapper(vendorColumn);
        }
    };
    AdaptableBlotter.prototype.getQuickSearchClassName = function () {
        var quickSearchClassName = StringExtensions_1.StringExtensions.IsNotNullOrEmpty(this.api.quickSearchApi.getQuickSearchStyle().ClassName)
            ? this.api.quickSearchApi.getQuickSearchStyle().ClassName
            : StyleHelper_1.StyleHelper.CreateStyleName(StrategyConstants.QuickSearchStrategyId, this);
        return quickSearchClassName;
    };
    AdaptableBlotter.prototype.addQuickSearchStyleToColumn = function (col, quickSearchClassName) {
        var blotter = this;
        var cellClassRules = {};
        cellClassRules[quickSearchClassName] = function (params) {
            if (params.node && !params.node.group) {
                var columnId = params.colDef.field ? params.colDef.field : params.colDef.colId;
                var quickSearchState = blotter.api.quickSearchApi.getQuickSearchState();
                if (StringExtensions_1.StringExtensions.IsNotNullOrEmpty(quickSearchState.QuickSearchText) &&
                    (quickSearchState.DisplayAction == Enums_1.DisplayAction.HighlightCell ||
                        quickSearchState.DisplayAction == Enums_1.DisplayAction.ShowRowAndHighlightCell)) {
                    var range = RangeHelper_1.RangeHelper.CreateValueRangeFromOperand(quickSearchState.QuickSearchText);
                    if (range) {
                        // not right but just checking...
                        if (RangeHelper_1.RangeHelper.IsColumnAppropriateForRange(range.Operator, col)) {
                            var expression = ExpressionHelper_1.ExpressionHelper.CreateSingleColumnExpression(columnId, null, null, null, [range]);
                            if (ExpressionHelper_1.ExpressionHelper.checkForExpressionFromRecord(expression, params.node, [col], blotter)) {
                                return true;
                            }
                        }
                    }
                }
            }
            return false;
        };
        this.setCellClassRules(cellClassRules, col.ColumnId, 'QuickSearch');
    };
    AdaptableBlotter.prototype.createMainMenu = function () {
        var menuItems = [];
        this.strategies.forEach(function (x) {
            var menuItem = x.getPopupMenuItem();
            if (menuItem != null && menuItem != undefined) {
                if (menuItems.findIndex(function (m) { return m.StrategyId == menuItem.StrategyId; }) == -1) {
                    menuItems.push(menuItem);
                }
            }
        });
        this.dispatchAction(MenuRedux.SetMainMenuItems(menuItems));
    };
    AdaptableBlotter.prototype.getPrimaryKeyValueFromRecord = function (record) {
        return this.gridOptions.api.getValue(this.blotterOptions.primaryKey, record);
    };
    AdaptableBlotter.prototype.gridHasCurrentEditValue = function () {
        if (this._currentEditor) {
            return true;
        }
        return false;
    };
    AdaptableBlotter.prototype.getCurrentCellEditValue = function () {
        // TODO: Jo: This is a workaround as we are accessing private members of agGrid.
        // Currently used by Shortcut to get the current edit value - is there a better way?
        if (this._currentEditor) {
            return this._currentEditor.getValue();
        }
        return '';
    };
    AdaptableBlotter.prototype.getActiveCell = function () {
        var activeCell = this.gridOptions.api.getFocusedCell();
        if (activeCell) {
            var rowNode = this.gridOptions.api.getModel().getRow(activeCell.rowIndex);
            // if the selected cell is from a group cell we don't return it
            // that's a design choice as this is used only when editing and you cant edit those cells
            if (rowNode && !rowNode.group) {
                return {
                    columnId: activeCell.column.getColId(),
                    primaryKeyValue: this.getPrimaryKeyValueFromRecord(rowNode),
                    value: this.gridOptions.api.getValue(activeCell.column, rowNode),
                };
            }
        }
    };
    AdaptableBlotter.prototype.saveGridLayout = function () {
        if (this.blotterOptions.layoutOptions != null &&
            this.blotterOptions.layoutOptions.includeVendorStateInLayouts != null &&
            this.blotterOptions.layoutOptions.includeVendorStateInLayouts) {
            LayoutHelper_1.LayoutHelper.autoSaveLayout(this);
        }
    };
    // This method returns selected cells ONLY (if selection mode is cells or multiple cells).
    // If the selection mode is row it will returns nothing - use the setSelectedRows() method
    AdaptableBlotter.prototype.setSelectedCells = function () {
        var _this = this;
        var selected = this.gridOptions.api.getCellRanges();
        var columns = [];
        var selectedCells = [];
        if (selected) {
            // we iterate for each ranges
            selected.forEach(function (rangeSelection, index) {
                var e_1, _a;
                var y1 = Math.min(rangeSelection.startRow.rowIndex, rangeSelection.endRow.rowIndex);
                var y2 = Math.max(rangeSelection.startRow.rowIndex, rangeSelection.endRow.rowIndex);
                try {
                    for (var _b = tslib_1.__values(rangeSelection.columns), _c = _b.next(); !_c.done; _c = _b.next()) {
                        var column = _c.value;
                        if (column != null) {
                            var colId = column.getColId();
                            if (index == 0) {
                                var selectedColumn = ColumnHelper_1.ColumnHelper.getColumnFromId(colId, _this.api.gridApi.getColumns());
                                columns.push(selectedColumn);
                            }
                            for (var rowIndex = y1; rowIndex <= y2; rowIndex++) {
                                var rowNode = _this.gridOptions.api.getModel().getRow(rowIndex);
                                // if the selected cells are from a group cell we don't return it
                                // that's a design choice as this is used only when editing and you cant edit those cells
                                if (rowNode && !rowNode.group) {
                                    var primaryKey = _this.getPrimaryKeyValueFromRecord(rowNode);
                                    var value = _this.gridOptions.api.getValue(column, rowNode);
                                    var selectedCell = {
                                        columnId: colId,
                                        value: value,
                                        primaryKeyValue: primaryKey,
                                    };
                                    selectedCells.push(selectedCell);
                                }
                            }
                        }
                    }
                }
                catch (e_1_1) { e_1 = { error: e_1_1 }; }
                finally {
                    try {
                        if (_c && !_c.done && (_a = _b.return)) _a.call(_b);
                    }
                    finally { if (e_1) throw e_1.error; }
                }
            });
        }
        var selectedCellInfo = { Columns: columns, GridCells: selectedCells };
        this.dispatchAction(GridRedux.GridSetSelectedCells(selectedCellInfo));
        this.emit(GeneralConstants_1.CELLS_SELECTED_EVENT);
        this.agGridHelper.fireSelectionChangedEvent();
    };
    AdaptableBlotter.prototype.setSelectedRows = function () {
        var _this = this;
        var nodes = this.gridOptions.api.getSelectedNodes();
        var selectedRows = [];
        if (ArrayExtensions_1.ArrayExtensions.IsNotNullOrEmpty(nodes)) {
            nodes.forEach(function (node) {
                var rowInfo = {
                    isMaster: !!(node.master != null && node.master == true),
                    isExpanded: !!(node.expanded != null && node.expanded == true),
                    isGroup: !!(node.group != null && node.group == true),
                    level: node.level,
                };
                var gridRow = {
                    primaryKeyValue: _this.getPrimaryKeyValueFromRecord(node),
                    rowData: node.data,
                    rowInfo: rowInfo,
                };
                selectedRows.push(gridRow);
            });
        }
        var selectedRowInfo = { GridRows: selectedRows };
        this.dispatchAction(GridRedux.GridSetSelectedRows(selectedRowInfo));
        this.emit(GeneralConstants_1.ROWS_SELECTED_EVENT);
        this.agGridHelper.fireSelectionChangedEvent();
    };
    // We deduce the type here, as there is no way to get it through the definition
    AdaptableBlotter.prototype.getColumnDataType = function (column) {
        var _this = this;
        // Some columns can have no ID or Title. we return string as a consequence but it needs testing
        if (!column) {
            LoggingHelper_1.LoggingHelper.LogAdaptableBlotterWarning('column is undefined returning String for Type');
            return Enums_1.DataType.String;
        }
        // get the column type if already in store (and not unknown)
        var existingColumn = ColumnHelper_1.ColumnHelper.getColumnFromId(column.getId(), this.api.gridApi.getColumns());
        if (existingColumn && existingColumn.DataType != Enums_1.DataType.Unknown) {
            return existingColumn.DataType;
        }
        // check for column type
        var colType = column.getColDef().type;
        if (colType) {
            var isArray = Array.isArray(colType);
            if (isArray) {
                // do array check
                var myDatatype_1 = Enums_1.DataType.Unknown;
                colType.forEach(function (c) {
                    if (c == 'numericColumn') {
                        myDatatype_1 = Enums_1.DataType.Number;
                    }
                    if (c.startsWith('abColDef')) {
                        myDatatype_1 = _this.getabColDefValue(c);
                    }
                });
                if (myDatatype_1 != Enums_1.DataType.Unknown) {
                    return myDatatype_1;
                }
            }
            else {
                // do string check
                if (colType == 'numericColumn') {
                    return Enums_1.DataType.Number;
                }
                if (colType.startsWith('abColDef')) {
                    return this.getabColDefValue(colType);
                }
            }
        }
        var model = this.gridOptions.api.getModel();
        if (model == null) {
            LoggingHelper_1.LoggingHelper.LogAdaptableBlotterWarning("No model so returning type \"Unknown\" for Column: \"" + column.getColId() + "\"");
            return Enums_1.DataType.Unknown;
        }
        var row = model.getRow(0);
        if (row == null) {
            // possible that there will be no data.
            LoggingHelper_1.LoggingHelper.LogAdaptableBlotterWarning("No data in grid so returning type \"Unknown\" for Column: \"" + column.getColId() + "\"");
            return Enums_1.DataType.Unknown;
        }
        // if it's a group we need the content of the group
        if (row.group) {
            var childNodes = row.childrenAfterGroup;
            if (ArrayExtensions_1.ArrayExtensions.IsNullOrEmpty(childNodes)) {
                LoggingHelper_1.LoggingHelper.LogAdaptableBlotterWarning("No data in grid so returning type \"Unknown\" for Column: \"" + column.getColId() + "\"");
                return Enums_1.DataType.Unknown;
            }
            row = childNodes[0];
        }
        var value = this.gridOptions.api.getValue(column, row);
        var dataType;
        if (value instanceof Date) {
            dataType = Enums_1.DataType.Date;
        }
        else {
            switch (typeof value) {
                case 'string':
                    dataType = Enums_1.DataType.String;
                    break;
                case 'number':
                    dataType = Enums_1.DataType.Number;
                    break;
                case 'boolean':
                    dataType = Enums_1.DataType.Boolean;
                    break;
                case 'object':
                    dataType = Enums_1.DataType.Object;
                    break;
                default:
                    break;
            }
        }
        LoggingHelper_1.LoggingHelper.LogAdaptableBlotterWarning("No defined type for column '" + column.getColId() + "'. Defaulting to type of first value: " + dataType);
        return dataType;
    };
    AdaptableBlotter.prototype.getabColDefValue = function (colType) {
        switch (colType) {
            case 'abColDefNumber':
                return Enums_1.DataType.Number;
            case 'abColDefString':
                return Enums_1.DataType.String;
            case 'abColDefBoolean':
                return Enums_1.DataType.Boolean;
            case 'abColDefDate':
                return Enums_1.DataType.Date;
            case 'abColDefObject':
                return Enums_1.DataType.Object;
        }
    };
    AdaptableBlotter.prototype.setValue = function (gridCell) {
        var _this = this;
        if (this.useRowNodeLookUp) {
            var rowNode = this.gridOptions.api.getRowNode(gridCell.primaryKeyValue);
            if (rowNode != null) {
                this.updateValue(gridCell, rowNode);
            }
        }
        else {
            var isUpdated_1 = false;
            // prefer not to use this method but if we do then at least we can prevent further lookups once we find
            this.gridOptions.api.getModel().forEachNode(function (rowNode) {
                if (!isUpdated_1) {
                    if (gridCell.primaryKeyValue == _this.getPrimaryKeyValueFromRecord(rowNode)) {
                        _this.updateValue(gridCell, rowNode);
                        isUpdated_1 = true;
                    }
                }
            });
        }
        this.filterOnUserDataChange();
        this.gridOptions.api.clearRangeSelection();
    };
    AdaptableBlotter.prototype.updateValue = function (gridCell, rowNode) {
        var oldValue = this.gridOptions.api.getValue(gridCell.columnId, rowNode);
        rowNode.setDataValue(gridCell.columnId, gridCell.value);
        var dataChangedEvent = {
            OldValue: oldValue,
            NewValue: gridCell.value,
            ColumnId: gridCell.columnId,
            IdentifierValue: gridCell.primaryKeyValue,
            Record: rowNode,
        };
        if (this.AuditLogService.isAuditCellEditsEnabled) {
            this.AuditLogService.addEditCellAuditLog(dataChangedEvent);
        }
        this.FreeTextColumnService.CheckIfDataChangingColumnIsFreeText(dataChangedEvent);
        this.DataService.CreateDataChangedEvent(dataChangedEvent);
    };
    // this is used by strategies to update the grid
    // not sure why do it this way and not just get it updated through the event
    AdaptableBlotter.prototype.setValueBatch = function (gridCellBatch) {
        var _this = this;
        if (ArrayExtensions_1.ArrayExtensions.IsNullOrEmpty(gridCellBatch)) {
            return;
        }
        var dataChangedEvents = [];
        var nodesToRefresh = [];
        var refreshColumnList = [];
        var percentBars = this.api.percentBarApi.getAllPercentBar();
        // now two ways to do this - one using pk lookup and other using foreach on row node
        if (this.useRowNodeLookUp) {
            gridCellBatch.forEach(function (gridCell) {
                var rowNode = _this.gridOptions.api.getRowNode(gridCell.primaryKeyValue);
                if (rowNode) {
                    _this.updateBatchValue(gridCell, rowNode, nodesToRefresh, refreshColumnList, dataChangedEvents, percentBars);
                }
            });
        }
        else {
            this.gridOptions.api.getModel().forEachNode(function (rowNode) {
                var gridCell = gridCellBatch.find(function (x) { return x.primaryKeyValue == _this.getPrimaryKeyValueFromRecord(rowNode); });
                if (gridCell) {
                    _this.updateBatchValue(gridCell, rowNode, nodesToRefresh, refreshColumnList, dataChangedEvents, percentBars);
                }
            });
        }
        if (this.AuditLogService.isAuditCellEditsEnabled) {
            this.AuditLogService.addEditCellAuditLogBatch(dataChangedEvents);
        }
        this.FreeTextColumnService.CheckIfDataChangingColumnIsFreeTextBatch(dataChangedEvents);
        dataChangedEvents.forEach(function (dc) { return _this.DataService.CreateDataChangedEvent(dc); });
        this.filterOnUserDataChange();
        this.refreshCells(nodesToRefresh, refreshColumnList);
        // we want to reselect the cells that are selected so that users can repeat actions
        // we do this by gettng the selected cells, clearing the selection and then re-applying
        //  agGridHelper.reselectSelectedCells();
        var selectedCellRanges = this.gridOptions.api.getCellRanges();
        if (ArrayExtensions_1.ArrayExtensions.CorrectLength(selectedCellRanges, 1)) {
            var selectedCellRange = selectedCellRanges[0];
            var cellRangeParams = {
                rowStartIndex: selectedCellRange.startRow.rowIndex,
                rowEndIndex: selectedCellRange.endRow.rowIndex,
                columns: selectedCellRange.columns,
            };
            this.gridOptions.api.clearRangeSelection();
            this.gridOptions.api.addCellRange(cellRangeParams);
        }
    };
    AdaptableBlotter.prototype.updateBatchValue = function (gridCell, rowNode, nodesToRefresh, refreshColumnList, dataChangedEvents, percentBars) {
        var colId = gridCell.columnId;
        refreshColumnList.push(colId);
        nodesToRefresh.push(rowNode);
        ArrayExtensions_1.ArrayExtensions.AddItem(refreshColumnList, colId);
        var oldValue = this.gridOptions.api.getValue(colId, rowNode);
        var data = rowNode.data;
        data[colId] = gridCell.value;
        var dataChangedEvent = {
            OldValue: oldValue,
            NewValue: gridCell.value,
            ColumnId: colId,
            IdentifierValue: gridCell.primaryKeyValue,
            Record: rowNode,
        };
        dataChangedEvents.push(dataChangedEvent);
        // check if any calc columns need to refresh
        var columnList = this.calculatedColumnPathMap.get(colId);
        if (columnList) {
            columnList.forEach(function (calcColumn) {
                ArrayExtensions_1.ArrayExtensions.AddItem(refreshColumnList, calcColumn);
            });
        }
        // see if we need to refresh any percent bars
        percentBars.forEach(function (pb) {
            refreshColumnList.forEach(function (changedColId) {
                if (StringExtensions_1.StringExtensions.IsNotNullOrEmpty(pb.MaxValueColumnId) &&
                    pb.MaxValueColumnId == changedColId) {
                    ArrayExtensions_1.ArrayExtensions.AddItem(refreshColumnList, pb.ColumnId);
                }
                if (StringExtensions_1.StringExtensions.IsNotNullOrEmpty(pb.MinValueColumnId) &&
                    pb.MinValueColumnId == changedColId) {
                    ArrayExtensions_1.ArrayExtensions.AddItem(refreshColumnList, pb.ColumnId);
                }
            });
        });
    };
    AdaptableBlotter.prototype.cancelEdit = function () {
        this.gridOptions.api.stopEditing(true);
    };
    AdaptableBlotter.prototype.getRecordIsSatisfiedFunction = function (id, distinctCriteria) {
        var _this = this;
        if (distinctCriteria == Enums_1.DistinctCriteriaPairValue.RawValue) {
            var rowNode_1;
            if (this.useRowNodeLookUp) {
                rowNode_1 = this.gridOptions.api.getRowNode(id);
            }
            else {
                var foundRow_1 = false;
                this.gridOptions.api.getModel().forEachNode(function (node) {
                    if (!foundRow_1 && id == _this.getPrimaryKeyValueFromRecord(node)) {
                        rowNode_1 = node;
                        foundRow_1 = true;
                    }
                });
            }
            return function (columnId) { return _this.gridOptions.api.getValue(columnId, rowNode_1); };
        }
        return function (columnId) { return _this.getDisplayValue(id, columnId); };
    };
    AdaptableBlotter.prototype.getRecordIsSatisfiedFunctionFromRecord = function (record, distinctCriteria) {
        var _this = this;
        if (distinctCriteria == Enums_1.DistinctCriteriaPairValue.RawValue) {
            return function (columnId) { return _this.gridOptions.api.getValue(columnId, record); };
        }
        return function (columnId) { return _this.getDisplayValueFromRecord(record, columnId); };
    };
    AdaptableBlotter.prototype.isColumnReadonly = function (columnId) {
        // same as hypergrid. we do not support the fact that some rows are editable and some are not
        // if editable is a function then we return that its not readonly since we assume that some record will be editable
        // that's wrong but we ll see if we face the issue later
        var colDef = this.gridOptions.api.getColumnDef(columnId);
        if (colDef && typeof colDef.editable === 'boolean') {
            return !colDef.editable;
        }
        return true;
    };
    AdaptableBlotter.prototype.isColumnSortable = function (columnId) {
        // follow agGrid logic which is that ONLY if sortable explicitly set to false do you suppress sort
        var colDef = this.gridOptions.api.getColumnDef(columnId);
        if (colDef.sortable != null) {
            return colDef.sortable;
        }
        return true;
    };
    AdaptableBlotter.prototype.isColumnFilterable = function (columnId) {
        // follow agGrid logic which is that ONLY filterable if one explicitly set
        var colDef = this.gridOptions.api.getColumnDef(columnId);
        return colDef.filter != null && colDef.filter != false;
    };
    AdaptableBlotter.prototype.setCustomSort = function (columnId, comparer) {
        var sortModel = this.gridOptions.api.getSortModel();
        var columnDef = this.gridOptions.api.getColumnDef(columnId);
        if (columnDef) {
            columnDef.comparator = comparer;
        }
        this.gridOptions.api.setSortModel(sortModel);
    };
    AdaptableBlotter.prototype.removeCustomSort = function (columnId) {
        var sortModel = this.gridOptions.api.getSortModel();
        var columnDef = this.gridOptions.api.getColumnDef(columnId);
        if (columnDef) {
            columnDef.comparator = null;
        }
        this.gridOptions.api.setSortModel(sortModel);
    };
    AdaptableBlotter.prototype.getColumnValueDisplayValuePairDistinctList = function (columnId, distinctCriteria, visibleRowsOnly) {
        var _this = this;
        var returnMap = new Map();
        // check if there are permitted column values for that column
        // NB.  this currently contains a small bug as we dont check for visibility so if using permitted values then ALL are returned :(
        var permittedValuesForColumn = this.api.userInterfaceApi.getPermittedValuesForColumn(columnId);
        if (permittedValuesForColumn != undefined) {
            permittedValuesForColumn.PermittedValues.forEach(function (pv) {
                returnMap.set(pv, { RawValue: pv, DisplayValue: pv });
            });
        }
        else {
            var useRawValue_1 = this.useRawValueForColumn(columnId);
            if (visibleRowsOnly) {
                this.gridOptions.api.forEachNodeAfterFilter(function (rowNode) {
                    _this.addDistinctColumnValue(rowNode, columnId, useRawValue_1, distinctCriteria, returnMap);
                });
            }
            else {
                this.gridOptions.api.forEachNode(function (rowNode) {
                    _this.addDistinctColumnValue(rowNode, columnId, useRawValue_1, distinctCriteria, returnMap);
                });
            }
        }
        return Array.from(returnMap.values()).slice(0, this.blotterOptions.queryOptions.maxColumnValueItemsDisplayed);
    };
    AdaptableBlotter.prototype.addDistinctColumnValue = function (rowNode, columnId, useRawValue, distinctCriteria, returnMap) {
        // we do not return the values of the aggregates when in grouping mode
        // otherwise they would appear in the filter dropdown etc....
        if (!rowNode.group) {
            var rawValue = this.gridOptions.api.getValue(columnId, rowNode);
            var displayValue = useRawValue
                ? Helper_1.Helper.StringifyValue(rawValue)
                : this.getDisplayValueFromRecord(rowNode, columnId);
            if (distinctCriteria == Enums_1.DistinctCriteriaPairValue.RawValue) {
                returnMap.set(rawValue, { RawValue: rawValue, DisplayValue: displayValue });
            }
            else {
                returnMap.set(displayValue, { RawValue: rawValue, DisplayValue: displayValue });
            }
        }
    };
    AdaptableBlotter.prototype.useRawValueForColumn = function (columnId) {
        // we need to return false if the column has a cell rendeerer i think...
        var colDef = this.gridOptions.api.getColumnDef(columnId);
        if (colDef) {
            if (colDef.cellRenderer != null) {
                return true;
            }
        }
        // will add more in due course I'm sure but for now only percent bar columns return false...
        var percentBars = this.api.percentBarApi.getAllPercentBar();
        if (ArrayExtensions_1.ArrayExtensions.IsEmpty(percentBars)) {
            return false;
        }
        return ArrayExtensions_1.ArrayExtensions.ContainsItem(percentBars.map(function (pb) { return pb.ColumnId; }), columnId);
    };
    AdaptableBlotter.prototype.getDisplayValue = function (id, columnId) {
        var _this = this;
        var returnValue;
        if (this.useRowNodeLookUp) {
            var rowNode = this.gridOptions.api.getRowNode(id);
            returnValue = this.getDisplayValueFromRecord(rowNode, columnId);
        }
        else {
            var foundRow_2 = false;
            this.gridOptions.api.getModel().forEachNode(function (rowNode) {
                if (!foundRow_2 && id == _this.getPrimaryKeyValueFromRecord(rowNode)) {
                    returnValue = _this.getDisplayValueFromRecord(rowNode, columnId);
                    foundRow_2 = true;
                }
            });
        }
        return returnValue;
    };
    AdaptableBlotter.prototype.getDisplayValueFromRecord = function (row, columnId) {
        if (row == null) {
            return '';
        }
        var rawValue = this.gridOptions.api.getValue(columnId, row);
        if (this.useRawValueForColumn(columnId)) {
            return Helper_1.Helper.StringifyValue(rawValue);
        }
        return this.getDisplayValueFromRawValue(columnId, rawValue);
    };
    AdaptableBlotter.prototype.getDisplayValueFromRawValue = function (columnId, rawValue) {
        var colDef = this.gridOptions.api.getColumnDef(columnId);
        if (colDef) {
            if (colDef.valueFormatter) {
                var column = this.gridOptions.columnApi
                    .getAllColumns()
                    .find(function (c) { return c.getColId() == columnId; });
                var formatter = colDef.valueFormatter;
                var params = {
                    value: rawValue,
                    node: null,
                    data: null,
                    colDef: colDef,
                    column: column,
                    api: this.gridOptions.api,
                    columnApi: this.gridOptions.columnApi,
                    context: null,
                };
                var formattedValue = formatter(params);
                if (colDef.cellRenderer) {
                    return this.getRenderedValue(colDef, formattedValue);
                }
                return formattedValue || '';
            }
            if (colDef.cellRenderer) {
                return this.getRenderedValue(colDef, rawValue);
            }
        }
        return this.agGridHelper.getCleanValue(rawValue);
    };
    AdaptableBlotter.prototype.getRenderedValue = function (colDef, valueToRender) {
        return this.agGridHelper.getRenderedValue(this.api.percentBarApi.getAllPercentBar(), colDef, valueToRender);
    };
    AdaptableBlotter.prototype.getRawValueFromRecord = function (row, columnId) {
        return this.gridOptions.api.getValue(columnId, row);
    };
    AdaptableBlotter.prototype.getDataRowFromRecord = function (record) {
        var rowNode = record;
        return rowNode != null && rowNode != undefined ? rowNode.data : undefined;
    };
    AdaptableBlotter.prototype.setCellClassRules = function (cellClassRules, columnId, type) {
        var localCellClassRules = this.gridOptions.columnApi.getColumn(columnId).getColDef()
            .cellClassRules;
        if (localCellClassRules) {
            if (type == 'FormatColumn') {
                for (var prop in localCellClassRules) {
                    if (prop.includes(StrategyConstants.FormatColumnStrategyId)) {
                        delete localCellClassRules[prop];
                    }
                }
            }
            else if (type == 'ConditionalStyle') {
                var cssStyles = this.api.conditionalStyleApi
                    .getAllConditionalStyle()
                    .map(function (c) { return c.Style.ClassName; });
                for (var prop in localCellClassRules) {
                    if (prop.includes(StrategyConstants.ConditionalStyleStrategyId) ||
                        ArrayExtensions_1.ArrayExtensions.ContainsItem(cssStyles, prop)) {
                        delete localCellClassRules[prop];
                    }
                }
            }
            // Is initialized in setColumnIntoStore
            else if (type == 'QuickSearch') {
                for (var prop in localCellClassRules) {
                    if (prop.includes(StrategyConstants.QuickSearchStrategyId)) {
                        delete localCellClassRules[prop];
                    }
                }
            }
            // Is initialized in Flash
            else if (type == 'FlashingCell') {
                for (var prop in localCellClassRules) {
                    if (prop.includes(StyleConstants.FLASH_UP_STYLE)) {
                        delete localCellClassRules[prop];
                    }
                    if (prop.includes(StyleConstants.FLASH_DOWN_STYLE)) {
                        delete localCellClassRules[prop];
                    }
                }
            }
            for (var prop in cellClassRules) {
                localCellClassRules[prop] = cellClassRules[prop];
            }
        }
        else {
            this.gridOptions.columnApi.getColumn(columnId).getColDef().cellClassRules = cellClassRules;
        }
    };
    AdaptableBlotter.prototype.forAllRecordsDo = function (func) {
        this.gridOptions.api.getModel().forEachNode(function (rowNode) {
            func(rowNode);
        });
    };
    AdaptableBlotter.prototype.forAllVisibleRecordsDo = function (func) {
        this.gridOptions.api.forEachNodeAfterFilterAndSort(function (rowNode) {
            func(rowNode);
        });
    };
    AdaptableBlotter.prototype.redraw = function () {
        this.gridOptions.api.redrawRows();
        this.gridOptions.api.refreshHeader();
        this.emit(GeneralConstants_1.GRID_REFRESHED_EVENT);
    };
    AdaptableBlotter.prototype.testredrawRow = function (rowNode) {
        this.gridOptions.api.redrawRows({ rowNodes: [rowNode] });
    };
    AdaptableBlotter.prototype.refreshCells = function (rows, columnIds) {
        var refreshCellParams = {
            rowNodes: rows,
            columns: columnIds,
            force: true,
        };
        this.gridOptions.api.refreshCells(refreshCellParams);
    };
    AdaptableBlotter.prototype.editCalculatedColumnInGrid = function (calculatedColumn) {
        var e_2, _a, e_3, _b;
        var _this = this;
        // the name of the column might have changed so lets get the column from store as that will be the 'old' one
        var cols = this.api.gridApi.getColumns();
        var existingABColumn = cols.find(function (c) { return c.Uuid == calculatedColumn.Uuid; });
        if (existingABColumn) {
            // now get the ag-Grid ColDef Index
            var colDefs = this.gridOptions.columnApi.getAllColumns().map(function (x) { return x.getColDef(); });
            var colDefIndex = colDefs.findIndex(function (x) { return x.headerName == existingABColumn.ColumnId; });
            // clean the expression in case it got dirty
            var cleanedExpression_1 = CalculatedColumnHelper_1.CalculatedColumnHelper.cleanExpressionColumnNames(calculatedColumn.ColumnExpression, cols);
            var newColDef = colDefs[colDefIndex];
            //  change the value getter in the coldefs
            newColDef.valueGetter = function (params) {
                return Helper_1.Helper.RoundValueIfNumeric(_this.CalculatedColumnExpressionService.ComputeExpressionValue(cleanedExpression_1, params.node), 4);
            };
            // reset the name in case its changed
            newColDef.headerName = calculatedColumn.ColumnId;
            newColDef.colId = calculatedColumn.ColumnId;
            colDefs[colDefIndex] = newColDef;
            this.agGridHelper.safeSetColDefs(colDefs);
            try {
                // for column list its an itnernal map only so we can first delete
                for (var _c = tslib_1.__values(this.calculatedColumnPathMap.values()), _d = _c.next(); !_d.done; _d = _c.next()) {
                    var columnList_2 = _d.value;
                    var index = columnList_2.indexOf(calculatedColumn.ColumnId);
                    if (index > -1) {
                        columnList_2.splice(index, 1);
                    }
                }
            }
            catch (e_2_1) { e_2 = { error: e_2_1 }; }
            finally {
                try {
                    if (_d && !_d.done && (_a = _c.return)) _a.call(_c);
                }
                finally { if (e_2) throw e_2.error; }
            }
            // and then add
            var columnList = CalculatedColumnHelper_1.CalculatedColumnHelper.getColumnListFromExpression(cleanedExpression_1);
            try {
                for (var columnList_1 = tslib_1.__values(columnList), columnList_1_1 = columnList_1.next(); !columnList_1_1.done; columnList_1_1 = columnList_1.next()) {
                    var column = columnList_1_1.value;
                    var childrenColumnList = this.calculatedColumnPathMap.get(column);
                    if (!childrenColumnList) {
                        childrenColumnList = [];
                        this.calculatedColumnPathMap.set(column, childrenColumnList);
                    }
                    childrenColumnList.push(calculatedColumn.ColumnId);
                }
            }
            catch (e_3_1) { e_3 = { error: e_3_1 }; }
            finally {
                try {
                    if (columnList_1_1 && !columnList_1_1.done && (_b = columnList_1.return)) _b.call(columnList_1);
                }
                finally { if (e_3) throw e_3.error; }
            }
            // finally the name of the column or the datatype might have changed so lets update the column in the store to be sure
            // re-apply the datatype in case it has been changed as a result of the expression changing
            existingABColumn.ColumnId = calculatedColumn.ColumnId;
            existingABColumn.DataType = this.CalculatedColumnExpressionService.GetCalculatedColumnDataType(cleanedExpression_1);
            this.dispatchAction(GridRedux.GridAddColumn(existingABColumn));
        }
    };
    AdaptableBlotter.prototype.removeCalculatedColumnFromGrid = function (calculatedColumnID) {
        var e_4, _a;
        var colDefs = this.gridOptions.columnApi.getAllColumns().map(function (x) { return x.getColDef(); });
        var colDefIndex = colDefs.findIndex(function (x) { return x.headerName == calculatedColumnID; });
        if (colDefIndex > -1) {
            colDefs.splice(colDefIndex, 1);
            this.agGridHelper.safeSetColDefs(colDefs);
        }
        try {
            for (var _b = tslib_1.__values(this.calculatedColumnPathMap.values()), _c = _b.next(); !_c.done; _c = _b.next()) {
                var columnList = _c.value;
                var index = columnList.indexOf(calculatedColumnID);
                if (index > -1) {
                    columnList.splice(index, 1);
                }
            }
        }
        catch (e_4_1) { e_4 = { error: e_4_1 }; }
        finally {
            try {
                if (_c && !_c.done && (_a = _b.return)) _a.call(_b);
            }
            finally { if (e_4) throw e_4.error; }
        }
        this.setColumnIntoStore();
    };
    AdaptableBlotter.prototype.addCalculatedColumnToGrid = function (calculatedColumn) {
        var e_5, _a;
        var _this = this;
        var venderCols = this.gridOptions.columnApi.getAllColumns();
        var colDefs = venderCols.map(function (x) { return x.getColDef(); });
        var cols = this.api.gridApi.getColumns();
        var cleanedExpression = CalculatedColumnHelper_1.CalculatedColumnHelper.cleanExpressionColumnNames(calculatedColumn.ColumnExpression, cols);
        var newColDef = {
            headerName: calculatedColumn.ColumnId,
            colId: calculatedColumn.ColumnId,
            hide: true,
            enableValue: true,
            editable: false,
            filter: true,
            resizable: true,
            sortable: true,
            valueGetter: function (params) {
                return Helper_1.Helper.RoundValueIfNumeric(_this.CalculatedColumnExpressionService.ComputeExpressionValue(cleanedExpression, params.node), 4);
            },
        };
        // if (pcr.ShowToolTip != null && pcr.ShowToolTip == true) {
        newColDef.tooltipField = 'changeOnYear';
        // for now NOT using this PercentBarTooltip but we can add it later and will be powwerful.
        //  coldDef.tooltipComponent = PercentBarTooltip;
        // } else {
        //   coldDef.tooltipField = '';
        // }
        colDefs.push(newColDef);
        this.agGridHelper.safeSetColDefs(colDefs);
        var columnList = CalculatedColumnHelper_1.CalculatedColumnHelper.getColumnListFromExpression(cleanedExpression);
        try {
            for (var columnList_3 = tslib_1.__values(columnList), columnList_3_1 = columnList_3.next(); !columnList_3_1.done; columnList_3_1 = columnList_3.next()) {
                var column = columnList_3_1.value;
                var childrenColumnList = this.calculatedColumnPathMap.get(column);
                if (!childrenColumnList) {
                    childrenColumnList = [];
                    this.calculatedColumnPathMap.set(column, childrenColumnList);
                }
                childrenColumnList.push(calculatedColumn.ColumnId);
            }
        }
        catch (e_5_1) { e_5 = { error: e_5_1 }; }
        finally {
            try {
                if (columnList_3_1 && !columnList_3_1.done && (_a = columnList_3.return)) _a.call(columnList_3);
            }
            finally { if (e_5) throw e_5.error; }
        }
        var dataType = this.CalculatedColumnExpressionService.GetCalculatedColumnDataType(cleanedExpression);
        this.addSpecialColumnToState(calculatedColumn.Uuid, calculatedColumn.ColumnId, dataType);
    };
    AdaptableBlotter.prototype.addFreeTextColumnToGrid = function (freeTextColumn) {
        var _this = this;
        var venderCols = this.gridOptions.columnApi.getAllColumns();
        var colDefs = venderCols.map(function (x) { return x.getColDef(); });
        var newColDef = {
            headerName: freeTextColumn.ColumnId,
            colId: freeTextColumn.ColumnId,
            editable: true,
            hide: true,
            filter: true,
            sortable: true,
            resizable: true,
            cellEditor: 'agLargeTextCellEditor',
            valueGetter: function (params) {
                return _this.FreeTextColumnService.GetFreeTextValue(freeTextColumn, params.node);
            },
        };
        colDefs.push(newColDef);
        this.agGridHelper.safeSetColDefs(colDefs);
        this.addSpecialColumnToState(freeTextColumn.Uuid, freeTextColumn.ColumnId, Enums_1.DataType.String);
    };
    AdaptableBlotter.prototype.addActionColumnToGrid = function (actionColumn) {
        var venderCols = this.gridOptions.columnApi.getAllColumns();
        var colDefs = venderCols.map(function (x) { return x.getColDef(); });
        var newColDef = {
            headerName: actionColumn.ColumnId,
            colId: actionColumn.ColumnId,
            editable: false,
            hide: false,
            filter: false,
            sortable: false,
            resizable: true,
            cellRenderer: ActionColumnRenderer_1.ActionColumnRenderer,
        };
        colDefs.push(newColDef);
        this.agGridHelper.safeSetColDefs(colDefs);
        this.addSpecialColumnToState(actionColumn.Uuid, actionColumn.ColumnId, Enums_1.DataType.String);
    };
    AdaptableBlotter.prototype.addSpecialColumnToState = function (uuid, columnId, dataType) {
        var vendorColumn = this.gridOptions
            .columnApi.getAllColumns()
            .find(function (vc) { return vc.getColId() == columnId; });
        if (vendorColumn) {
            var vendorColDef = vendorColumn.getColDef();
            var specialColumn = {
                Uuid: uuid,
                ColumnId: columnId,
                FriendlyName: columnId,
                DataType: dataType,
                Visible: false,
                ReadOnly: !vendorColDef.editable,
                Sortable: vendorColDef.sortable,
                Filterable: vendorColDef.filter,
            };
            if (this.isQuickFilterActive()) {
                this.createQuickFilterWrapper(vendorColumn);
                this.gridOptions.api.refreshHeader();
            }
            this.dispatchAction(GridRedux.GridAddColumn(specialColumn));
            var quickSearchClassName = this.getQuickSearchClassName();
            this.addQuickSearchStyleToColumn(specialColumn, quickSearchClassName);
            this.addFiltersToVendorColumn(vendorColumn);
            if (this.isInitialised) {
                var conditionalStyleagGridStrategy = this.strategies.get(StrategyConstants.ConditionalStyleStrategyId);
                conditionalStyleagGridStrategy.initStyles();
            }
        }
    };
    AdaptableBlotter.prototype.isGroupRecord = function (record) {
        var rowNode = record;
        return rowNode.group;
    };
    AdaptableBlotter.prototype.getFirstRecord = function () {
        // TODO: we can find a better way but its only used by Calccolumn on creation so not urgent
        var record;
        this.gridOptions.api.forEachNode(function (rowNode) {
            if (!rowNode.group) {
                if (!record) {
                    record = rowNode;
                }
            }
        });
        return record;
    };
    // need to destroy more than just this...
    // TODO;  manage destruction properly
    AdaptableBlotter.prototype.destroy = function () {
        var abContainerElement = this.getBlotterContainerElement();
        if (abContainerElement != null) {
            ReactDOM.unmountComponentAtNode(abContainerElement);
        }
    };
    // TEMPORARY : JO
    AdaptableBlotter.prototype.getIPPStyle = function () {
        var headerFirstCol = document
            .querySelectorAll('.ag-header-cell')
            .item(0);
        var header = document.querySelector('.ag-header');
        var headerColStyle = window.getComputedStyle(header, null);
        var firstRow = document.querySelector('.ag-row-even');
        var firstRowStyle = window.getComputedStyle(firstRow, null);
        var secondRow = document.querySelector('.ag-row-odd');
        var secondRowStyle = window.getComputedStyle(secondRow, null);
        return {
            Header: {
                headerColor: new color_1.Color(headerColStyle.color).toHex(),
                headerBackColor: new color_1.Color(headerColStyle.backgroundColor).toHex(),
                headerFontFamily: headerColStyle.fontFamily,
                headerFontSize: headerColStyle.fontSize,
                headerFontStyle: headerColStyle.fontStyle,
                headerFontWeight: headerColStyle.fontWeight,
                height: Number(headerColStyle.height.replace('px', '')),
                Columns: this.api.gridApi.getColumns().map(function (col) {
                    var headerColumn = document.querySelector(".ag-header-cell[col-id='" + col.ColumnId + "']");
                    var headerColumnStyle = window.getComputedStyle(headerColumn || headerFirstCol, null);
                    return {
                        columnFriendlyName: col.FriendlyName,
                        width: Number(headerColumnStyle.width.replace('px', '')),
                        textAlign: headerColumnStyle.textAlign,
                    };
                }),
            },
            Row: {
                color: new color_1.Color(firstRowStyle.color).toHex(),
                backColor: new color_1.Color(firstRowStyle.backgroundColor).toHex(),
                altBackColor: new color_1.Color(secondRowStyle.backgroundColor).toHex(),
                fontFamily: firstRowStyle.fontFamily,
                fontSize: firstRowStyle.fontSize,
                fontStyle: firstRowStyle.fontStyle,
                fontWeight: firstRowStyle.fontWeight,
                height: Number(firstRowStyle.height.replace('px', '')),
                Columns: this.api.gridApi.getColumns().map(function (col) {
                    var cellElement = document.querySelector(".ag-cell[col-id='" + col.ColumnId + "']");
                    var headerColumnStyle = window.getComputedStyle(cellElement || firstRow, null);
                    return {
                        columnFriendlyName: col.FriendlyName,
                        width: Number(headerColumnStyle.width.replace('px', '')),
                        textAlign: headerColumnStyle.textAlign,
                    };
                }),
            },
        };
    };
    AdaptableBlotter.prototype.getBlotterContainerElement = function () {
        if (!this.abContainerElement) {
            this.abContainerElement = document.getElementById(this.blotterOptions.containerOptions.adaptableBlotterContainer);
        }
        return this.abContainerElement;
    };
    AdaptableBlotter.prototype.getGridContainerElement = function () {
        if (!this.gridContainerElement) {
            this.gridContainerElement = document.getElementById(this.blotterOptions.containerOptions.vendorContainer);
        }
        return this.gridContainerElement;
    };
    AdaptableBlotter.prototype.initInternalGridLogic = function () {
        var _this = this;
        if (this.renderGrid) {
            if (this.abContainerElement == null) {
                this.abContainerElement = this.getBlotterContainerElement();
            }
            if (this.abContainerElement == null) {
                LoggingHelper_1.LoggingHelper.LogAdaptableBlotterError("There is no DIV with id=\"" + this.blotterOptions.containerOptions.adaptableBlotterContainer + "\" so cannot render the Adaptable Blotter");
                return;
            }
        }
        var gridContainerElement = this.getGridContainerElement();
        if (gridContainerElement) {
            gridContainerElement.addEventListener('keydown', function (event) { return _this.emit(GeneralConstants_1.KEY_DOWN_EVENT, event); });
        }
        // vendorGrid.api.addGlobalListener((type: string, event: any) => {
        //     //console.log(event)
        // });
        // we could use the single event listener but for this one it makes sense to listen to all of them and filter on the type
        // since there are many events and we want them to behave the same
        this.gridOptions.api.addEventListener(eventKeys_1.Events.EVENT_COLUMN_VISIBLE, function (params) {
            if (params.visible) {
                _this.updateQuickSearchRangeVisibleColumn(params.column.colId);
            }
        });
        var columnEventsThatTriggersStateChange = [
            eventKeys_1.Events.EVENT_COLUMN_MOVED,
            eventKeys_1.Events.EVENT_GRID_COLUMNS_CHANGED,
            eventKeys_1.Events.EVENT_COLUMN_EVERYTHING_CHANGED,
            eventKeys_1.Events.EVENT_DISPLAYED_COLUMNS_CHANGED,
            //   Events.EVENT_DISPLAYED_COLUMNS_WIDTH_CHANGED,
            eventKeys_1.Events.EVENT_COLUMN_VISIBLE,
            //   Events.EVENT_COLUMN_PINNED,
            eventKeys_1.Events.EVENT_NEW_COLUMNS_LOADED,
        ];
        this.gridOptions.api.addGlobalListener(function (type) {
            if (columnEventsThatTriggersStateChange.indexOf(type) > -1) {
                // bit messy but better than alternative which was calling setColumnIntoStore for every single column
                var popupState = _this.getState().Popup.ScreenPopup;
                if (popupState.ShowScreenPopup &&
                    (popupState.ComponentName == ScreenPopups.ColumnChooserPopup ||
                        ScreenPopups.CalculatedColumnPopup)) {
                    // ignore
                }
                else {
                    // set the column into the store
                    _this.debouncedSetColumnIntoStore(); // was: this.setColumnIntoStore();
                }
                // refilter the grid if required
                _this.debouncedFilterGrid();
            }
        });
        // dealing with scenario where the data is poured into the blotter after grid has been setup
        this.gridOptions.api.addEventListener(eventKeys_1.Events.EVENT_FIRST_DATA_RENDERED, function () {
            _this.debouncedSetColumnIntoStore();
        });
        // once the grid is ready we should make sure we are too
        this.gridOptions.api.addEventListener(eventKeys_1.Events.EVENT_GRID_READY, function () {
            // do something?
        });
        // Pinning columms and changing column widths will trigger an auto save (if that and includvendorstate are both turned on)
        var columnEventsThatTriggersAutoLayoutSave = [
            eventKeys_1.Events.EVENT_DISPLAYED_COLUMNS_WIDTH_CHANGED,
            eventKeys_1.Events.EVENT_COLUMN_PINNED,
        ];
        this.gridOptions.api.addGlobalListener(function (type) {
            if (columnEventsThatTriggersAutoLayoutSave.indexOf(type) > -1) {
                _this.debouncedSaveGridLayout();
            }
        });
        this.gridOptions.api.addEventListener(eventKeys_1.Events.EVENT_COLUMN_RESIZED, function (params) {
            if (params.type == 'columnResized' && params.finished == true) {
                if (_this.isQuickFilterActive()) {
                    _this.gridOptions.api.refreshHeader();
                }
            }
        });
        // this event deals with when the user makes an edit - it doesnt look at ticking data
        this.gridOptions.api.addEventListener(eventKeys_1.Events.EVENT_CELL_EDITING_STARTED, function (params) {
            // TODO: Jo: This is a workaround as we are accessing private members of agGrid.
            // I still wonder if we can do this nicer by using :   this.gridOptions.api!.getEditingCells();
            // must be a good reason why we don't use it
            var editor = _this.gridOptions.api.rowRenderer.rowCompsByIndex[params.node.rowIndex]
                .cellComps[params.column.getColId()].cellEditor;
            // editor might be type Popup like agPopupTextCellEditor or agPopupSelectCellEditor (see: https://www.ag-grid.com/javascript-grid-cell-editing/)
            // if so then we need to get the inner editor
            if (editor instanceof ag_grid_community_1.PopupEditorWrapper) {
                _this._currentEditor = _this.gridOptions.api.rowRenderer.rowCompsByIndex[params.node.rowIndex].cellComps[params.column.getColId()].cellEditor.cellEditor;
            }
            else {
                _this._currentEditor = editor;
            }
            // No need to register for the keydown on the editor since we already register on the main div
            // if there was already an implementation set by the dev we keep the reference to it and execute it at the end
            var oldIsCancelAfterEnd = _this._currentEditor.isCancelAfterEnd;
            var isCancelAfterEnd = function () {
                var dataChangedInfo = {
                    OldValue: _this.gridOptions.api.getValue(params.column.getColId(), params.node),
                    NewValue: _this._currentEditor.getValue(),
                    ColumnId: params.column.getColId(),
                    IdentifierValue: _this.getPrimaryKeyValueFromRecord(params.node),
                    Record: params.node,
                };
                var failedRules = _this.ValidationService.ValidateCellChanging(dataChangedInfo);
                if (failedRules.length > 0) {
                    // first see if its an error = should only be one item in array if so
                    if (failedRules[0].ActionMode == 'Stop Edit') {
                        var errorMessage = ObjectFactory_1.ObjectFactory.CreateCellValidationMessage(failedRules[0], _this);
                        _this.api.alertApi.showAlertError('Validation Error', errorMessage, true);
                        return true;
                    }
                    var warningMessage_1 = '';
                    failedRules.forEach(function (f) {
                        warningMessage_1 = warningMessage_1 +
                            ObjectFactory_1.ObjectFactory.CreateCellValidationMessage(f, _this) + "\n";
                    });
                    var gridCell = {
                        primaryKeyValue: dataChangedInfo.IdentifierValue,
                        columnId: dataChangedInfo.ColumnId,
                        value: dataChangedInfo.NewValue,
                    };
                    var confirmAction = GridRedux.GridSetValueLikeEdit(gridCell, _this.gridOptions.api.getValue(params.column.getColId(), params.node));
                    var cancelAction = null;
                    var confirmation = CellValidationHelper_1.CellValidationHelper.createCellValidationUIConfirmation(confirmAction, cancelAction, warningMessage_1);
                    _this.dispatchAction(PopupRedux.PopupShowConfirmation(confirmation));
                    // we prevent the save and depending on the user choice we will set the value to the edited value in the middleware
                    return true;
                }
                var whatToReturn = oldIsCancelAfterEnd ? oldIsCancelAfterEnd() : false;
                if (!whatToReturn) {
                    // audit the cell event if needed
                    if (_this.AuditLogService.isAuditCellEditsEnabled) {
                        _this.AuditLogService.addEditCellAuditLog(dataChangedInfo);
                    }
                    // it might be a free text column so we need to update the values
                    _this.FreeTextColumnService.CheckIfDataChangingColumnIsFreeText(dataChangedInfo);
                    // do we need to also refresh calculated columns?
                }
                return whatToReturn;
            };
            _this._currentEditor.isCancelAfterEnd = isCancelAfterEnd;
        });
        this.gridOptions.api.addEventListener(eventKeys_1.Events.EVENT_CELL_EDITING_STOPPED, function () {
            // (<any>this._currentEditor).getGui().removeEventListener("keydown", (event: any) => this._onKeyDown.Dispatch(this, event))
            _this._currentEditor = null;
            // We refresh the filter so we get live search/filter when editing.
            // Note: I know it will be triggered as well when cancelling an edit but I don't think it's a prb
            // if they have set to run filter after edit then lets do it
            _this.filterOnUserDataChange();
            _this.debouncedSetSelectedCells();
        });
        var columnEventsThatTriggerSetRowSelection = [
            eventKeys_1.Events.EVENT_ROW_GROUP_OPENED,
            eventKeys_1.Events.EVENT_SELECTION_CHANGED,
            eventKeys_1.Events.EVENT_ROW_SELECTED,
        ];
        this.gridOptions.api.addGlobalListener(function (type) {
            if (ArrayExtensions_1.ArrayExtensions.ContainsItem(columnEventsThatTriggerSetRowSelection, type)) {
                _this.debouncedSetSelectedRows();
            }
        });
        this.gridOptions.api.addEventListener(eventKeys_1.Events.EVENT_ROW_GROUP_OPENED, function () {
            //      this.debouncedSetSelectedRows();
        });
        this.gridOptions.api.addEventListener(eventKeys_1.Events.EVENT_SELECTION_CHANGED, function () {
            //     this.debouncedSetSelectedRows();
        });
        this.gridOptions.api.addEventListener(eventKeys_1.Events.EVENT_ROW_SELECTED, function () {
            //     this.debouncedSetSelectedRows();
        });
        this.gridOptions.api.addEventListener(eventKeys_1.Events.EVENT_RANGE_SELECTION_CHANGED, function () {
            _this.debouncedSetSelectedCells();
        });
        // this.gridOptions.api!.addEventListener(Events.EVENT_TOOL_PANEL_VISIBLE_CHANGED, () => {
        // });
        //  this.gridOptions.api!.addEventListener(Events.EVENT_COLUMN_ROW_GROUP_CHANGED, (params: any) => {
        // });
        this.gridOptions.api.addEventListener(eventKeys_1.Events.EVENT_SORT_CHANGED, function () {
            _this.onSortChanged();
            _this.debouncedSetSelectedCells();
        });
        // this.gridOptions.api.addEventListener(Events.EVENT_ROW_DATA_UPDATED, (params: any) => {
        //  console.log('in row data updated');
        //  console.log(params);
        //});
        // this.gridOptions.api.addEventListener(Events.EVENT_ROW_DATA_CHANGED, (params: any) => {
        //  console.log('in row data changed');
        //   console.log(params);
        // });
        this.gridOptions.api.addEventListener(eventKeys_1.Events.EVENT_MODEL_UPDATED, function (params) {
            // not sure about this - doing it to make sure that we set the columns properly at least once!
            _this.checkColumnsDataTypeSet();
        });
        var rowListeners = {
            dataChanged: function (event) {
                return _this.onRowDataChanged({
                    //  myevent: event,
                    node: event.node,
                    oldData: event.oldData,
                    newData: event.newData,
                });
            },
        };
        /**
         * AgGrid does not expose Events.EVENT_ROW_DATA_CHANGED
         *
         * so we have to override `dispatchLocalEvent`
         * and hook our own functionality into it
         *
         */
        RowNodeProto.dispatchLocalEvent = function (event) {
            var result = RowNode_dispatchLocalEvent.apply(this, arguments);
            var fn = rowListeners[event.type];
            if (fn) {
                fn(event);
            }
            return result;
        };
        // this handles ticking data
        // except it doesnt handle when data has been added to ag-Grid using updateRowData  ouch !!!
        this.gridOptions.api.addEventListener(eventKeys_1.Events.EVENT_CELL_VALUE_CHANGED, function (params) {
            // this gets called as soon as opening editor so make sure the values are different before starting any work...
            if (params.newValue != params.oldValue) {
                var identifierValue_1 = _this.getPrimaryKeyValueFromRecord(params.node);
                var colId = params.colDef.field;
                var dataChangedInfo = {
                    OldValue: params.oldValue,
                    NewValue: params.newValue,
                    ColumnId: colId,
                    IdentifierValue: identifierValue_1,
                    Record: params.node,
                };
                _this.DataService.CreateDataChangedEvent(dataChangedInfo);
                // 24/08/17 : AgGrid doesn't raise an event for computed columns that depends on that column
                // so we manually raise.
                // https://github.com/JonnyAdaptableTools/adaptableblotter/issues/118
                var refreshColumnList_1 = [colId];
                var columnList = _this.calculatedColumnPathMap.get(colId);
                if (columnList) {
                    columnList.forEach(function (columnId) {
                        var dataChangedInfo = {
                            OldValue: params.oldValue,
                            NewValue: _this.gridOptions.api.getValue(columnId, params.node),
                            ColumnId: columnId,
                            IdentifierValue: identifierValue_1,
                            Record: params.node,
                        };
                        _this.DataService.CreateDataChangedEvent(dataChangedInfo);
                        ArrayExtensions_1.ArrayExtensions.AddItem(refreshColumnList_1, columnId);
                    });
                }
                // see if we need to refresh any percent bars
                _this.api.percentBarApi.getAllPercentBar().forEach(function (pb) {
                    refreshColumnList_1.forEach(function (changedColId) {
                        if (StringExtensions_1.StringExtensions.IsNotNullOrEmpty(pb.MaxValueColumnId) &&
                            pb.MaxValueColumnId == changedColId) {
                            ArrayExtensions_1.ArrayExtensions.AddItem(refreshColumnList_1, pb.ColumnId);
                        }
                        if (StringExtensions_1.StringExtensions.IsNotNullOrEmpty(pb.MinValueColumnId) &&
                            pb.MinValueColumnId == changedColId) {
                            ArrayExtensions_1.ArrayExtensions.AddItem(refreshColumnList_1, pb.ColumnId);
                        }
                    });
                });
                // this is new  - giving users ability to filter on external data changes
                _this.filterOnExternalDataChange();
                // only if visible...
                _this.refreshCells([params.node], refreshColumnList_1);
            }
        });
        // We plug our filter mechanism and if there is already something like external widgets... we save ref to the function
        var originalisExternalFilterPresent = this.gridOptions.isExternalFilterPresent;
        this.gridOptions.isExternalFilterPresent = function () {
            var e_6, _a;
            var columnFilters = _this.getState().ColumnFilter.ColumnFilters;
            var isFilterActive = ArrayExtensions_1.ArrayExtensions.IsNotNullOrEmpty(columnFilters);
            if (isFilterActive) {
                try {
                    // used in particular at init time to show the filter icon correctly
                    for (var columnFilters_1 = tslib_1.__values(columnFilters), columnFilters_1_1 = columnFilters_1.next(); !columnFilters_1_1.done; columnFilters_1_1 = columnFilters_1.next()) {
                        var colFilter = columnFilters_1_1.value;
                        var agGridCol = _this.gridOptions.columnApi.getColumn(colFilter.ColumnId);
                        if (agGridCol) {
                            if (!agGridCol.isFilterActive()) {
                                agGridCol.setFilterActive(true);
                            }
                        }
                    }
                }
                catch (e_6_1) { e_6 = { error: e_6_1 }; }
                finally {
                    try {
                        if (columnFilters_1_1 && !columnFilters_1_1.done && (_a = columnFilters_1.return)) _a.call(columnFilters_1);
                    }
                    finally { if (e_6) throw e_6.error; }
                }
            }
            var isSearchActive = StringExtensions_1.StringExtensions.IsNotNullOrEmpty(_this.getState().AdvancedSearch.CurrentAdvancedSearch);
            var isQuickSearchActive = StringExtensions_1.StringExtensions.IsNotNullOrEmpty(_this.getState().QuickSearch.QuickSearchText);
            // it means that originaldoesExternalFilterPass will be called to we reinit that collection
            return (isFilterActive ||
                isSearchActive ||
                isQuickSearchActive ||
                (originalisExternalFilterPresent ? originalisExternalFilterPresent() : false));
        };
        var originaldoesExternalFilterPass = this.gridOptions.doesExternalFilterPass;
        this.gridOptions.doesExternalFilterPass = function (node) {
            var e_7, _a, e_8, _b;
            var columns = _this.api.gridApi.getColumns();
            // first we assess AdvancedSearch (if its running locally)
            if (_this.blotterOptions.generalOptions.serverSearchOption == 'None') {
                var currentSearch = _this.api.advancedSearchApi.getCurrentAdvancedSearch();
                if (currentSearch) {
                    // See if our record passes the Expression - using Expression Helper; if not then return false
                    if (!ExpressionHelper_1.ExpressionHelper.checkForExpressionFromRecord(currentSearch.Expression, node, columns, _this)) {
                        return false;
                    }
                }
            }
            // we then assess filters
            if (_this.getGeneralOptions().serverSearchOption == 'None' ||
                _this.getGeneralOptions().serverSearchOption == 'AdvancedSearch') {
                var columnFilters = _this.api.columnFilterApi.getAllColumnFilter();
                if (columnFilters.length > 0) {
                    try {
                        for (var columnFilters_2 = tslib_1.__values(columnFilters), columnFilters_2_1 = columnFilters_2.next(); !columnFilters_2_1.done; columnFilters_2_1 = columnFilters_2.next()) {
                            var columnFilter = columnFilters_2_1.value;
                            if (!ExpressionHelper_1.ExpressionHelper.checkForExpressionFromRecord(columnFilter.Filter, node, columns, _this)) {
                                return false;
                            }
                        }
                    }
                    catch (e_7_1) { e_7 = { error: e_7_1 }; }
                    finally {
                        try {
                            if (columnFilters_2_1 && !columnFilters_2_1.done && (_a = columnFilters_2.return)) _a.call(columnFilters_2);
                        }
                        finally { if (e_7) throw e_7.error; }
                    }
                }
                // we next assess quicksearch
                var quickSearchState = _this.api.quickSearchApi.getQuickSearchState();
                if (quickSearchState.DisplayAction != Enums_1.DisplayAction.HighlightCell) {
                    if (StringExtensions_1.StringExtensions.IsNullOrEmpty(quickSearchState.QuickSearchText)) {
                        return true;
                    }
                    var quickSearchVisibleColumnExpresssions = _this.getState().System
                        .QuickSearchVisibleColumnExpressions;
                    var quickSearchRange = _this.getState().System.QuickSearchRange;
                    if (quickSearchRange == null) {
                        // might not have created so lets do it here
                        quickSearchRange = RangeHelper_1.RangeHelper.CreateValueRangeFromOperand(quickSearchState.QuickSearchText);
                    }
                    if (quickSearchRange != null) {
                        var visibleCols = columns.filter(function (c) { return c.Visible; });
                        var _loop_1 = function (column) {
                            var expression = quickSearchVisibleColumnExpresssions.find(function (exp) { return exp.RangeExpressions[0].ColumnId == column.ColumnId; });
                            if (expression) {
                                if (ExpressionHelper_1.ExpressionHelper.checkForExpressionFromRecord(expression, node, [column], _this)) {
                                    return { value: originaldoesExternalFilterPass
                                            ? originaldoesExternalFilterPass(node)
                                            : true };
                                }
                            }
                        };
                        try {
                            for (var visibleCols_1 = tslib_1.__values(visibleCols), visibleCols_1_1 = visibleCols_1.next(); !visibleCols_1_1.done; visibleCols_1_1 = visibleCols_1.next()) {
                                var column = visibleCols_1_1.value;
                                var state_1 = _loop_1(column);
                                if (typeof state_1 === "object")
                                    return state_1.value;
                            }
                        }
                        catch (e_8_1) { e_8 = { error: e_8_1 }; }
                        finally {
                            try {
                                if (visibleCols_1_1 && !visibleCols_1_1.done && (_b = visibleCols_1.return)) _b.call(visibleCols_1);
                            }
                            finally { if (e_8) throw e_8.error; }
                        }
                    }
                    else {
                        return true; // is this right????
                    }
                    return false;
                }
            }
            return originaldoesExternalFilterPass ? originaldoesExternalFilterPass(node) : true;
        };
        // add any special renderers
        this.api.percentBarApi.getAllPercentBar().forEach(function (pcr) {
            _this.addPercentBar(pcr);
        });
        var originalgetMainMenuItems = this.gridOptions.getMainMenuItems;
        this.gridOptions.getMainMenuItems = function (params) {
            // couldnt find a way to listen for menu close. There is a Menu Item Select
            // but you can also clsoe the menu from filter and clicking outside the menu....
            var colId = params.column.getColId();
            // not quite sure we why do it this way
            // we clear the column menu
            // set all the items
            // then read them 5 lines below !....
            _this.dispatchAction(MenuRedux.ClearColumntMenu());
            var column = ColumnHelper_1.ColumnHelper.getColumnFromId(colId, _this.api.gridApi.getColumns());
            if (column != null) {
                _this.strategies.forEach(function (s) {
                    s.addColumnMenuItem(column);
                });
            }
            var colMenuItems;
            // if there was an initial implementation we init the list of menu items with this one, otherwise we take
            // the default items
            if (originalgetMainMenuItems) {
                var originalMenuItems = originalgetMainMenuItems(params);
                colMenuItems = originalMenuItems.slice(0);
            }
            else {
                colMenuItems = params.defaultItems.slice(0);
            }
            colMenuItems.push('separator');
            _this.getState().Menu.ColumnMenu.MenuItems.forEach(function (x) {
                colMenuItems.push({
                    name: x.Label,
                    action: function () { return _this.dispatchAction(x.Action); },
                    icon: icons_1.iconToString(x.GlyphIcon, {
                        style: {
                            fill: 'var(--ab-color-text-on-primary)',
                        },
                    }),
                });
            });
            return colMenuItems;
        };
        /*
            this.AdaptableBlotterStore.Load
                .then(() => this.strategies.forEach(strat => strat.initializeWithRedux()), (e) => {
                    LoggingHelper.LogAdaptableBlotterError('Failed to Init AdaptableBlotterStore : ', e);
                    //for now i'm still initializing the strategies even if loading state has failed....
                    //we may revisit that later
                    this.strategies.forEach(strat => strat.initializeWithRedux());
    
                });
    */
        var originalgetContextMenuItems = this.gridOptions.getContextMenuItems;
        this.gridOptions.getContextMenuItems = function (params) {
            // this is the agGrid Context Menu that we might want to listen to...
            var colMenuItems;
            // if there was an initial implementation we init the list of menu items with this one, otherwise we take default items
            // this allows us to ensure that devs can still create their own agGrid context menu without losing ours
            if (originalgetContextMenuItems) {
                var originalContexttems = originalgetContextMenuItems(params);
                colMenuItems = originalContexttems.slice(0);
            }
            else {
                colMenuItems = params.defaultItems.slice(0);
            }
            colMenuItems.push('separator');
            // this is where we will add extra itesm...
            return colMenuItems;
        };
    };
    AdaptableBlotter.prototype.addPercentBar = function (pcr) {
        var renderedColumn = ColumnHelper_1.ColumnHelper.getColumnFromId(pcr.ColumnId, this.api.gridApi.getColumns());
        if (renderedColumn) {
            var cellRendererFunc = this.agGridHelper.createPercentBarCellRendererFunc(pcr, this.blotterOptions.blotterId);
            var vendorGridColumn = this.gridOptions.columnApi.getColumn(pcr.ColumnId);
            var coldDef = vendorGridColumn.getColDef();
            coldDef.cellRenderer = cellRendererFunc;
            // change the style from number-cell temporarily?
            if (coldDef.cellClass == 'number-cell') {
                coldDef.cellClass = 'number-cell-changed';
            }
            if (pcr.ShowToolTip != null && pcr.ShowToolTip == true) {
                coldDef.tooltipField = coldDef.field;
                // for now NOT using this PercentBarTooltip but we can add it later and will be powwerful.
                //   console.log('getting tooltip');
                //  coldDef.tooltipComponent = PercentBarTooltip;
                // coldDef.tooltipValueGetter = (params: ITooltipParams) => {
                //   return { value: params.value * 10 };
                // };
            }
            else {
                coldDef.tooltipField = '';
            }
        }
    };
    AdaptableBlotter.prototype.onRowDataChanged = function (_a) {
        var _this = this;
        var 
        // myevent,
        node = _a.node, oldData = _a.oldData, newData = _a.newData;
        // this is not quite right as its breaking for master / detail : openign a Master fires DataChanged Events of update : false and no oldData
        // should we check the event for false?
        // or should we check for oldData?
        // for now will do the second...
        // might need to rethink if we add full cache and then just return if its master / details
        if (oldData == null || oldData == undefined) {
            return;
        }
        var identifierValue = this.getPrimaryKeyValueFromRecord(node);
        Object.keys(oldData).forEach(function (key) {
            var oldValue = oldData[key];
            var newValue = newData[key];
            if (oldValue != newValue) {
                var dataChangedInfo = {
                    OldValue: oldValue,
                    NewValue: newValue,
                    ColumnId: key,
                    IdentifierValue: identifierValue,
                    Record: node,
                };
                _this.DataService.CreateDataChangedEvent(dataChangedInfo);
                // todo - same stuff with percent bars and calculated columns
                // need to refactor into an afterDataChangedEventCreated method so we do it once
            }
        });
    };
    AdaptableBlotter.prototype.removePercentBar = function (pcr) {
        var renderedColumn = ColumnHelper_1.ColumnHelper.getColumnFromId(pcr.ColumnId, this.api.gridApi.getColumns());
        if (renderedColumn) {
            var vendorGridColumn = this.gridOptions.columnApi.getColumn(pcr.ColumnId);
            // note we dont get it from the original (but I guess it will be applied next time you run...)
            vendorGridColumn.getColDef().cellRenderer = null;
            var coldDef = vendorGridColumn.getColDef();
            coldDef.cellRenderer = null;
            // change the style back if it was changed by us
            if (coldDef.cellClass == 'number-cell-changed') {
                coldDef.cellClass = 'number-cell';
            }
        }
    };
    AdaptableBlotter.prototype.editPercentBar = function (pcr) {
        this.removePercentBar(pcr);
        this.addPercentBar(pcr);
    };
    AdaptableBlotter.prototype.onSortChanged = function () {
        var _this = this;
        var sortModel = this.gridOptions.api.getSortModel();
        var columnSorts = [];
        if (sortModel != null) {
            if (sortModel.length > 0) {
                sortModel.forEach(function (sm) {
                    if (ColumnHelper_1.ColumnHelper.isSpecialColumn(sm.colId)) {
                        var groupedColumn_1 = _this.gridOptions.columnApi
                            .getAllColumns()
                            .find(function (c) { return c.isRowGroupActive() == true; });
                        if (groupedColumn_1) {
                            var customSort = _this.api.customSortApi
                                .getAllCustomSort()
                                .find(function (cs) { return cs.ColumnId == groupedColumn_1.getColId(); });
                            if (customSort) {
                                // check that not already applied
                                if (!_this.getState().Grid.ColumnSorts.find(function (gs) {
                                    return ColumnHelper_1.ColumnHelper.isSpecialColumn(gs.Column);
                                })) {
                                    var customSortStrategy = _this.strategies.get(StrategyConstants.CustomSortStrategyId);
                                    var groupCustomSort = ObjectFactory_1.ObjectFactory.CreateEmptyCustomSort();
                                    groupCustomSort.ColumnId = sm.colId;
                                    groupCustomSort.SortedValues = customSort.SortedValues;
                                    var comparator = customSortStrategy.getComparerFunction(groupCustomSort, _this);
                                    _this.setCustomSort(sm.colId, comparator);
                                }
                            }
                        }
                    }
                    var columnSort = {
                        Column: sm.colId,
                        SortOrder: sm.sort == 'asc' ? Enums_1.SortOrder.Ascending : Enums_1.SortOrder.Descending,
                    };
                    columnSorts.push(columnSort);
                });
            }
        }
        this.dispatchAction(GridRedux.GridSetSort(columnSorts));
    };
    AdaptableBlotter.prototype.getRowCount = function () {
        return this.gridOptions.rowData
            ? this.gridOptions.rowData.length
            : this.gridOptions.api.getDisplayedRowCount();
    };
    AdaptableBlotter.prototype.getColumnCount = function () {
        return this.gridOptions.columnApi.getAllColumns().length;
    };
    AdaptableBlotter.prototype.getVisibleRowCount = function () {
        return this.gridOptions.api.getDisplayedRowCount();
    };
    AdaptableBlotter.prototype.getVisibleColumnCount = function () {
        return this.gridOptions.columnApi.getAllColumns().filter(function (c) { return c.isVisible(); }).length;
    };
    AdaptableBlotter.prototype.selectColumn = function (columnId) {
        this.gridOptions.api.clearRangeSelection();
        var cellRangeParams = {
            rowStartIndex: 0,
            rowEndIndex: this.gridOptions.api.getDisplayedRowCount(),
            columnStart: columnId,
            columnEnd: columnId,
        };
        this.gridOptions.api.addCellRange(cellRangeParams);
    };
    AdaptableBlotter.prototype.setColumnSort = function (columnSorts) {
        // get the sort model
        var sortModel = [];
        columnSorts.forEach(function (gs) {
            var sortDescription = gs.SortOrder == Enums_1.SortOrder.Ascending ? 'asc' : 'desc';
            sortModel.push({ colId: gs.Column, sort: sortDescription });
        });
        this.gridOptions.api.setSortModel(sortModel);
        this.gridOptions.api.onSortChanged();
    };
    AdaptableBlotter.prototype.setGridData = function (dataSource) {
        this.gridOptions.api.setRowData(dataSource);
    };
    AdaptableBlotter.prototype.updateQuickSearchRangeVisibleColumn = function (columnId) {
        if (this.isInitialised) {
            var quickSearchState = this.api.quickSearchApi.getQuickSearchState();
            // only update if quick search is not highlight and is set - rare use case...
            if (quickSearchState.DisplayAction != Enums_1.DisplayAction.HighlightCell &&
                StringExtensions_1.StringExtensions.IsNotNullOrEmpty(quickSearchState.QuickSearchText)) {
                var quickSearchRange = this.getState().System.QuickSearchRange;
                var column = ColumnHelper_1.ColumnHelper.getColumnFromId(columnId, this.api.gridApi.getColumns());
                if (quickSearchRange != null) {
                    if (RangeHelper_1.RangeHelper.IsColumnAppropriateForRange(quickSearchRange.Operator, column)) {
                        var quickSearchVisibleColumnExpression = ExpressionHelper_1.ExpressionHelper.CreateSingleColumnExpression(column.ColumnId, null, null, null, [quickSearchRange]);
                        var quickSearchVisibleColumnExpressions = [].concat(this.getState().System.QuickSearchVisibleColumnExpressions);
                        quickSearchVisibleColumnExpressions.push(quickSearchVisibleColumnExpression);
                        this.adaptableBlotterStore.TheStore.dispatch(SystemRedux.QuickSearchSetVisibleColumnExpressions(quickSearchVisibleColumnExpressions));
                    }
                }
            }
        }
    };
    AdaptableBlotter.prototype.checkColumnsDataTypeSet = function () {
        // check that we have no unknown columns - if we do then ok
        var firstCol = this.api.gridApi.getColumns()[0];
        if (firstCol && firstCol.DataType == Enums_1.DataType.Unknown) {
            this.setColumnIntoStore();
        }
    };
    AdaptableBlotter.prototype.getVendorGridState = function (visibleCols, forceFetch) {
        // forceFetch is used for default layout and just gets everything in the grid's state - not nice and can be refactored
        if (forceFetch) {
            return {
                GroupState: null,
                ColumnState: JSON.stringify(this.gridOptions.columnApi.getColumnState()),
            };
        }
        if (this.blotterOptions.layoutOptions != null &&
            this.blotterOptions.layoutOptions.includeVendorStateInLayouts != null &&
            this.blotterOptions.layoutOptions.includeVendorStateInLayouts) {
            var groupedState = null;
            var displayedColumns = this.gridOptions.columnApi.getAllDisplayedColumns();
            var groupedCol = displayedColumns.find(function (c) { return ColumnHelper_1.ColumnHelper.isSpecialColumn(c.getColId()); });
            if (groupedCol) {
                groupedState = groupedCol.getActualWidth();
            }
            var columnState = this.gridOptions.columnApi.getColumnState();
            // Dont like this but not sure we have a choice to avoid other issues...
            // Going to update the state to make sure that visibility matches those given here
            columnState.forEach(function (c) {
                // to do
                var colId = c.colId;
                if (visibleCols.find(function (v) { return v == colId; })) {
                    c.hide = false;
                }
                else {
                    c.hide = true;
                }
            });
            return {
                GroupState: groupedState,
                ColumnState: JSON.stringify(columnState),
            };
        }
        return null; // need this?
    };
    AdaptableBlotter.prototype.setVendorGridState = function (vendorGridState) {
        if (vendorGridState) {
            var columnState = JSON.parse(vendorGridState.ColumnState);
            if (columnState) {
                this.setColumnState(this.gridOptions.columnApi, columnState, 'api');
            }
            var groupedState = vendorGridState.GroupState;
            if (groupedState) {
                // assume for now its just a number
                var column = this.gridOptions.columnApi.getColumn('ag-Grid-AutoColumn');
                if (column) {
                    this.gridOptions.columnApi.setColumnWidth(column, groupedState, true);
                }
            }
        }
    };
    // these 3 methods are strange as we shouldnt need to have to set a columnEventType but it seems agGrid forces us to
    // not sure why as its not in the api
    AdaptableBlotter.prototype.setColumnVisible = function (columnApi, col, isVisible, columnEventType) {
        columnApi.setColumnVisible(col, isVisible, columnEventType);
    };
    AdaptableBlotter.prototype.moveColumn = function (columnApi, col, index, columnEventType) {
        columnApi.moveColumn(col, index, columnEventType);
    };
    AdaptableBlotter.prototype.setColumnState = function (columnApi, columnState, columnEventType) {
        columnApi.setColumnState(columnState, columnEventType);
    };
    AdaptableBlotter.prototype.isSelectable = function () {
        if (this.gridOptions.enableRangeSelection != null) {
            return this.gridOptions.enableRangeSelection;
        }
        return false;
    };
    AdaptableBlotter.prototype.isQuickFilterActive = function () {
        return (this.gridOptions.floatingFilter != null &&
            this.gridOptions.floatingFilter == true &&
            this.blotterOptions.filterOptions.useAdaptableBlotterQuickFilter);
    };
    AdaptableBlotter.prototype.showQuickFilter = function () {
        var _this = this;
        if (this.blotterOptions.filterOptions.useAdaptableBlotterQuickFilter) {
            this.gridOptions.floatingFilter = true;
            this.gridOptions.columnApi.getAllGridColumns().forEach(function (col) {
                _this.createQuickFilterWrapper(col);
            });
            this.gridOptions.api.refreshHeader();
        }
    };
    AdaptableBlotter.prototype.hideQuickFilter = function () {
        if (this.blotterOptions.filterOptions.useAdaptableBlotterQuickFilter) {
            this.gridOptions.floatingFilter = false;
            this.gridOptions.api.refreshHeader();
        }
    };
    AdaptableBlotter.prototype.applyBlotterTheme = function (theme) {
        var themeName = typeof theme === 'string' ? theme : theme.Name;
        var themesToRemove = [];
        var el = document.documentElement;
        el.classList.forEach(function (cssClassName) {
            if (cssClassName.indexOf('ab--theme-') === 0) {
                themesToRemove.push(cssClassName);
            }
        });
        themesToRemove.forEach(function (cssClassName) { return el.classList.remove(cssClassName); });
        var newThemeClassName = "ab--theme-" + themeName;
        el.classList.add(newThemeClassName);
        var computedDocumentStyle = getComputedStyle(el);
        var _a = tslib_1.__read(['--ab-loaded', '--ab-theme-loaded'].map(function (variable) {
            var val = computedDocumentStyle.getPropertyValue(variable);
            if (typeof val === 'string' && val.trim) {
                val = val.trim();
            }
            return val;
        }), 2), abLoaded = _a[0], abThemeLoaded = _a[1];
        var systemThemes = this.api.themeApi.getAllSystemTheme();
        var isSystemTheme = !!systemThemes.filter(function (t) { return t.Name === themeName; })[0];
        if (isSystemTheme) {
            var container = this.getGridContainerElement();
            if (container != null) {
                var vendorLight = this.agGridHelper.getVendorLightThemeName();
                var vendorDark = this.agGridHelper.getVendorDarkThemeName();
                container.classList.remove(vendorLight);
                container.classList.remove(vendorDark);
                container.classList.add(themeName === GeneralConstants_1.LIGHT_THEME ? vendorLight : vendorDark);
            }
        }
        if (abLoaded !== '777') {
            LoggingHelper_1.LoggingHelper.LogError('Please import the AdaptableBlotter styles from "adaptableblotter/index.css"');
        }
        // every theme should define a custom css variable: --ab-theme-loaded: <themeName> defined on the document element.
        if (abThemeLoaded !== themeName) {
            LoggingHelper_1.LoggingHelper.LogWarning("Theme \"" + themeName + "\" doesn't seem to be loaded! Make sure you import the css file for the \"" + themeName + "\" theme!\n        \nIf it's a default theme, try\n\nimport \"adaptableblotter/themes/" + themeName + ".css\"");
        }
    };
    // Method called after we have rendered the grid
    // where we apply our stuff but also any ag-Grid props that we control
    AdaptableBlotter.prototype.applyFinalRendering = function () {
        var _this = this;
        // Apply row styles here?  weird that it cannot find the method in Helper.
        this.agGridHelper.setUpRowStyles();
        // not sure if this is the right place here.
        // perhaps we need some onDataLoaded event??
        var editLookUpCols = this.api.userInterfaceApi.getUserInterfaceState()
            .EditLookUpColumns;
        if (ArrayExtensions_1.ArrayExtensions.IsNotNullOrEmpty(editLookUpCols)) {
            var colDefs_1 = this.gridOptions.columnApi.getAllColumns().map(function (x) { return x.getColDef(); });
            editLookUpCols.forEach(function (e) {
                var colDefIndex = colDefs_1.findIndex(function (x) { return x.field == e.ColumnId; });
                var newColDef = colDefs_1[colDefIndex];
                newColDef.cellEditor = 'agRichSelectCellEditor';
                if (ArrayExtensions_1.ArrayExtensions.IsNullOrEmpty(e.LookUpValues)) {
                    newColDef.cellEditorParams = {
                        values: _this.getColumnValueDisplayValuePairDistinctList(e.ColumnId, Enums_1.DistinctCriteriaPairValue.DisplayValue, false).map(function (t) { return t.DisplayValue; }),
                    };
                }
                else {
                    newColDef.cellEditorParams = {
                        values: e.LookUpValues,
                    };
                }
                colDefs_1[colDefIndex] = newColDef;
            });
            this.agGridHelper.safeSetColDefs(colDefs_1);
        }
        // add the filter header style if required
        if (this.blotterOptions.filterOptions.indicateFilteredColumns == true) {
            var css = document.createElement('style');
            css.id = this.blotterOptions.blotterId + "_filtered-columns-style";
            css.type = 'text/css';
            css.innerHTML = '.ag-header-cell-filtered {  font-style: italic; font-weight: bolder;}';
            document.body.appendChild(css);
        }
        // sometimes the header row looks wrong when using quick filter so to be sure...
        if (this.isQuickFilterActive()) {
            this.dispatchAction(GridRedux.QuickFilterBarShow());
            this.gridOptions.api.refreshHeader();
        }
        // if user layout and a percent bar sometimes the first few cells are pre-rendered so we frig it like this
        var currentlayout = this.api.layoutApi.getCurrentLayoutName();
        if (currentlayout != GeneralConstants_1.DEFAULT_LAYOUT &&
            ArrayExtensions_1.ArrayExtensions.IsNotNullOrEmpty(this.api.percentBarApi.getAllPercentBar())) {
            this.api.layoutApi.setLayout(GeneralConstants_1.DEFAULT_LAYOUT);
        }
        // at the end so load the current layout
        this.api.layoutApi.setLayout(currentlayout);
    };
    AdaptableBlotter.prototype.getGeneralOptions = function () {
        return this.blotterOptions.generalOptions;
    };
    // A couple of state management functions
    AdaptableBlotter.prototype.getState = function () {
        return this.adaptableBlotterStore.TheStore.getState();
    };
    AdaptableBlotter.prototype.dispatchAction = function (action) {
        this.adaptableBlotterStore.TheStore.dispatch(action);
    };
    return AdaptableBlotter;
}());
exports.AdaptableBlotter = AdaptableBlotter;
